/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser;

import java.net.URL;

import com.springsource.json.parser.Node;

/**
 * A JsonParser is able to parse data obeying the JSON format originating from either a URL or a simple string.
 * <p />
 * 
 * Implementations of this interface should be thread safe.
 * 
 * @author Andy Clement
 * @since 1.0
 */
public interface JSONParser {

    /**
     * Parse JSON formatted data from the specified URL.
     * 
     * @param jsonDataURL the URL at which JSON formatted data can be found
     * @return the root of the parse tree
     */
    Node parse(URL jsonDataURL) throws JSONParseException;

    /**
     * Parse the supplied string as JSON formatted data.
     * 
     * @param jsonDataURL a simple string obeying the JSON format
     * @return the root of the parse tree
     */
    Node parse(String jsonData) throws JSONParseException;
}
