/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser;

import com.springsource.json.parser.StandardJSONParserLogger;

/**
 * Any messages that occur during parsing (error/warn/info) are reported through a JSONParserLogger instance. A standard
 * implementation is used (@see {@link StandardJSONParserLogger}) if an alternative implementation is not supplied at
 * parser instance construction time.
 * <p />
 * 
 * Implementations of this class should be thread safe.
 * 
 * @author Andy Clement
 * @author Rob Harrop
 * @since 1.0
 */
public interface JSONParserLogger {

    void error(ParserMessage message, int line, int col, Object... inserts);

    void error(ParserMessage message, int line, int col, Throwable throwable, Object... inserts);

    void warn(ParserMessage message, int line, int col, Object... inserts);

    void info(ParserMessage message, int line, int col, Object... inserts);

}
