/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser;

import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.tree.CommonTreeNodeStream;

import com.springsource.json.parser.JSONParserLogger;
import com.springsource.json.parser.generated.JsonFormatTreeWalker;

/**
 * The LoggedJsonFormatTreeWalker extends the Antlr generated JsonFormatTreeWalker and allows a logger to be plugged in.
 * This logger will get all info/warn/error events that occur during parser processing. If no parser logger is plugged
 * in, a StandardJsonParserLogger instance will be created and used, which reports events to System.out.
 * <p />
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 * @since 1.0
 */
class LoggedJsonFormatTreeWalker extends JsonFormatTreeWalker {

    private final JSONParserLogger logger;

    public LoggedJsonFormatTreeWalker(JSONParserLogger logger, CommonTreeNodeStream treeNodeStream) {
        super(treeNodeStream);
        this.logger = logger;
    }

    @Override
    public void reportError(RecognitionException re) {
        logger.error(ParserMessage.ERROR_RECOGNITION, re.line, re.charPositionInLine, re);
    }

}
