/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;


/**
 * Basic implementation of the JsonParserLogger that reports info/warn/error messages and exception to Commons Logging.
 * Instances of this class are used if no other implementation of JsonParserLogger is supplied at parser construction
 * time.
 * <p />
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 * @author Rob Harrop
 * @since 1.0
 */
public class StandardJSONParserLogger implements JSONParserLogger {

    private final Log LOG = LogFactory.getLog(StandardJSONParserLogger.class);

    public void error(ParserMessage message, int line, int col, Object... inserts) {
        error(message, line, col, null, inserts);
    }

    public void error(ParserMessage message, int line, int col, Throwable throwable, Object... inserts) {
        if (LOG.isErrorEnabled()) {
            LOG.error(message.format(line, col, inserts), throwable);
        }
    }

    public void info(ParserMessage message, int line, int col, Object... inserts) {
        if (LOG.isInfoEnabled()) {
            LOG.info(message.format(line, col, inserts));
        }
    }

    public void warn(ParserMessage message, int line, int col, Object... inserts) {
        if (LOG.isWarnEnabled()) {
            LOG.warn(message.format(line, col, inserts));
        }
    }

}
