/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser.internal;

import java.util.ArrayList;
import java.util.List;

import com.springsource.json.parser.InternalParseException;
import com.springsource.json.parser.Node;

public abstract class AbstractNode implements Node {

    private static final List<String> EMPTY_PATH = new ArrayList<String>();

    private final Node parent;

    public AbstractNode(Node parent) {
        this.parent = parent;
    }

    protected String head(List<String> path) {
        if (path.isEmpty()) {
            return null;
        } else {
            return path.get(0);
        }
    }

    protected List<String> tail(List<String> path) {
        if (path.isEmpty()) {
            return null;
        } else {
            return path.size() > 1 ? path.subList(1, path.size()) : EMPTY_PATH;
        }
    }

    public Node getParent() {
        return parent;
    }

    public final String getPath() {
        Node parent = getParent();
        if (parent == null)
            return "";
        else
            return parent.getPath(this);
    }

    public final String getPath(Node childNode) {
        if (childNode.getParent() == this) {
            return doGetPath(childNode);
        } else {
            throw new InternalParseException("Invalid child node", null);
        }
    }

    protected String doGetPath(Node childNode) {
        throw new InternalParseException("doGetPath not overridden", null);
    }

}
