/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser.internal;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.springsource.json.parser.InternalParseException;
import com.springsource.json.parser.ListNode;
import com.springsource.json.parser.Node;

/**
 * Implementation of the ListNode. A ListNode is represented as a java.util.List of child nodes.
 * 
 * this class is thread safe.
 * 
 * @author Andy Clement
 * @since 1.0
 */
public final class StandardListNode extends AbstractNode implements ListNode {

    public StandardListNode(Node parent) {
        super(parent);
    }

    private final List<Node> nodeList = Collections.synchronizedList(new ArrayList<Node>());

    public List<Node> getNodes() {
        return Collections.unmodifiableList(this.nodeList);
    }

    public boolean addNode(Node newNode) {
        if (newNode.getParent() != this) {
            throw new InternalParseException("Cannot add node to a list node which is not a child of the list node", null);
        }
        return this.nodeList.add(newNode);
    }

    public boolean addNode(List<String> path, Node newNode) {
        return false;
    }

    public Node getNode(List<String> path) {
        Node result = null;
        if (!path.isEmpty()) {
            String head = head(path);
            try {
                int index = Integer.valueOf(head).intValue();

                if (index >= 0 && index < this.nodeList.size()) {
                    result = this.nodeList.get(index).getNode(tail(path));
                }
            } catch (NumberFormatException e) {
                // TODO: trace e and ignore
            }
        } else {
            result = this;
        }
        return result;
    }

    @Override
    public String toString() {
        StringBuffer result = new StringBuffer();
        result.append('[');
        boolean first = true;
        for (Node n : this.nodeList) {
            if (first == false) {
                result.append(", ");
            }
            result.append(n.toString());
            first = false;
        }
        result.append(']');
        return result.toString();
    }

    /**
     * @inheritDoc
     */
    @Override
    protected String doGetPath(Node childNode) {
        StringBuffer path = new StringBuffer();
        path.append(getPath());
        if (getParent() != null) {
            path.append(',');
        }
        for (int i = 0; i < this.nodeList.size(); i++) {
            if (this.nodeList.get(i) == childNode) {
                path.append(i);
                return path.toString();
            }
        }
        throw new InternalParseException("Child node not found in parent list", null);
    }
}
