/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser.internal;

import com.springsource.json.parser.Node;
import com.springsource.json.parser.ScalarNode;
import com.springsource.json.parser.ScalarNodeType;

/**
 * Represents a number scalar node.
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 * @since 1.0
 */
public final class StandardNumberNode extends AbstractScalarNode implements ScalarNode {

    /**
     * The numeric value is actually captured as a string - it is up to the caller of getValue() to treat it
     * appropriately. This is because it will be used to hold integers and floats.
     */
    private final String value;

    public StandardNumberNode(Node parent, String value) {
        super(parent, ScalarNodeType.Number);
        this.value = value;
    }

    @SuppressWarnings("unchecked")
    public String getValue() {
        return this.value;
    }

    @Override
    public String toString() {
        return this.value.toString();
    }

}
