/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.parser.internal;

import com.springsource.json.parser.Node;
import com.springsource.json.parser.ScalarNode;
import com.springsource.json.parser.ScalarNodeType;

/**
 * Represents a String scalar node.
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 * @since 1.0
 */
public final class StandardStringNode extends AbstractScalarNode implements ScalarNode {

    private final String value;

    public StandardStringNode(Node parent, String value) {
        super(parent, ScalarNodeType.String);
        // strip off any '"' that remain
        if (value.charAt(0) == '"')
            value = value.substring(1, value.length() - 1);
        this.value = value;
    }

    @SuppressWarnings("unchecked")
    public String getValue() {
        return this.value;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // toString() includes the '"' but getValue() does not
        sb.append("\"").append(this.value).append("\"");
        return sb.toString();
    }

}
