/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.validation;

/**
 * Represents a validation problem that occurred whilst validating a JSON format structure against a schema using the
 * JSONValidator.
 * 
 * @author Andy Clement
 * @since 1.0
 */
public class JSONValidationProblem {

    private final ValidationMessages message;

    private final Object[] inserts;

    /**
     * Create a new JSONValidationProblem with the particular message and specified inserts for that message.
     * 
     */
    public JSONValidationProblem(ValidationMessages message, Object... inserts) {
        this.message = message;
        this.inserts = inserts;
    }

    public ValidationMessages getMessage() {
        return message;
    }

    /**
     * @return a formatted form of the message where the inserts have been applied
     */
    @Override
    public String toString() {
        return new StringBuilder().append(message.format(inserts)).toString();
    }
}