/*
 * Copyright 2007-2008 SpringSource Inc.
 */
package com.springsource.json.validation;

import java.text.MessageFormat;

/**
 * Captures all the messages relating to JSON validation.
 * 
 * @author Andy Clement
 * @since 1.0
 */
public enum ValidationMessages {
	
	PROPERTY_SHOULD_BE_UNIQUE(1,"''{0}'': this property should be set only once but has been defined multiple times"),
	INCORRECT_FORMAT_WRONG_TYPE(2,"''{0}'': property value is not valid type for format ''{1}'', expected value to be ''{2}'' but it is ''{3}''"),
	UNRESOLVABLE_REFERENCE(3,"''{0}'': unresolvable reference ''{1}''"),
	EXTENDING_SCHEMA_CANNOT_ADD_NEW_PROPERTIES(4,"''{0}'': cannot extend schema ''{1}'' and define new properties"),
	SCHEMA_REFERENCE_INVALID(5,"''{0}'': extends must specify a valid schema, but found ''{1}''"),
	VALUE_CANNOT_CONVERT_TO_BOOLEAN(6,"''{0}'': cannot convert this property value ''{1}'' of type ''{2}'' to a boolean"),
	VALUE_IS_INCORRECT_TYPE(7,"''{0}'': property value is of incorrect type.  Type was ''{1}'' but expected ''{2}''"),
	INVALID_OPTION_VALUE_SPECIFIED(8,"''{0}'': invalid property value specified ''{1}''.  Options allowed are ''{2}''"), 
	VALUE_CANNOT_CONVERT_TO_INTEGER(9,"''{0}'': cannot convert this property value to an integer ''{1}''"),
	LIST_EXPECTED(10,"''{0}'': expected an array, not a ''{1}''"),
	
	PROPERTY_NOT_ALLOWED(11,"''{0}'':  The property ''{1}'' is not allowed by the schema"),
	PROPERTY_NOT_DEFINED_AND_NOT_OPTIONAL(12,"''{0}'': property is not defined and is not optional"),
	VALUE_TOO_HIGH(13,"''{0}'': value of ''{1}'' specified for the property is higher than maximum allowed ''{2}''"),
	VALUE_TOO_LOW(14,"''{0}'': value of ''{1}'' specified for the property is lower than minimum allowed ''{2}''"),
	VALUE_STRING_TOO_SHORT(15,"''{0}'': the string {1} is too short, the minimum length is ''{2}''"),
	VALUE_STRING_TOO_LONG(16,"''{0}'': the string {1} is too long, the maximum length is ''{2}''"),
	VALUE_LIST_TOO_SHORT(17,"''{0}'': the list value for this property is too short, it contains {1} elements when the minimum is {2}"),
	VALUE_LIST_TOO_LONG(18,"''{0}'': the list value for this property is too long, it contains {1} elements when the maximum is {2}"),
	VALUE_DOES_NOT_MATCH_PATTERN(19,"''{0}'': the property value ''{1}'' does not match the specified regex pattern ''{2}''"),
	VALUE_IS_INCORRECT_FORMAT(20,"''{0}'': invalid format for property value. {1} does not obey the ''{2}'' format"),
	
	TOO_MANY_DECIMAL_PLACES(21,"''{0}'': Value of ''{1}'' uses too many decimal places, maximum is ''{2}'' "),
	VALUE_CANNOT_CONVERT_TO_NUMBER(22,"''{0}'': cannot convert this property value to a number ''{1}''"), 
	OPTIONS_NODE_SHOULD_BE_LIST(23,"''{0}'': options value should be a list, not a ''{1}''"),
	MORE_SPECIFIC_PROPERTY_REQUIRED(24,"''{0}'': when ''{1}'' is specified, the property ''{2}'' must also be specified");
	 
	private int code;
	private String message;
	
	private ValidationMessages(int code,String message) {
		this.code = code;
		this.message = message;
	}
	
	/**
	 * Format a message with the given inserts and return it.
	 * 
	 * @param inserts the inserts to be put into the message
	 * @return a formatted form the of the message where the inserts have been added
	 */
    public String format(Object... inserts) {
        StringBuilder messageText = new StringBuilder();
        messageText.append("Error ").append(code).append(": ");
        messageText.append(MessageFormat.format(this.message, inserts));
        return messageText.toString();
    }
}