/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.validation;

import java.util.StringTokenizer;

/**
 * Custom format checker that can be plugged into the JSONValidator for checking version numbers of the form
 * major.minor.micro.qualifier
 * 
 * @author Andy Clement
 * @since 1.0
 */
public class VersionFormatChecker implements FormatChecker {

    public String getFormat() {
        return "version";
    }

    public boolean isFormatOK(Object data) {
        if (!(data instanceof String))
            return false;
        String theData = (String) data;
        return parseVersion(theData);
    }

    protected boolean parseVersion(String theData) {
        int major = -1;
        int minor = -1;
        int micro = -1;
        String qualifier = null;

        StringTokenizer st = new StringTokenizer(theData, ".");
        try {
            while (st.hasMoreTokens()) {
                String nextbit = st.nextToken();
                if (major == -1 || minor == -1 || micro == -1) {
                    int v = Integer.parseInt(nextbit);
                    if (major == -1)
                        major = v;
                    else if (minor == -1)
                        minor = v;
                    else if (micro == -1)
                        micro = v;
                } else {
                    if (qualifier == null)
                        qualifier = nextbit; // could check it meets requirements of the alphanumeric char set
                                                // allowed
                    else {
                        return false;
                    }
                }
            }
        } catch (NumberFormatException nfe) {
            return false;
        }
        if (major == -1) { // didnt find anything
            return false;
        }
        return true;
    }

}