/*
 * Copyright 2007-2008 SpringSource Inc.
 */

package com.springsource.json.validation;

/**
 * Custom format checker that can be plugged into the JSONValidator to check the format of a version range, eg.
 * [1.0.0,2.0.0)
 * 
 * @author Andy Clement
 * @since 1.0
 */
public class VersionRangeFormatChecker extends VersionFormatChecker {

    @Override
    public String getFormat() {
        return "version-range";
    }

    @Override
    public boolean isFormatOK(Object data) {
        if (!(data instanceof String))
            return false;
        String theData = (String) data;
        return parseVersionRange(theData);
    }

    // "[1.0.0,2.0.0)" [ = inclusive, ) means exclusive.
    // [1,2)
    protected boolean parseVersionRange(String theData) {
        boolean startInclusive = false;
        boolean endInclusive = false;
        if ("[(".indexOf(theData.charAt(0)) == -1) {
            return false;
        }
        startInclusive = theData.charAt(0) == '[';
        if ("])".indexOf(theData.charAt(theData.length() - 1)) == -1) {
            return false;
        }
        endInclusive = theData.charAt(0) == '[';

        int comma = theData.indexOf(",");
        if (comma == -1) {
            return false;
        }
        String minimumVersion = theData.substring(1, comma);
        String maximumVersion = theData.substring(comma + 1, theData.length() - 1);
        if (!parseVersion(minimumVersion))
            return false;
        if (!parseVersion(maximumVersion))
            return false;
        return true;
    }
}
