/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.common.math;

/**
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */

public final class Range<T extends Comparable<? super T>> {

    public static final String FLOOR_INCLUSIVE_DELIMITER = "[";

    public static final String CEILING_INCLUSIVE_DELIMITER = "]";

    public static final String FLOOR_EXCLUSIVE_DELIMITER = "(";

    public static final String CEILING_EXCLUSIVE_DELIMITER = ")";

    public static final String SEPARATOR = ",";

    private final T floor, ceiling;

    private final boolean floorInc, ceilingInc;

    public Range(T floor, boolean floorInc, T ceiling, boolean ceilingInc) {
        if (floor == null || ceiling == null) {
            throw new IllegalArgumentException("Range floor and ceiling must be non-null");
        }
        this.floor = floor;
        this.floorInc = floorInc;
        this.ceiling = ceiling;
        this.ceilingInc = ceilingInc;
    }

    public boolean contains(T t) {
        int minCheck = this.floorInc ? 0 : 1;
        int maxCheck = this.ceilingInc ? 0 : -1;
        return t.compareTo(this.floor) >= minCheck && t.compareTo(this.ceiling) <= maxCheck;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        StringBuffer result = new StringBuffer();
        result.append(this.floorInc ? FLOOR_INCLUSIVE_DELIMITER : FLOOR_EXCLUSIVE_DELIMITER);
        result.append(this.floor.toString());
        result.append(SEPARATOR);
        result.append(this.ceiling.toString());
        result.append(this.ceilingInc ? CEILING_INCLUSIVE_DELIMITER : CEILING_EXCLUSIVE_DELIMITER);
        return result.toString();
    }
}
