/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core;

import java.util.concurrent.Callable;

/**
 * {@link RepeatScheduler} is an interface for scheduling repeating tasks governed by a {@link Ticker}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface RepeatScheduler {

    /**
     * Schedule a call to the given action each time the given ticker ticks.
     * 
     * Any exceptions thrown when the action is called are discarded.
     * 
     * @param ticker the {@link Ticker} to govern when action is called
     * @param action the action to be called
     */
    void schedule(Ticker ticker, Callable<Void> action);

    /**
     * Remove the given ticker and its associated action from the scheduler. If the ticker is not present in the
     * scheduler, do nothing.
     * 
     * @param ticker the {@link Ticker} that was passed to {@link schedule}
     */
    void cancel(Ticker ticker);

}
