/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.accessor;

/**
 * Factory for creating a {@link ThreadLocalAccessor} that is specific to the current execution server. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public final class ThreadLocalAccessorFactory {

    private static final boolean CAN_USE_SUN_ACCESSOR;

    static {
        boolean canUseSun;
        try {
            new SunThreadLocalAccessor();
            canUseSun = true;

        } catch (Exception ex) {
            canUseSun = false;
        }
        CAN_USE_SUN_ACCESSOR = canUseSun;
    }

    /**
     * Creates a {@link ThreadLocalAccessor} that is suitable for the current server.
     * 
     * @return the <code>ThreadLocalAccessor</code>. Never <code>null</code>.
     */
    public static ThreadLocalAccessor newThreadLocalAccessor() {
        if (CAN_USE_SUN_ACCESSOR) {
            return new SunThreadLocalAccessor();
        } else {
            return new NoOpThreadLocalAccessor();
        }
    }
}
