/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.queue;

import java.util.concurrent.BlockingQueue;

/**
 * Simplified version of the <a
 * href="http://java.sun.com/javase/6/docs/api/java/util/concurrent/BlockingDeque.html">BlockingDeque"</a> from Java SE
 * 6+.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Extends the semantics of {@link BlockingQueue}. Poll operations are non-blocking and threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
interface BlockingDeque<T> extends BlockingQueue<T> {

    /**
     * Returns the last item in this deque; returns <code>null</code> if the deque is empty.
     * 
     * @return the tail of this deque, or <code>null</code> if the deque is empty.
     */
    T pollLast();
}
