/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.diagnostics;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * Defines all the {@link LogEvent LogEvents} for the configuration subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementation is immutable.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public enum ConfigLogEvent implements LogEvent {

    INVALID_LIST(0, Level.ERROR), INVALID_MAP(1, Level.ERROR), EXTRA_MAPLET(2, Level.ERROR), MISSING_MAPLET(3, Level.ERROR), INVALID_SCALAR(4,
        Level.ERROR), INVALID_ENUMERATION_VALUE(5, Level.ERROR), INVALID_INTEGER(6, Level.ERROR), INTEGER_OUT_OF_RANGE(7, Level.ERROR), INVALID_VERSION(8,
        Level.ERROR), VERSION_OUT_OF_RANGE(9, Level.ERROR), INVALID_CONFIG_DIRECTORY(10, Level.WARN), UNKNOWN_CONFIG_POINT(11, Level.ERROR), INVALID_CONFIG_FILENAME(12,
        Level.WARN);

    private static final String SUBSYSTEM_NAME = "Config";

    private static final String SUBSYSTEM_CODE = "CO";

    private LogEventDelegate delegate;

    /**
     * Creates a new <code>ConfigLogEvent</code>.
     * 
     * @param code the log event code.
     * @param severity the event severity.
     */
    private ConfigLogEvent(int code, Level level) {
        this.delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, code, level);
    }

    /**
     * {@inheritDoc}
     */
    public String getEventCode() {
        return this.delegate.getEventCode();
    }

    /**
     * {@inheritDoc}
     */
    public Level getLevel() {
        return this.delegate.getLevel();
    }

    /**
     * {@inheritDoc}
     */
    public String getSubsystemName() {
        return this.delegate.getSubsystemName();
    }

    /**
     * Creates a dynamic {@link LogEvent} for this subsystem.
     * 
     * @param code the log event code.
     * @param level the log event level.
     * @return the dynamically-created <code>LogEvent</code>
     */
    public static LogEvent createDynamic(int code, Level level) {
        return new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, code, level) {
        };
    }
}
