/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal;

import java.util.Map;
import java.util.Set;

import com.springsource.server.config.core.ConfigTree;
import com.springsource.server.serviceability.ffdc.DumpExtension;
import com.springsource.server.serviceability.ffdc.DumpWriter.ListWriter;
import com.springsource.server.serviceability.ffdc.DumpWriter.MapWriter;
import com.springsource.server.serviceability.ffdc.DumpWriter.SectionWriter;

/**
 * {@link DumpExtension} for the config subsystem. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Damilola Senbanjo
 * @since 1.0
 */
public class ConfigDumpExtension implements DumpExtension {

    private final StandardConfigTreeFactory configTreeFactory;

    /**
     * Creates a new ConfigDumpExtension
     * 
     * @param configTreeFactory an instance of {@link StandardConfigTreeFactory}
     */
    private ConfigDumpExtension(StandardConfigTreeFactory configTreeFactory) {
        this.configTreeFactory = configTreeFactory;
    }

    /**
     * {@inheritDoc}
     */
    public void dump(SectionWriter sw) {
        Map<String, ConfigTree> treeMap = this.configTreeFactory.getConfigTreesMap();
        ListWriter<SectionWriter> configs = sw.list("Configurations");

        for (Map.Entry<String, ConfigTree> entry : treeMap.entrySet()) {

            ListWriter<MapWriter<ListWriter<SectionWriter>>> configPoints = configs.map().list("configPoints");
            Set<String> configPointNames = entry.getValue().getConfigPointNames();

            for (String name : configPointNames) {
                configPoints.map().scalar("config tree", name).scalar("value", entry.getValue().getConfigPoint(name));
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return this.getClass().getCanonicalName().replace(".core.internal.ConfigDumpExtension", "");
    }
}
