/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal;

import com.springsource.server.config.core.ConfigPoint;
import com.springsource.server.management.proxy.configuration.ConfigPointInfo;

/**
 * 
 * Standard implementation of {@link ConfigPointInfo}.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public final class StandardConfigPointInfo implements ConfigPointInfo {

    private final String fileName;

    private final String nodeName;

    private final String fullfileName;

    private final String nodePath;

    private final String rawConfigPoint;

    public StandardConfigPointInfo(ConfigPoint configPoint, String fileName) {
        this.fullfileName = fileName;
        this.fileName = fileName.substring(fileName.lastIndexOf("/") + 1);
        this.nodeName = configPoint.getName();
        this.nodePath = configPoint.getPath();
        this.rawConfigPoint = configPoint.toString();
    }

    /**
     * 
     * {@inheritDoc}
     */
    public String getShortFileName() {
        return this.fileName;
    }

    /**
     * 
     * {@inheritDoc}
     */
    public String getLongFileName() {
        return this.fullfileName;
    }

    /**
     * 
     * {@inheritDoc}
     */
    public String getNodeName() {
        return this.nodeName;
    }

    /**
     * {@inheritDoc}
     */
    public String getNodePath() {
        return this.nodePath;
    }

    /**
     * {@inheritDoc}
     */
    public String getRawConfigPoint() {
        return this.rawConfigPoint;
    }
}
