/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal;

import java.util.List;

import com.springsource.server.config.core.ConfigNode;
import com.springsource.server.config.core.ScalarConfigNode;

/**
 * Standard implementation of {@link ScalarConfigNode}. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public final class StandardScalarConfigNode extends AbstractConfigNode implements ScalarConfigNode {

    private final Object value;

    /**
     * Creates a new <code>StandardScalarConfigNode</code>.
     * 
     * @param parent the parent {@link ConfigNode}.
     * @param value the node value.
     */
    public StandardScalarConfigNode(ConfigNode parent, Object value) {
        super(parent);
        this.value = value;
    }

    /**
     * {@inheritDoc}
     */
    @SuppressWarnings("unchecked")
    public <T> T getValue() {
        return (T) this.value;
    }

    /**
     * {@inheritDoc}
     */
    public ConfigNode getNode(List<String> path) {
        ConfigNode result = null;
        if (path.isEmpty()) {
            result = this;
        }
        return result;
    }

    /**
     * {@inheritDoc}
     */
    public boolean addNode(List<String> path, ConfigNode newNode) {
        return false;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return this.value.toString();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected String doGetPath(ConfigNode childNode) {
        return null;
    }

}
