/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal.validate;

import java.io.IOException;
import java.net.URL;

import org.antlr.runtime.ANTLRInputStream;
import org.antlr.runtime.CommonTokenStream;
import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.tree.Tree;

import com.springsource.server.config.core.FatalConfigurationException;
import com.springsource.server.config.core.internal.validate.EngineConfigPointSchemaParser.configPointSchema_return;

/**
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public final class AntlrConfigPointSchemaParser implements ConfigPointSchemaParser {

    /** 
     * {@inheritDoc}
     */
    public Tree parseConfigPointSchema(URL configSchemaURL) {
        EngineConfigPointSchemaParser parser = createParser(configSchemaURL);
        try {
            configPointSchema_return result = parser.configPointSchema();
            return (Tree) result.getTree();
        } catch (RecognitionException e) {
            throw new FatalConfigurationException("Engine configuration point schema file does not parse", e);
        }
    }

    /**
     * Create a parser for the given configuration point schema file.
     * 
     * @param configFileURL the configuration point schema file
     * @return an {@link EngineConfigPointSchemaParser} for the schema file
     */
    private EngineConfigPointSchemaParser createParser(URL configFileURL) {
        if (configFileURL == null) {
            throw new FatalConfigurationException("Null configuration file URL encountered.", null);
        }
        ANTLRInputStream stream = null;
        try {
            stream = new ANTLRInputStream(configFileURL.openStream());
        } catch (IOException e) {
            throw new FatalConfigurationException("Engine configuration point schema inaccessible", e);
        }
        EngineConfigPointSchemaLexer lexer = new EngineConfigPointSchemaLexer(stream);
        CommonTokenStream tokenStream = new CommonTokenStream(lexer);
        EngineConfigPointSchemaParser parser = new EngineConfigPointSchemaParser(tokenStream);
        return parser;
    }

}
