/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal.validate;

import com.springsource.server.config.core.ConfigNode;

/**
 * {@link ConfigValidator} is an interface for validating configuration point nodes.
 * 
 *  <strong>Concurrent Semantics</strong><br />
 *  
 * Implementations of this interface are thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface ConfigValidator {

    /**
     * Validate the given configuration node.
     * 
     * @param configNode the {@link ConfigNode} to be validated
     * @return <code>true</code> if and only if the configuration node is valid
     */
    boolean validate(ConfigNode configNode);

}
