/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal.validate;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.Stack;

import org.antlr.runtime.BitSet;
import org.antlr.runtime.EarlyExitException;
import org.antlr.runtime.NoViableAltException;
import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.Token;
import org.antlr.runtime.tree.CommonTree;
import org.antlr.runtime.tree.TreeNodeStream;
import org.antlr.runtime.tree.TreeParser;

import com.springsource.server.common.math.Range;
import com.springsource.server.common.math.Version;

public class EngineConfigPointSchemaWalker extends TreeParser {

    public static final String[] tokenNames = new String[] { "<invalid>", "<EOR>", "<DOWN>", "<UP>", "ConfigPointSchema", "MAPSCHEMA",
        "MAPLETSCHEMA", "LISTSCHEMA", "KEY", "STRINGSCHEMA", "ANYSTRING", "ENUM", "INTEGER", "INTEGERRANGE", "INTGE", "INTG", "INTLE", "INTL",
        "SIGNED", "NEGATIVE", "POSITIVE", "VERSION", "VERSIONRANGE", "VERSIONVALUE", "VERGE", "VERG", "VERLE", "VERL", "IDENTIFIER", "ALPHA",
        "DIGIT", "NUMBER", "COMMENT", "LINE_COMMENT", "WS", "':'", "'{'", "','", "'}'", "'['", "']'", "'String'", "'string'", "'Enumeration'",
        "'enumeration'", "'Int'", "'int'", "'-'", "'('", "')'", "'versionNumber'", "'VersionNumber'", "'.'" };

    public static final int ANYSTRING = 10;

    public static final int VERG = 25;

    public static final int NUMBER = 31;

    public static final int WS = 34;

    public static final int ALPHA = 29;

    public static final int COMMENT = 32;

    public static final int LINE_COMMENT = 33;

    public static final int NEGATIVE = 19;

    public static final int INTEGERRANGE = 13;

    public static final int ConfigPointSchema = 4;

    public static final int MAPSCHEMA = 5;

    public static final int VERSIONRANGE = 22;

    public static final int VERLE = 26;

    public static final int INTEGER = 12;

    public static final int STRINGSCHEMA = 9;

    public static final int INTLE = 16;

    public static final int INTL = 17;

    public static final int KEY = 8;

    public static final int EOF = -1;

    public static final int MAPLETSCHEMA = 6;

    public static final int VERSION = 21;

    public static final int INTG = 15;

    public static final int LISTSCHEMA = 7;

    public static final int SIGNED = 18;

    public static final int DIGIT = 30;

    public static final int IDENTIFIER = 28;

    public static final int INTGE = 14;

    public static final int POSITIVE = 20;

    public static final int VERGE = 24;

    public static final int VERL = 27;

    public static final int VERSIONVALUE = 23;

    public static final int ENUM = 11;

    public EngineConfigPointSchemaWalker(TreeNodeStream input) {
        super(input);
    }

    @Override public String[] getTokenNames() {
        return tokenNames;
    }

    @Override public String getGrammarFileName() {
        return "/Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g";
    }

    private String configPointName;

    private ConfigValidator configPointValidator;

    // Stacks are used to hold the last of various kinds of nodes but should never be more than one element deep.
    Stack<ConfigValidator> configurationSchemaStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> mapStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> listStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> valueStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> stringStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> anyStringStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> enumerationStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> integerStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> integerRangeStack = new Stack<ConfigValidator>();

    Stack<ConfigValidator> versionStack = new Stack<ConfigValidator>();

    Stack<Version> versionValueStack = new Stack<Version>();

    Stack<ConfigValidator> versionRangeStack = new Stack<ConfigValidator>();

    public String getConfigPointName() {
        return this.configPointName;
    }

    public ConfigValidator getConfigPointValidator() {
        return this.configPointValidator;
    }

    protected static class configPointSchema_scope {

        String configPointName;

        ConfigValidator configPointValidator;
    }

    protected Stack<configPointSchema_scope> configPointSchema_stack = new Stack<configPointSchema_scope>();

    // $ANTLR start configPointSchema
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:46:1:
    // configPointSchema : ^( ConfigPointSchema IDENTIFIER configurationSchema ) ;
    public final void configPointSchema() throws RecognitionException {
        this.configPointSchema_stack.push(new configPointSchema_scope());
        CommonTree IDENTIFIER1 = null;

        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:55:2:
            // ( ^( ConfigPointSchema IDENTIFIER configurationSchema ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:55:4:
            // ^( ConfigPointSchema IDENTIFIER configurationSchema )
            {
                match(this.input, ConfigPointSchema, FOLLOW_ConfigPointSchema_in_configPointSchema59);

                match(this.input, Token.DOWN, null);
                IDENTIFIER1 = (CommonTree) this.input.LT(1);
                match(this.input, IDENTIFIER, FOLLOW_IDENTIFIER_in_configPointSchema62);
                (this.configPointSchema_stack.peek()).configPointName = IDENTIFIER1.getText();
                pushFollow(FOLLOW_configurationSchema_in_configPointSchema71);
                configurationSchema();
                this._fsp--;

                (this.configPointSchema_stack.peek()).configPointValidator = this.configurationSchemaStack.pop();

                match(this.input, Token.UP, null);

            }

            this.configPointName = (this.configPointSchema_stack.peek()).configPointName;
            this.configPointValidator = (this.configPointSchema_stack.peek()).configPointValidator;

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
            this.configPointSchema_stack.pop();
        }
        return;
    }

    // $ANTLR end configPointSchema

    // $ANTLR start configurationSchema
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:60:1:
    // configurationSchema : ( mapSchema | listSchema );
    public final void configurationSchema() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:61:2:
            // ( mapSchema | listSchema )
            int alt1 = 2;
            int LA1_0 = this.input.LA(1);

            if (LA1_0 == MAPSCHEMA) {
                alt1 = 1;
            } else if (LA1_0 == LISTSCHEMA) {
                alt1 = 2;
            } else {
                NoViableAltException nvae = new NoViableAltException("60:1: configurationSchema : ( mapSchema | listSchema );", 1, 0, this.input);

                throw nvae;
            }
            switch (alt1) {
                case 1:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:61:4:
                    // mapSchema
                {
                    pushFollow(FOLLOW_mapSchema_in_configurationSchema91);
                    mapSchema();
                    this._fsp--;

                    this.configurationSchemaStack.push(this.mapStack.pop());

                }
                    break;
                case 2:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:61:67:
                    // listSchema
                {
                    pushFollow(FOLLOW_listSchema_in_configurationSchema97);
                    listSchema();
                    this._fsp--;

                    this.configurationSchemaStack.push(this.listStack.pop());

                }
                    break;

            }
        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end configurationSchema

    protected static class mapSchema_scope {

        Map<String, ConfigValidator> validatorMap;
    }

    protected Stack<mapSchema_scope> mapSchema_stack = new Stack<mapSchema_scope>();

    // $ANTLR start mapSchema
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:64:1:
    // mapSchema : ^( MAPSCHEMA ( mapletSchema )+ ) ;
    public final void mapSchema() throws RecognitionException {
        this.mapSchema_stack.push(new mapSchema_scope());

        (this.mapSchema_stack.peek()).validatorMap = new HashMap<String, ConfigValidator>();

        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:74:2:
            // ( ^( MAPSCHEMA ( mapletSchema )+ ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:74:4:
            // ^( MAPSCHEMA ( mapletSchema )+ )
            {
                match(this.input, MAPSCHEMA, FOLLOW_MAPSCHEMA_in_mapSchema127);

                match(this.input, Token.DOWN, null);
                // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:74:17:
                // ( mapletSchema )+
                int cnt2 = 0;
                loop2: do {
                    int alt2 = 2;
                    int LA2_0 = this.input.LA(1);

                    if (LA2_0 == MAPLETSCHEMA) {
                        alt2 = 1;
                    }

                    switch (alt2) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:74:17:
                            // mapletSchema
                        {
                            pushFollow(FOLLOW_mapletSchema_in_mapSchema129);
                            mapletSchema();
                            this._fsp--;

                        }
                            break;

                        default:
                            if (cnt2 >= 1) {
                                break loop2;
                            }
                            EarlyExitException eee = new EarlyExitException(2, this.input);
                            throw eee;
                    }
                    cnt2++;
                } while (true);

                match(this.input, Token.UP, null);

            }

            this.mapStack.push(new StandardMapConfigNodeValidator((this.mapSchema_stack.peek()).validatorMap));

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
            this.mapSchema_stack.pop();
        }
        return;
    }

    // $ANTLR end mapSchema

    protected static class mapletSchema_scope {

        String key;

        ConfigValidator valueValidator;
    }

    protected Stack<mapletSchema_scope> mapletSchema_stack = new Stack<mapletSchema_scope>();

    // $ANTLR start mapletSchema
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:77:1:
    // mapletSchema : ^( MAPLETSCHEMA key valueSchema ) ;
    public final void mapletSchema() throws RecognitionException {
        this.mapletSchema_stack.push(new mapletSchema_scope());
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:85:2:
            // ( ^( MAPLETSCHEMA key valueSchema ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:85:4:
            // ^( MAPLETSCHEMA key valueSchema )
            {
                match(this.input, MAPLETSCHEMA, FOLLOW_MAPLETSCHEMA_in_mapletSchema154);

                match(this.input, Token.DOWN, null);
                pushFollow(FOLLOW_key_in_mapletSchema156);
                key();
                this._fsp--;

                pushFollow(FOLLOW_valueSchema_in_mapletSchema158);
                valueSchema();
                this._fsp--;

                (this.mapletSchema_stack.peek()).valueValidator = this.valueStack.pop();

                match(this.input, Token.UP, null);

            }

            (this.mapSchema_stack.peek()).validatorMap.put((this.mapletSchema_stack.peek()).key, (this.mapletSchema_stack.peek()).valueValidator);

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
            this.mapletSchema_stack.pop();
        }
        return;
    }

    // $ANTLR end mapletSchema

    // $ANTLR start valueSchema
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:88:1:
    // valueSchema : ( stringSchema | configurationSchema );
    public final void valueSchema() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:89:2:
            // ( stringSchema | configurationSchema )
            int alt3 = 2;
            int LA3_0 = this.input.LA(1);

            if (LA3_0 == STRINGSCHEMA) {
                alt3 = 1;
            } else if (LA3_0 == MAPSCHEMA || LA3_0 == LISTSCHEMA) {
                alt3 = 2;
            } else {
                NoViableAltException nvae = new NoViableAltException("88:1: valueSchema : ( stringSchema | configurationSchema );", 3, 0, this.input);

                throw nvae;
            }
            switch (alt3) {
                case 1:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:89:4:
                    // stringSchema
                {
                    pushFollow(FOLLOW_stringSchema_in_valueSchema173);
                    stringSchema();
                    this._fsp--;

                    this.valueStack.push(this.stringStack.pop());

                }
                    break;
                case 2:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:89:59:
                    // configurationSchema
                {
                    pushFollow(FOLLOW_configurationSchema_in_valueSchema179);
                    configurationSchema();
                    this._fsp--;

                    this.valueStack.push(this.configurationSchemaStack.pop());

                }
                    break;

            }
        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end valueSchema

    // $ANTLR start listSchema
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:92:1:
    // listSchema : ^( LISTSCHEMA valueSchema ) ;
    public final void listSchema() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:96:2:
            // ( ^( LISTSCHEMA valueSchema ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:96:5:
            // ^( LISTSCHEMA valueSchema )
            {
                match(this.input, LISTSCHEMA, FOLLOW_LISTSCHEMA_in_listSchema200);

                match(this.input, Token.DOWN, null);
                pushFollow(FOLLOW_valueSchema_in_listSchema202);
                valueSchema();
                this._fsp--;

                match(this.input, Token.UP, null);

            }

            this.listStack.push(new StandardListConfigNodeValidator(this.valueStack.pop()));

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end listSchema

    // $ANTLR start key
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:99:1:
    // key : ^( KEY IDENTIFIER ) ;
    public final void key() throws RecognitionException {
        CommonTree IDENTIFIER2 = null;

        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:99:5:
            // ( ^( KEY IDENTIFIER ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:99:8:
            // ^( KEY IDENTIFIER )
            {
                match(this.input, KEY, FOLLOW_KEY_in_key218);

                match(this.input, Token.DOWN, null);
                IDENTIFIER2 = (CommonTree) this.input.LT(1);
                match(this.input, IDENTIFIER, FOLLOW_IDENTIFIER_in_key220);

                match(this.input, Token.UP, null);
                (this.mapletSchema_stack.peek()).key = IDENTIFIER2.getText();

            }

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end key

    // $ANTLR start stringSchema
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:103:1:
    // stringSchema : ^( STRINGSCHEMA ( anyString )? ( enumeration )? ( integer )? ( integerRange )? ( version )? (
    // versionRange )? ) ;
    public final void stringSchema() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:103:15:
            // ( ^( STRINGSCHEMA ( anyString )? ( enumeration )? ( integer )? ( integerRange )? ( version )? (
            // versionRange )? ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:103:17:
            // ^( STRINGSCHEMA ( anyString )? ( enumeration )? ( integer )? ( integerRange )? ( version )? (
            // versionRange )? )
            {
                match(this.input, STRINGSCHEMA, FOLLOW_STRINGSCHEMA_in_stringSchema242);

                if (this.input.LA(1) == Token.DOWN) {
                    match(this.input, Token.DOWN, null);
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:103:34:
                    // ( anyString )?
                    int alt4 = 2;
                    int LA4_0 = this.input.LA(1);

                    if (LA4_0 == ANYSTRING) {
                        alt4 = 1;
                    }
                    switch (alt4) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:103:36:
                            // anyString
                        {
                            pushFollow(FOLLOW_anyString_in_stringSchema247);
                            anyString();
                            this._fsp--;

                            this.stringStack.push(this.anyStringStack.pop());

                        }
                            break;

                    }

                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:104:10:
                    // ( enumeration )?
                    int alt5 = 2;
                    int LA5_0 = this.input.LA(1);

                    if (LA5_0 == ENUM) {
                        alt5 = 1;
                    }
                    switch (alt5) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:104:12:
                            // enumeration
                        {
                            pushFollow(FOLLOW_enumeration_in_stringSchema266);
                            enumeration();
                            this._fsp--;

                            this.stringStack.push(this.enumerationStack.pop());

                        }
                            break;

                    }

                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:105:10:
                    // ( integer )?
                    int alt6 = 2;
                    int LA6_0 = this.input.LA(1);

                    if (LA6_0 == INTEGER) {
                        alt6 = 1;
                    }
                    switch (alt6) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:105:12:
                            // integer
                        {
                            pushFollow(FOLLOW_integer_in_stringSchema286);
                            integer();
                            this._fsp--;

                            this.stringStack.push(this.integerStack.pop());

                        }
                            break;

                    }

                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:106:10:
                    // ( integerRange )?
                    int alt7 = 2;
                    int LA7_0 = this.input.LA(1);

                    if (LA7_0 == INTEGERRANGE) {
                        alt7 = 1;
                    }
                    switch (alt7) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:106:12:
                            // integerRange
                        {
                            pushFollow(FOLLOW_integerRange_in_stringSchema305);
                            integerRange();
                            this._fsp--;

                            this.stringStack.push(this.integerRangeStack.pop());

                        }
                            break;

                    }

                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:107:10:
                    // ( version )?
                    int alt8 = 2;
                    int LA8_0 = this.input.LA(1);

                    if (LA8_0 == VERSION) {
                        alt8 = 1;
                    }
                    switch (alt8) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:107:12:
                            // version
                        {
                            pushFollow(FOLLOW_version_in_stringSchema324);
                            version();
                            this._fsp--;

                            this.stringStack.push(this.versionStack.pop());

                        }
                            break;

                    }

                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:108:10:
                    // ( versionRange )?
                    int alt9 = 2;
                    int LA9_0 = this.input.LA(1);

                    if (LA9_0 == VERSIONRANGE) {
                        alt9 = 1;
                    }
                    switch (alt9) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:108:12:
                            // versionRange
                        {
                            pushFollow(FOLLOW_versionRange_in_stringSchema343);
                            versionRange();
                            this._fsp--;

                            this.stringStack.push(this.versionRangeStack.pop());

                        }
                            break;

                    }

                    match(this.input, Token.UP, null);
                }

            }

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end stringSchema

    // $ANTLR start anyString
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:112:1:
    // anyString : ANYSTRING ;
    public final void anyString() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:112:11:
            // ( ANYSTRING )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:112:13:
            // ANYSTRING
            {
                match(this.input, ANYSTRING, FOLLOW_ANYSTRING_in_anyString367);
                this.anyStringStack.push(new StandardScalarConfigNodeValidator());

            }

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end anyString

    protected static class enumeration_scope {

        Set<String> values;
    }

    protected Stack<enumeration_scope> enumeration_stack = new Stack<enumeration_scope>();

    // $ANTLR start enumeration
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:116:1:
    // enumeration : ^( ENUM ( IDENTIFIER )+ ) ;
    public final void enumeration() throws RecognitionException {
        this.enumeration_stack.push(new enumeration_scope());
        CommonTree IDENTIFIER3 = null;

        (this.enumeration_stack.peek()).values = new HashSet<String>();

        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:126:2:
            // ( ^( ENUM ( IDENTIFIER )+ ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:126:4:
            // ^( ENUM ( IDENTIFIER )+ )
            {
                match(this.input, ENUM, FOLLOW_ENUM_in_enumeration400);

                match(this.input, Token.DOWN, null);
                // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:126:12:
                // ( IDENTIFIER )+
                int cnt10 = 0;
                loop10: do {
                    int alt10 = 2;
                    int LA10_0 = this.input.LA(1);

                    if (LA10_0 == IDENTIFIER) {
                        alt10 = 1;
                    }

                    switch (alt10) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:126:14:
                            // IDENTIFIER
                        {
                            IDENTIFIER3 = (CommonTree) this.input.LT(1);
                            match(this.input, IDENTIFIER, FOLLOW_IDENTIFIER_in_enumeration404);
                            (this.enumeration_stack.peek()).values.add(IDENTIFIER3.getText());

                        }
                            break;

                        default:
                            if (cnt10 >= 1) {
                                break loop10;
                            }
                            EarlyExitException eee = new EarlyExitException(10, this.input);
                            throw eee;
                    }
                    cnt10++;
                } while (true);

                match(this.input, Token.UP, null);

            }

            this.enumerationStack.push(new StandardEnumerationConfigNodeValidator((this.enumeration_stack.peek()).values));

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
            this.enumeration_stack.pop();
        }
        return;
    }

    // $ANTLR end enumeration

    // $ANTLR start integer
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:129:1:
    // integer : INTEGER ;
    public final void integer() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:129:9:
            // ( INTEGER )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:129:11:
            // INTEGER
            {
                match(this.input, INTEGER, FOLLOW_INTEGER_in_integer422);
                this.integerStack.push(new StandardIntegerConfigNodeValidator());

            }

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end integer

    protected static class integerRange_scope {

        int floor;

        boolean floorInc;

        int ceiling;

        boolean ceilingInc;
    }

    protected Stack<integerRange_scope> integerRange_stack = new Stack<integerRange_scope>();

    // $ANTLR start integerRange
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:132:1:
    // integerRange : ^( INTEGERRANGE integerRangeStart integerRangeEnd ) ;
    public final void integerRange() throws RecognitionException {
        this.integerRange_stack.push(new integerRange_scope());
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:143:2:
            // ( ^( INTEGERRANGE integerRangeStart integerRangeEnd ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:143:4:
            // ^( INTEGERRANGE integerRangeStart integerRangeEnd )
            {
                match(this.input, INTEGERRANGE, FOLLOW_INTEGERRANGE_in_integerRange448);

                match(this.input, Token.DOWN, null);
                pushFollow(FOLLOW_integerRangeStart_in_integerRange450);
                integerRangeStart();
                this._fsp--;

                pushFollow(FOLLOW_integerRangeEnd_in_integerRange452);
                integerRangeEnd();
                this._fsp--;

                match(this.input, Token.UP, null);

            }

            this.integerRangeStack.push(new StandardIntegerRangeConfigNodeValidator(new Range<Integer>((this.integerRange_stack.peek()).floor,
                (this.integerRange_stack.peek()).floorInc, (this.integerRange_stack.peek()).ceiling, (this.integerRange_stack.peek()).ceilingInc)));

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
            this.integerRange_stack.pop();
        }
        return;
    }

    // $ANTLR end integerRange

    // $ANTLR start integerRangeStart
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:146:1:
    // integerRangeStart : ( ^( INTGE NUMBER ( POSITIVE | NEGATIVE ) ) | ^( INTG NUMBER ( POSITIVE | NEGATIVE ) ) );
    public final void integerRangeStart() throws RecognitionException {
        CommonTree NUMBER4 = null;
        CommonTree NUMBER5 = null;

        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:146:19:
            // ( ^( INTGE NUMBER ( POSITIVE | NEGATIVE ) ) | ^( INTG NUMBER ( POSITIVE | NEGATIVE ) ) )
            int alt13 = 2;
            int LA13_0 = this.input.LA(1);

            if (LA13_0 == INTGE) {
                alt13 = 1;
            } else if (LA13_0 == INTG) {
                alt13 = 2;
            } else {
                NoViableAltException nvae = new NoViableAltException(
                    "146:1: integerRangeStart : ( ^( INTGE NUMBER ( POSITIVE | NEGATIVE ) ) | ^( INTG NUMBER ( POSITIVE | NEGATIVE ) ) );", 13, 0,
                    this.input);

                throw nvae;
            }
            switch (alt13) {
                case 1:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:146:22:
                    // ^( INTGE NUMBER ( POSITIVE | NEGATIVE ) )
                {
                    match(this.input, INTGE, FOLLOW_INTGE_in_integerRangeStart467);

                    match(this.input, Token.DOWN, null);
                    NUMBER4 = (CommonTree) this.input.LT(1);
                    match(this.input, NUMBER, FOLLOW_NUMBER_in_integerRangeStart469);
                    (this.integerRange_stack.peek()).floor = Integer.parseInt(NUMBER4.getText());
                    (this.integerRange_stack.peek()).floorInc = true;
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:146:129:
                    // ( POSITIVE | NEGATIVE )
                    int alt11 = 2;
                    int LA11_0 = this.input.LA(1);

                    if (LA11_0 == POSITIVE) {
                        alt11 = 1;
                    } else if (LA11_0 == NEGATIVE) {
                        alt11 = 2;
                    } else {
                        NoViableAltException nvae = new NoViableAltException("146:129: ( POSITIVE | NEGATIVE )", 11, 0, this.input);

                        throw nvae;
                    }
                    switch (alt11) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:146:130:
                            // POSITIVE
                        {
                            match(this.input, POSITIVE, FOLLOW_POSITIVE_in_integerRangeStart474);

                        }
                            break;
                        case 2:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:146:141:
                            // NEGATIVE
                        {
                            match(this.input, NEGATIVE, FOLLOW_NEGATIVE_in_integerRangeStart478);
                            (this.integerRange_stack.peek()).floor = -(this.integerRange_stack.peek()).floor;

                        }
                            break;

                    }

                    match(this.input, Token.UP, null);

                }
                    break;
                case 2:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:147:4:
                    // ^( INTG NUMBER ( POSITIVE | NEGATIVE ) )
                {
                    match(this.input, INTG, FOLLOW_INTG_in_integerRangeStart492);

                    match(this.input, Token.DOWN, null);
                    NUMBER5 = (CommonTree) this.input.LT(1);
                    match(this.input, NUMBER, FOLLOW_NUMBER_in_integerRangeStart494);
                    (this.integerRange_stack.peek()).floor = Integer.parseInt(NUMBER5.getText());
                    (this.integerRange_stack.peek()).floorInc = false;
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:147:111:
                    // ( POSITIVE | NEGATIVE )
                    int alt12 = 2;
                    int LA12_0 = this.input.LA(1);

                    if (LA12_0 == POSITIVE) {
                        alt12 = 1;
                    } else if (LA12_0 == NEGATIVE) {
                        alt12 = 2;
                    } else {
                        NoViableAltException nvae = new NoViableAltException("147:111: ( POSITIVE | NEGATIVE )", 12, 0, this.input);

                        throw nvae;
                    }
                    switch (alt12) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:147:112:
                            // POSITIVE
                        {
                            match(this.input, POSITIVE, FOLLOW_POSITIVE_in_integerRangeStart499);

                        }
                            break;
                        case 2:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:147:123:
                            // NEGATIVE
                        {
                            match(this.input, NEGATIVE, FOLLOW_NEGATIVE_in_integerRangeStart503);
                            (this.integerRange_stack.peek()).floor = -(this.integerRange_stack.peek()).floor;

                        }
                            break;

                    }

                    match(this.input, Token.UP, null);

                }
                    break;

            }
        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end integerRangeStart

    // $ANTLR start integerRangeEnd
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:150:1:
    // integerRangeEnd : ( ^( INTLE NUMBER ( POSITIVE | NEGATIVE ) ) | ^( INTL NUMBER ( POSITIVE | NEGATIVE ) ) );
    public final void integerRangeEnd() throws RecognitionException {
        CommonTree NUMBER6 = null;
        CommonTree NUMBER7 = null;

        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:150:17:
            // ( ^( INTLE NUMBER ( POSITIVE | NEGATIVE ) ) | ^( INTL NUMBER ( POSITIVE | NEGATIVE ) ) )
            int alt16 = 2;
            int LA16_0 = this.input.LA(1);

            if (LA16_0 == INTLE) {
                alt16 = 1;
            } else if (LA16_0 == INTL) {
                alt16 = 2;
            } else {
                NoViableAltException nvae = new NoViableAltException(
                    "150:1: integerRangeEnd : ( ^( INTLE NUMBER ( POSITIVE | NEGATIVE ) ) | ^( INTL NUMBER ( POSITIVE | NEGATIVE ) ) );", 16, 0,
                    this.input);

                throw nvae;
            }
            switch (alt16) {
                case 1:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:150:20:
                    // ^( INTLE NUMBER ( POSITIVE | NEGATIVE ) )
                {
                    match(this.input, INTLE, FOLLOW_INTLE_in_integerRangeEnd521);

                    match(this.input, Token.DOWN, null);
                    NUMBER6 = (CommonTree) this.input.LT(1);
                    match(this.input, NUMBER, FOLLOW_NUMBER_in_integerRangeEnd523);
                    (this.integerRange_stack.peek()).ceiling = Integer.parseInt(NUMBER6.getText());
                    (this.integerRange_stack.peek()).ceilingInc = true;
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:150:131:
                    // ( POSITIVE | NEGATIVE )
                    int alt14 = 2;
                    int LA14_0 = this.input.LA(1);

                    if (LA14_0 == POSITIVE) {
                        alt14 = 1;
                    } else if (LA14_0 == NEGATIVE) {
                        alt14 = 2;
                    } else {
                        NoViableAltException nvae = new NoViableAltException("150:131: ( POSITIVE | NEGATIVE )", 14, 0, this.input);

                        throw nvae;
                    }
                    switch (alt14) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:150:132:
                            // POSITIVE
                        {
                            match(this.input, POSITIVE, FOLLOW_POSITIVE_in_integerRangeEnd528);

                        }
                            break;
                        case 2:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:150:143:
                            // NEGATIVE
                        {
                            match(this.input, NEGATIVE, FOLLOW_NEGATIVE_in_integerRangeEnd532);
                            (this.integerRange_stack.peek()).ceiling = -(this.integerRange_stack.peek()).ceiling;

                        }
                            break;

                    }

                    match(this.input, Token.UP, null);

                }
                    break;
                case 2:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:151:4:
                    // ^( INTL NUMBER ( POSITIVE | NEGATIVE ) )
                {
                    match(this.input, INTL, FOLLOW_INTL_in_integerRangeEnd546);

                    match(this.input, Token.DOWN, null);
                    NUMBER7 = (CommonTree) this.input.LT(1);
                    match(this.input, NUMBER, FOLLOW_NUMBER_in_integerRangeEnd548);
                    (this.integerRange_stack.peek()).ceiling = Integer.parseInt(NUMBER7.getText());
                    (this.integerRange_stack.peek()).ceilingInc = false;
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:151:115:
                    // ( POSITIVE | NEGATIVE )
                    int alt15 = 2;
                    int LA15_0 = this.input.LA(1);

                    if (LA15_0 == POSITIVE) {
                        alt15 = 1;
                    } else if (LA15_0 == NEGATIVE) {
                        alt15 = 2;
                    } else {
                        NoViableAltException nvae = new NoViableAltException("151:115: ( POSITIVE | NEGATIVE )", 15, 0, this.input);

                        throw nvae;
                    }
                    switch (alt15) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:151:116:
                            // POSITIVE
                        {
                            match(this.input, POSITIVE, FOLLOW_POSITIVE_in_integerRangeEnd553);

                        }
                            break;
                        case 2:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:151:127:
                            // NEGATIVE
                        {
                            match(this.input, NEGATIVE, FOLLOW_NEGATIVE_in_integerRangeEnd557);
                            (this.integerRange_stack.peek()).ceiling = -(this.integerRange_stack.peek()).ceiling;

                        }
                            break;

                    }

                    match(this.input, Token.UP, null);

                }
                    break;

            }
        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end integerRangeEnd

    // $ANTLR start version
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:154:1:
    // version : VERSION ;
    public final void version() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:154:9:
            // ( VERSION )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:154:11:
            // VERSION
            {
                match(this.input, VERSION, FOLLOW_VERSION_in_version573);
                this.versionStack.push(new StandardVersionConfigNodeValidator());

            }

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end version

    protected static class versionValue_scope {

        List<Integer> components;
    }

    protected Stack<versionValue_scope> versionValue_stack = new Stack<versionValue_scope>();

    // $ANTLR start versionValue
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:157:1:
    // versionValue : ^( VERSIONVALUE ( NUMBER )+ ) ;
    public final void versionValue() throws RecognitionException {
        this.versionValue_stack.push(new versionValue_scope());
        CommonTree NUMBER8 = null;

        (this.versionValue_stack.peek()).components = new ArrayList<Integer>();

        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:167:2:
            // ( ^( VERSIONVALUE ( NUMBER )+ ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:167:4:
            // ^( VERSIONVALUE ( NUMBER )+ )
            {
                match(this.input, VERSIONVALUE, FOLLOW_VERSIONVALUE_in_versionValue603);

                match(this.input, Token.DOWN, null);
                // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:167:20:
                // ( NUMBER )+
                int cnt17 = 0;
                loop17: do {
                    int alt17 = 2;
                    int LA17_0 = this.input.LA(1);

                    if (LA17_0 == NUMBER) {
                        alt17 = 1;
                    }

                    switch (alt17) {
                        case 1:
                            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:167:22:
                            // NUMBER
                        {
                            NUMBER8 = (CommonTree) this.input.LT(1);
                            match(this.input, NUMBER, FOLLOW_NUMBER_in_versionValue607);
                            (this.versionValue_stack.peek()).components.add(Integer.parseInt(NUMBER8.getText()));

                        }
                            break;

                        default:
                            if (cnt17 >= 1) {
                                break loop17;
                            }
                            EarlyExitException eee = new EarlyExitException(17, this.input);
                            throw eee;
                    }
                    cnt17++;
                } while (true);

                match(this.input, Token.UP, null);

            }

            this.versionValueStack.push(new Version((this.versionValue_stack.peek()).components));

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
            this.versionValue_stack.pop();
        }
        return;
    }

    // $ANTLR end versionValue

    protected static class versionRange_scope {

        Version floor;

        boolean floorInc;

        Version ceiling;

        boolean ceilingInc;
    }

    protected Stack<versionRange_scope> versionRange_stack = new Stack<versionRange_scope>();

    // $ANTLR start versionRange
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:170:1:
    // versionRange : ^( VERSIONRANGE versionRangeStart versionRangeEnd ) ;
    public final void versionRange() throws RecognitionException {
        this.versionRange_stack.push(new versionRange_scope());
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:181:2:
            // ( ^( VERSIONRANGE versionRangeStart versionRangeEnd ) )
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:181:4:
            // ^( VERSIONRANGE versionRangeStart versionRangeEnd )
            {
                match(this.input, VERSIONRANGE, FOLLOW_VERSIONRANGE_in_versionRange638);

                match(this.input, Token.DOWN, null);
                pushFollow(FOLLOW_versionRangeStart_in_versionRange640);
                versionRangeStart();
                this._fsp--;

                pushFollow(FOLLOW_versionRangeEnd_in_versionRange642);
                versionRangeEnd();
                this._fsp--;

                match(this.input, Token.UP, null);

            }

            this.versionRangeStack.push(new StandardVersionRangeConfigNodeValidator(new Range<Version>((this.versionRange_stack.peek()).floor,
                (this.versionRange_stack.peek()).floorInc, (this.versionRange_stack.peek()).ceiling, (this.versionRange_stack.peek()).ceilingInc)));

        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
            this.versionRange_stack.pop();
        }
        return;
    }

    // $ANTLR end versionRange

    // $ANTLR start versionRangeStart
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:184:1:
    // versionRangeStart : ( ^( VERGE versionValue ) | ^( VERG versionValue ) );
    public final void versionRangeStart() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:184:19:
            // ( ^( VERGE versionValue ) | ^( VERG versionValue ) )
            int alt18 = 2;
            int LA18_0 = this.input.LA(1);

            if (LA18_0 == VERGE) {
                alt18 = 1;
            } else if (LA18_0 == VERG) {
                alt18 = 2;
            } else {
                NoViableAltException nvae = new NoViableAltException(
                    "184:1: versionRangeStart : ( ^( VERGE versionValue ) | ^( VERG versionValue ) );", 18, 0, this.input);

                throw nvae;
            }
            switch (alt18) {
                case 1:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:184:22:
                    // ^( VERGE versionValue )
                {
                    match(this.input, VERGE, FOLLOW_VERGE_in_versionRangeStart657);

                    match(this.input, Token.DOWN, null);
                    pushFollow(FOLLOW_versionValue_in_versionRangeStart659);
                    versionValue();
                    this._fsp--;

                    (this.versionRange_stack.peek()).floor = this.versionValueStack.pop();
                    (this.versionRange_stack.peek()).floorInc = true;

                    match(this.input, Token.UP, null);

                }
                    break;
                case 2:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:185:4:
                    // ^( VERG versionValue )
                {
                    match(this.input, VERG, FOLLOW_VERG_in_versionRangeStart672);

                    match(this.input, Token.DOWN, null);
                    pushFollow(FOLLOW_versionValue_in_versionRangeStart674);
                    versionValue();
                    this._fsp--;

                    (this.versionRange_stack.peek()).floor = this.versionValueStack.pop();
                    (this.versionRange_stack.peek()).floorInc = false;

                    match(this.input, Token.UP, null);

                }
                    break;

            }
        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end versionRangeStart

    // $ANTLR start versionRangeEnd
    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:188:1:
    // versionRangeEnd : ( ^( VERLE versionValue ) | ^( VERL versionValue ) );
    public final void versionRangeEnd() throws RecognitionException {
        try {
            // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:188:17:
            // ( ^( VERLE versionValue ) | ^( VERL versionValue ) )
            int alt19 = 2;
            int LA19_0 = this.input.LA(1);

            if (LA19_0 == VERLE) {
                alt19 = 1;
            } else if (LA19_0 == VERL) {
                alt19 = 2;
            } else {
                NoViableAltException nvae = new NoViableAltException(
                    "188:1: versionRangeEnd : ( ^( VERLE versionValue ) | ^( VERL versionValue ) );", 19, 0, this.input);

                throw nvae;
            }
            switch (alt19) {
                case 1:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:188:20:
                    // ^( VERLE versionValue )
                {
                    match(this.input, VERLE, FOLLOW_VERLE_in_versionRangeEnd692);

                    match(this.input, Token.DOWN, null);
                    pushFollow(FOLLOW_versionValue_in_versionRangeEnd694);
                    versionValue();
                    this._fsp--;

                    (this.versionRange_stack.peek()).ceiling = this.versionValueStack.pop();
                    (this.versionRange_stack.peek()).ceilingInc = true;

                    match(this.input, Token.UP, null);

                }
                    break;
                case 2:
                    // /Users/glynnormington/engine/config/com.springsource.server.config.core/src/main/java/com/springsource/engine/config/core/validate/EngineConfigPointSchemaWalker.g:189:4:
                    // ^( VERL versionValue )
                {
                    match(this.input, VERL, FOLLOW_VERL_in_versionRangeEnd707);

                    match(this.input, Token.DOWN, null);
                    pushFollow(FOLLOW_versionValue_in_versionRangeEnd709);
                    versionValue();
                    this._fsp--;

                    (this.versionRange_stack.peek()).ceiling = this.versionValueStack.pop();
                    (this.versionRange_stack.peek()).ceilingInc = false;

                    match(this.input, Token.UP, null);

                }
                    break;

            }
        } catch (RecognitionException re) {
            reportError(re);
            recover(this.input, re);
        } finally {
        }
        return;
    }

    // $ANTLR end versionRangeEnd

    public static final BitSet FOLLOW_ConfigPointSchema_in_configPointSchema59 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_IDENTIFIER_in_configPointSchema62 = new BitSet(new long[] { 0x00000000000000A0L });

    public static final BitSet FOLLOW_configurationSchema_in_configPointSchema71 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_mapSchema_in_configurationSchema91 = new BitSet(new long[] { 0x0000000000000002L });

    public static final BitSet FOLLOW_listSchema_in_configurationSchema97 = new BitSet(new long[] { 0x0000000000000002L });

    public static final BitSet FOLLOW_MAPSCHEMA_in_mapSchema127 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_mapletSchema_in_mapSchema129 = new BitSet(new long[] { 0x0000000000000048L });

    public static final BitSet FOLLOW_MAPLETSCHEMA_in_mapletSchema154 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_key_in_mapletSchema156 = new BitSet(new long[] { 0x00000000000002A0L });

    public static final BitSet FOLLOW_valueSchema_in_mapletSchema158 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_stringSchema_in_valueSchema173 = new BitSet(new long[] { 0x0000000000000002L });

    public static final BitSet FOLLOW_configurationSchema_in_valueSchema179 = new BitSet(new long[] { 0x0000000000000002L });

    public static final BitSet FOLLOW_LISTSCHEMA_in_listSchema200 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_valueSchema_in_listSchema202 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_KEY_in_key218 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_IDENTIFIER_in_key220 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_STRINGSCHEMA_in_stringSchema242 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_anyString_in_stringSchema247 = new BitSet(new long[] { 0x0000000000603808L });

    public static final BitSet FOLLOW_enumeration_in_stringSchema266 = new BitSet(new long[] { 0x0000000000603008L });

    public static final BitSet FOLLOW_integer_in_stringSchema286 = new BitSet(new long[] { 0x0000000000602008L });

    public static final BitSet FOLLOW_integerRange_in_stringSchema305 = new BitSet(new long[] { 0x0000000000600008L });

    public static final BitSet FOLLOW_version_in_stringSchema324 = new BitSet(new long[] { 0x0000000000400008L });

    public static final BitSet FOLLOW_versionRange_in_stringSchema343 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_ANYSTRING_in_anyString367 = new BitSet(new long[] { 0x0000000000000002L });

    public static final BitSet FOLLOW_ENUM_in_enumeration400 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_IDENTIFIER_in_enumeration404 = new BitSet(new long[] { 0x0000000010000008L });

    public static final BitSet FOLLOW_INTEGER_in_integer422 = new BitSet(new long[] { 0x0000000000000002L });

    public static final BitSet FOLLOW_INTEGERRANGE_in_integerRange448 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_integerRangeStart_in_integerRange450 = new BitSet(new long[] { 0x0000000000030000L });

    public static final BitSet FOLLOW_integerRangeEnd_in_integerRange452 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_INTGE_in_integerRangeStart467 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_NUMBER_in_integerRangeStart469 = new BitSet(new long[] { 0x0000000000180000L });

    public static final BitSet FOLLOW_POSITIVE_in_integerRangeStart474 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_NEGATIVE_in_integerRangeStart478 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_INTG_in_integerRangeStart492 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_NUMBER_in_integerRangeStart494 = new BitSet(new long[] { 0x0000000000180000L });

    public static final BitSet FOLLOW_POSITIVE_in_integerRangeStart499 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_NEGATIVE_in_integerRangeStart503 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_INTLE_in_integerRangeEnd521 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_NUMBER_in_integerRangeEnd523 = new BitSet(new long[] { 0x0000000000180000L });

    public static final BitSet FOLLOW_POSITIVE_in_integerRangeEnd528 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_NEGATIVE_in_integerRangeEnd532 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_INTL_in_integerRangeEnd546 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_NUMBER_in_integerRangeEnd548 = new BitSet(new long[] { 0x0000000000180000L });

    public static final BitSet FOLLOW_POSITIVE_in_integerRangeEnd553 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_NEGATIVE_in_integerRangeEnd557 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_VERSION_in_version573 = new BitSet(new long[] { 0x0000000000000002L });

    public static final BitSet FOLLOW_VERSIONVALUE_in_versionValue603 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_NUMBER_in_versionValue607 = new BitSet(new long[] { 0x0000000080000008L });

    public static final BitSet FOLLOW_VERSIONRANGE_in_versionRange638 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_versionRangeStart_in_versionRange640 = new BitSet(new long[] { 0x000000000C000000L });

    public static final BitSet FOLLOW_versionRangeEnd_in_versionRange642 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_VERGE_in_versionRangeStart657 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_versionValue_in_versionRangeStart659 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_VERG_in_versionRangeStart672 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_versionValue_in_versionRangeStart674 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_VERLE_in_versionRangeEnd692 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_versionValue_in_versionRangeEnd694 = new BitSet(new long[] { 0x0000000000000008L });

    public static final BitSet FOLLOW_VERL_in_versionRangeEnd707 = new BitSet(new long[] { 0x0000000000000004L });

    public static final BitSet FOLLOW_versionValue_in_versionRangeEnd709 = new BitSet(new long[] { 0x0000000000000008L });

}
