/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.control.core.internal;

import javax.management.modelmbean.ModelMBeanInfo;

/**
 * Strategy interface for defining a {@link ModelMBeanInfo Model MBean} for a given class.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <strong>must</strong> must be threadsafe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface ModelMBeanInfoAssembler {

    /**
     * Constructs the {@link ModelMBeanInfo} for the supplied {@link Class}.
     * 
     * @param definition the <code>Class</code> used to construct the MBean interface.
     * @param mBeanClassName the name of the concrete type implementing the MBean interface.
     * @return the <code>ModelMBeanInfo</code>.
     */
    ModelMBeanInfo assembleModelMBeanInfo(Class<?> definition, String mBeanClassName);
}
