/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.control.core.internal;

import com.springsource.server.control.core.ControlExporter;
import com.springsource.server.control.core.ControlHandle;
import com.springsource.server.serviceability.ffdc.FFDCService;

/**
 * 
 * This class is an MBean allowing the system state to be dumped out on demand. Standard 
 * implementation of <code>DumpControl</code>
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is thread safe
 *
 * @author Christopher Frost
 * @since 1.0
 */
public class StandardSystemDumpControl implements SystemDumpControl {

    private final ControlHandle controlHandle;

    private final FFDCService ffdcService;
    
    public StandardSystemDumpControl(FFDCService ffdcService, ControlExporter controlExporter) {
        this.ffdcService = ffdcService;
        this.controlHandle = controlExporter.exportControl(this, SystemDumpControl.class, null);
    }
    
    /** 
     * {@inheritDoc}
     */
    public void generateDump(){
        this.ffdcService.generateDump(null);
    }
    
    /**
     * Retract this control so it is no longer visible. 
     */
    public void retract() {
        this.controlHandle.retractControl();
    }
}
