/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.app.spring;

import static com.springsource.server.deployer.core.ModuleDeployer.MODULE_TYPE_MANIFEST_HEADER;

import org.osgi.framework.Bundle;

/**
 * Utility methods for working with server application module bundles. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Thread-safe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public final class ApplicationBundleUtils {

    /**
     * Gets the server module type for the supplied {@link Bundle}.
     * 
     * @param bundle the <code>Bundle</code>.
     * @return the server module type, or <code>null</code> if the supplied <code>Bundle</code> is not a server
     *         application module.
     */
    public static String getModuleType(Bundle bundle) {
        String value = (String) bundle.getHeaders().get(MODULE_TYPE_MANIFEST_HEADER);
        return (value == null || value.length() == 0 ? null : value);
    }
}
