/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.app.spring;

import static com.springsource.server.deployer.core.ModuleDeployer.BUNDLE_MODULE_TYPE;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.springframework.osgi.context.DelegatedExecutionOsgiBundleApplicationContext;
import org.springframework.osgi.extender.OsgiApplicationContextCreator;

/**
 * {@link OsgiApplicationContextCreator} that creates {@link GenericModuleOsgiBundleXmlApplicationContext} instances for
 * all generic bundle modules.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Thread-safe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class GenericModuleOsgiApplicationContextCreator implements OsgiApplicationContextCreator {

    /**
     * {@inheritDoc}
     */
    public DelegatedExecutionOsgiBundleApplicationContext createApplicationContext(BundleContext bundleContext) throws Exception {
        if (isGenericModuleBundle(bundleContext.getBundle())) {
            GenericModuleOsgiBundleXmlApplicationContext context = new GenericModuleOsgiBundleXmlApplicationContext();
            context.setBundleContext(bundleContext);
            return context;
        }
        return null;
    }

    /**
     * Queries whether the supplied bundle is a generic bundle module.
     */
    private boolean isGenericModuleBundle(Bundle bundle) {
        return BUNDLE_MODULE_TYPE.equals(ApplicationBundleUtils.getModuleType(bundle));
    }

}
