/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.controls;

/**
 * MBean for tracking deployer recovery. A notification of type {@value #NOTIFICATION_TYPE} is broadcasted when recovery
 * completes. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <code>must</code> be threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface RecoveryMonitorMBean {

    /**
     * The type of notification sent when recovery completes.
     */
    public static final String NOTIFICATION_TYPE = "com.springsource.server.recovery";

    /**
     * Indicates whether or not recovery is complete.
     * 
     * @return <code>true</code> if recovery is complete, otherwise <code>false</code>.
     */
    boolean isRecoveryComplete();
}
