/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import java.net.URI;


/**
 * {@link ModuleFactory} is an interface for {@link Module} factories.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this class must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface ModuleFactory {
    
    /**
     * Create a module of the given deployable from the given bundle.
     * 
     * @param informedDeployable the {@link InformedDeployable} the module belongs to
     * @param bundleLocation the location of the bundle defining the module
     * @return the new module
     * @throws DeploymentException 
     */
    Module create(InformedDeployable informedDeployable, URI bundleLocation) throws DeploymentException;

}
