/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.event;

import com.springsource.server.common.math.Version;

/**
 * {@link ApplicationDeploymentEvent} is the base class for all events relating to deployment of applications and
 * modules of applications.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is immutable and therefore thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public abstract class ApplicationDeploymentEvent {

    private final String applicationSymbolicName;

    private final Version applicationVersion;

    /**
     * Construct a new {@link ApplicationDeploymentEvent} with the given application name and version.
     * 
     * @param applicationSymbolicName the symbolic name of the application
     * @param applicationVersion the version of the application
     */
    protected ApplicationDeploymentEvent(String applicationSymbolicName, Version applicationVersion) {
        this.applicationSymbolicName = applicationSymbolicName;
        this.applicationVersion = applicationVersion;
    }

    /**
     * Get the symbolic name of this event's application.
     * 
     * @return the application symbolic name
     */
    public String getApplicationSymbolicName() {
        return applicationSymbolicName;
    }

    /**
     * Get the version of this event's application.
     * 
     * @return the application version
     */
    public Version getApplicationVersion() {
        return applicationVersion;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        return this.getClass().getName() + " for application " + this.applicationSymbolicName + " version " + this.applicationVersion;
    }

}
