/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.event;

/**
 * {@link DeploymentListener} is used to listen for events relating to application deployment.
 * <p />
 * Application wide events extend {@link ApplicationDeploymentEvent} and are delivered synchronously by the thread which
 * initiated deployment.
 * <p />
 * Events for specific bundles of an application extend {@link ApplicationBundleDeploymentEvent} and may be delivered
 * during deployment or undeployment of the application or refresh of a bundle of the application.
 * <p />
 * Users of this interface should simply publish an object that implements this interface to the OSGi service registry.
 * <p />
 * 
 * @see ApplicationDeploymentEvent
 * @see ApplicationBundleDeploymentEvent
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface DeploymentListener {

    /**
     * Notify an {@link ApplicationDeploymentEvent}.
     * 
     * @param event the event being notified
     */
    void onEvent(ApplicationDeploymentEvent event);

}
