/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.internal;

import java.io.File;
import java.io.IOException;
import java.net.URI;

import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;

import com.springsource.server.deployer.core.DeploymentArtefact;
import com.springsource.server.deployer.core.FatalDeploymentException;

/**
 * TODO Document AbstractDeploymentArtefact
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is as thread-safe as {@link org.springframework.core.io.Resource}.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
abstract class AbstractDeploymentArtefact implements DeploymentArtefact {

    private final Resource resource;

    public AbstractDeploymentArtefact(URI location) {
        this.resource = new FileSystemResource(new File(location));
    }

    /**
     * {@inheritDoc}
     */
    public String getDescription() {
        return resource.getDescription();
    }

    /**
     * {@inheritDoc}
     */
    public File getFile() {
        try {
            return resource.getFile();
        } catch (IOException e) {
            throw new FatalDeploymentException("Deployment artefact file error", e);
        }
    }

    /**
     * {@inheritDoc}
     */
    public String getFilename() {
        return resource.getFilename();
    }

    /**
     * {@inheritDoc}
     */
    public URI getURI() {
        try {
            return resource.getURI();
        } catch (IOException e) {
            throw new FatalDeploymentException("Deployment artefact URI error", e);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return getDescription();
    }

}
