/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.internal;

import java.util.Set;

import com.springsource.server.deployer.core.DeploymentContext;
import com.springsource.server.deployer.core.Module;
import com.springsource.server.deployer.core.ModuleDeployer;
import com.springsource.server.deployer.core.ZeroModulePersonality;

/**
 * 
 * BundleDeployer is a deployer for basic OSGi bundles which are not deployed by
 * personality-specific deployers. The generic deployer must call this deployer
 * last so that personlity-specific deployers get in first.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
final class BundleDeployer implements ModuleDeployer {

    private static final String BUNDLE_PERSONALITY = "Bundle";

    /**
     * {@inheritDoc}
     */
    public int getOrder() {
        return BUNDLE_ORDER;
    }

    
    /**
     * {@inheritDoc}
     */
    public boolean canDeploy(DeploymentContext deploymentContext, Module module) {
        // Only offer to deploy bundles that no personality-specific deployer
        // has offered to deploy.
        if (!module.hasPersonality()) {
            module.setPersonality(new ZeroModulePersonality(module));
            return true;
        }
        return false;
    }

    /**
     * {@inheritDoc}
     */
    public String getPersonality() {
        return BUNDLE_PERSONALITY;
    }


    /** 
     * {@inheritDoc}
     */
    public Set<PersonalityBundle> getBundles(DeploymentContext deploymentContext) {
        return null;
    }
}
