/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.internal;

import org.osgi.framework.Bundle;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.osgi.context.ConfigurableOsgiBundleApplicationContext;
import org.springframework.osgi.context.event.OsgiBundleApplicationContextEvent;
import org.springframework.osgi.context.event.OsgiBundleApplicationContextListener;
import org.springframework.osgi.context.event.OsgiBundleContextFailedEvent;

import com.springsource.server.deployer.core.DeployerLogEvent;
import com.springsource.server.serviceability.logging.LogService;
import com.springsource.server.serviceability.logging.LogServiceFactory;
import com.springsource.server.serviceability.tracing.Tracer;
import com.springsource.server.serviceability.tracing.TracerFactory;

/**
 * TODO Document DeployerFailureListener
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * TODO Document concurrent semantics of DeployerFailureListener
 * 
 * @author Andy Wilkinson
 * @author Sam Brannen
 * @since 1.0
 */
final class DeployerFailureListener implements OsgiBundleApplicationContextListener {

    private static final LogService LOGGER = LogServiceFactory.getLogService();

    private static final Tracer TRACER = TracerFactory.createTracer(DeployerFailureListener.class);

    public static Bundle getOsgiBundle(OsgiBundleApplicationContextEvent event) {
        Bundle bundle = null;
        ApplicationContext applicationContext = event.getApplicationContext();
        if (applicationContext instanceof ConfigurableOsgiBundleApplicationContext) {
            ConfigurableOsgiBundleApplicationContext osgiBundleApplicationContext = (ConfigurableOsgiBundleApplicationContext) applicationContext;
            bundle = osgiBundleApplicationContext.getBundle();
        }
        return bundle;
    }

    /**
     * {@inheritDoc}
     */
    public void onOsgiApplicationEvent(OsgiBundleApplicationContextEvent event) {
        TRACER.traceInfo("OsgiApplicationEvent '%s'", event);
        if (event instanceof OsgiBundleContextFailedEvent) {
            Bundle bundle = getOsgiBundle(event);
            if (bundle != null) {
                OsgiBundleContextFailedEvent failedEvent = (OsgiBundleContextFailedEvent) event;
                Throwable cause = failedEvent.getFailureCause();
                if (cause instanceof BeansException) {
                    BeansExceptionHandler.handleBeansException((BeansException) cause, bundle);
                } else {
                    LOGGER.log(DeployerLogEvent.BUNDLE_CONTEXT_FAILED, cause, BeansExceptionHandler.getBundleIdentifier(bundle));
                }
            }
        }
    }
}
