/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.internal;

import org.osgi.framework.BundleContext;

import com.springsource.server.config.core.ConfigTree;
import com.springsource.server.config.core.ConfigTreeFactory;
import com.springsource.server.deployer.core.DeployerConfiguration;


/**
 * {@link StandardDeployerConfiguration} is the default implementation of {@link DeployerConfiguration}.
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is thread safe.
 *
 * @author Glyn Normington
 * @since 1.0
 */
public final class StandardDeployerConfiguration implements DeployerConfiguration {
    
    private static final String DEPLOYER_CONFIG_NAME = "deployer";

    private static final String DEPLOYMENT_TIMEOUT_SECONDS_KEY = "deploymentTimeoutSeconds";
    
    private final ConfigTree configTree;
    
    private final int deploymentTimeoutSeconds;
    
    /**
     * Construct a deployment configuration using the given {@link ConfigTreeFactory} and {@link BundleContext}.
     * 
     * @param configTreeFactory a factory for configuration trees
     * @param context the context of the bundle containing the configuration
     */
    StandardDeployerConfiguration(ConfigTreeFactory configTreeFactory, BundleContext context) {
        this.configTree = configTreeFactory.createConfigTree(DEPLOYER_CONFIG_NAME, context);
        int configuredDeploymentTimeoutSeconds = this.configTree.getIntValue(DEPLOYER_CONFIG_NAME + ":" + DEPLOYMENT_TIMEOUT_SECONDS_KEY);
        // Treat non-positive values as indicating "no timeout". Integer.MAX_VALUE seconds is over 60 years, which should be long enough.
        this.deploymentTimeoutSeconds = configuredDeploymentTimeoutSeconds > 0 ? configuredDeploymentTimeoutSeconds : Integer.MAX_VALUE; 
    }

    /** 
     * {@inheritDoc}
     */
    public int getDeploymentTimeoutSeconds() {
        return this.deploymentTimeoutSeconds;
    }

}
