/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.internal;

import com.springsource.server.deployer.core.DeploymentIdentity;


/**
 * {@link StandardDeploymentIdentity} is the implementation of {@link DeploymentIdentity}.
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is immutable and therefore thread safe.
 *
 * @author Glyn Normington
 * @since 1.0
 */
public final class StandardDeploymentIdentity implements DeploymentIdentity {

    private static final long serialVersionUID = 67849234293492373L;
    
    private String symbolicName;
    
    private String version;

    /**
     * Construct a {@link StandardDeploymentIdentity} with the given name and version.
     * 
     * @param symbolicName the symbolic name of the deployed artefact
     * @param version the version of the deployed artefact
     */
    public StandardDeploymentIdentity(String symbolicName, String version) {
        this.symbolicName = symbolicName;
        this.version = version;
    }

    /** 
     * {@inheritDoc}
     */
    public String getSymbolicName() {
        return this.symbolicName;
    }

    /** 
     * {@inheritDoc}
     */
    public String getVersion() {
        return this.version;
    }

    /** 
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((symbolicName == null) ? 0 : symbolicName.hashCode());
        result = prime * result + ((version == null) ? 0 : version.hashCode());
        return result;
    }

    /** 
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (!(obj instanceof StandardDeploymentIdentity))
            return false;
        final StandardDeploymentIdentity other = (StandardDeploymentIdentity) obj;
        if (symbolicName == null) {
            if (other.symbolicName != null)
                return false;
        } else if (!symbolicName.equals(other.symbolicName))
            return false;
        if (version == null) {
            if (other.version != null)
                return false;
        } else if (!version.equals(other.version))
            return false;
        return true;
    }

    /** 
     * {@inheritDoc}
     */
    @Override public String toString() {
        return "DeploymentIdentity(" + this.symbolicName + ", " + this.version + ")";
    }
    
}
