/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.module;

import java.net.URI;

import org.osgi.service.packageadmin.PackageAdmin;

import com.springsource.server.deployer.core.DeployerConfiguration;
import com.springsource.server.deployer.core.DeploymentException;
import com.springsource.server.deployer.core.InformedDeployable;
import com.springsource.server.deployer.core.Module;
import com.springsource.server.deployer.core.ModuleFactory;
import com.springsource.server.deployer.core.event.DeploymentListener;
import com.springsource.server.deployer.core.internal.DeployArea;
import com.springsource.server.kernel.core.BundleStarter;
import com.springsource.server.osgi.framework.BundleInstaller;
import com.springsource.server.osgi.framework.OsgiFramework;
import com.springsource.server.osgi.manifest.BundleManifestFactory;
import com.springsource.server.serviceability.tracing.TracingService;

/**
 * {@link StandardModuleFactory} is a factory for {@link StandardModule} {@link Module Modules}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @author Andy Wilkinson
 * @since 1.0
 */
class StandardModuleFactory implements ModuleFactory {

    private static final String WORK_AREA_NAME = "Module";

    private final DeployArea deployArea;

    private final BundleInstaller bundleInstaller;

    private final BundleManifestFactory bundleManifestFactory;

    private final OsgiFramework osgi;

    private final StandardModuleRegistry standardModuleRegistry;

    private final PackageAdmin packageAdmin;

    private final TracingService tracingService;

    private final DeployerConfiguration deployerConfiguration;

    private final BundleStarter bundleStarter;

    private final DeploymentListener applicationDeploymentEventNotifier;

    StandardModuleFactory(DeployArea deployArea, BundleInstaller bundleInstaller, BundleManifestFactory bundleManifestFactory, OsgiFramework osgi,
        StandardModuleRegistry standardModuleRegistry, PackageAdmin packageAdmin, TracingService tracingService,
        DeployerConfiguration deployerConfiguration, BundleStarter bundleStarter, DeploymentListener applicationDeploymentEventNotifier) {
        this.deployArea = deployArea.createWorkArea(WORK_AREA_NAME, true);
        this.bundleInstaller = bundleInstaller;
        this.bundleManifestFactory = bundleManifestFactory;
        this.osgi = osgi;
        this.standardModuleRegistry = standardModuleRegistry;
        this.packageAdmin = packageAdmin;
        this.tracingService = tracingService;
        this.deployerConfiguration = deployerConfiguration;
        this.bundleStarter = bundleStarter;
        this.applicationDeploymentEventNotifier = applicationDeploymentEventNotifier;
    }

    /**
     * {@inheritDoc}
     */
    public Module create(InformedDeployable informedDeployable, URI bundleLocation) throws DeploymentException {
        return new StandardModule(informedDeployable, this.deployArea, bundleLocation, this.bundleInstaller, this.bundleManifestFactory, this.osgi,
            this.standardModuleRegistry, this.packageAdmin, this.tracingService, this.deployerConfiguration, this.bundleStarter,
            this.applicationDeploymentEventNotifier);
    }

}
