/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.module;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.osgi.framework.Bundle;

import com.springsource.server.deployer.core.Module;
import com.springsource.server.deployer.core.ModuleRegistry;

/**
 * {@link StandardModuleRegistry} provides the implementation of {@link ModuleRegistry}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public class StandardModuleRegistry implements ModuleRegistry {
    
    private Map<Bundle, Module> moduleByBundle = new ConcurrentHashMap<Bundle, Module>();
    
    /**
     * {@inheritDoc}
     */
    public Module getModule(Bundle bundle) {
        return this.moduleByBundle.get(bundle);
    }

    /**
     * Associate the given {@link Bundle} with the given {@link Module}.
     * 
     * @param bundle the {@link Bundle} to be associated
     * @param module the {@link Module} to be associated
     */
    public void associateModule(Bundle bundle, Module module) {
        this.moduleByBundle.put(bundle, module);

    }

    /**
     * Dissociate the given {@link Bundle} from an associated {@link Module Modules}.
     * 
     * @param bundle the {@link Bundle} to be dissociated
     */
    public void dissociateModule(Bundle bundle) {
        this.moduleByBundle.remove(bundle);
    }

}
