/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.lib;

import java.net.URI;

import com.springsource.server.deployer.core.Deployable;
import com.springsource.server.deployer.core.DeployableFactory;
import com.springsource.server.deployer.core.InformedDeployable;
import com.springsource.server.deployer.core.ApplicationDeployer.DeploymentOptions;
import com.springsource.server.osgi.framework.BundleInstaller;
import com.springsource.server.osgi.framework.OsgiFramework;

/**
 * {@link LibraryFactory} is a factory for {@link Library} {@link Deployable Deployables}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
final class LibraryFactory implements DeployableFactory {
    
    private final BundleInstaller bundleInstaller;
    
    private final OsgiFramework osgi;

    LibraryFactory(BundleInstaller bundleInstaller, OsgiFramework osgi) {
        this.bundleInstaller = bundleInstaller;
        this.osgi = osgi;
    }

    /**
     * {@inheritDoc}
     */
    public InformedDeployable create(URI location, URI sourceLocation, DeploymentOptions deploymentOptions) {
        return new Library(this.bundleInstaller, location, sourceLocation, deploymentOptions, this.osgi);
    }
}
