/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.ffdc.core.internal;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * {@link LogEvent} enum for FFDC subsystem
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * @author Damilola Senbanjo
 * @author Sam Brannen
 * @since 1.0
 */

public enum FFDCLogEvent implements LogEvent {

    /* START OF ENUM DEFINITIONS */

    FAILED_TO_LOCATE_DUMP_DIRECTORY(0, Level.ERROR),

    USING_DUMP_DIRECTORY(1, Level.INFO),

    DUMP_FILE_WRITTEN(2, Level.INFO),

    SUBSYSTEM_BUNDLE_FAILED(3, Level.ERROR);

    /* END OF ENUM DEFINITIONS */

    private static final String SUBSYSTEM_CODE = "FF";

    private static final String SUBSYSTEM_NAME = "FFDC";

    private final LogEventDelegate delegate;

    /**
     * Constructs a log event for the FFDC subsystem
     * 
     * @param code the unique code identifying the subsystem
     * @param level the severity of the event
     */
    private FFDCLogEvent(int code, Level level) {
        this.delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, code, level);
    }

    /**
     * {@inheritDoc}
     */
    public String getEventCode() {
        return this.delegate.getEventCode();
    }

    /**
     * {@inheritDoc}
     */
    public Level getLevel() {
        return this.delegate.getLevel();
    }

    /**
     * {@inheritDoc}
     */
    public String getSubsystemName() {
        return SUBSYSTEM_NAME;
    }

}
