/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.io.core.work;

import com.springsource.server.bootstrap.BootstrapConfiguration;
import com.springsource.server.io.core.PathReference;
import com.springsource.server.kernel.core.Subsystem;

/**
 * Standard implementation of {@link WorkAreaManager}.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class StandardWorkAreaManager implements WorkAreaManager {

    private static final String DEFAULT_WORK_DIRECTORY = "target";

    private final PathReference workDirectoryReference;

    /**
     * Creates a new <code>StandardWorkAreaManager</code>.
     * 
     * @param bootstrapConfiguration the bootstrap configuration.
     */
    public StandardWorkAreaManager(BootstrapConfiguration bootstrapConfiguration) {
        String workDirectory = bootstrapConfiguration.getWorkDirectory();
        if (workDirectory == null) {
            workDirectory = DEFAULT_WORK_DIRECTORY;
        }
        this.workDirectoryReference = new PathReference(workDirectory);
    }

    /**
     * {@inheritDoc}
     */
    public PathReference getWorkDirectory(Subsystem subsystem) {
        PathReference subsystemWorkDirectory = this.workDirectoryReference.newChild(subsystem.getName());
        subsystemWorkDirectory.createDirectory();
        return subsystemWorkDirectory;
    }

}
