/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.io.core.work;

import com.springsource.server.io.core.PathReference;
import com.springsource.server.kernel.core.Subsystem;

/**
 * Controls access to the work area.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface WorkAreaManager {

    /**
     * Gets a work directory for the supplied {@link Subsystem}. If the <code>Subsystem</code> already has a work
     * directory, the existing work directory is used, otherwise a work directory is created.
     * 
     * @param subsystem the <code>Subsystem</code>.
     * @return a {@link PathReference} to the work directory.
     */
    PathReference getWorkDirectory(Subsystem subsystem);
}
