/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.bootstrap;

import java.util.Collection;
import java.util.List;

import org.osgi.framework.Bundle;

/**
 * A bootstrap configuration records a collection of bundles partitioned by subsystem name.
 * 
 * @author Glyn Normington
 * 
 */
public interface SubsystemContents {

    public static interface SubsystemConfiguration {

        String getSubsystemName();

        List<Bundle> getBundles();

        void addBundle(Bundle bundle);

    }

    /**
     * Return all the subsystems and bundles in the configuration.
     * 
     * @return a list of subsystem configurations each of which has a subsystem name and a list of bundles in
     *         installation order
     */
    Collection<? extends SubsystemConfiguration> getSubsystemConfigurations();

    /**
     * Record that the given bundle belongs to the subsystem of the given name.
     * 
     * @param subsystemName the subsystem to which the bundle belongs
     * @param bundle the bundle which belongs to the given subsystem
     */
    void addBundle(String subsystemName, Bundle bundle);
}
