/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core;

/**
 * A Listener that listens to events on a Subsystem.<p/>
 * 
 * Implementations should be aware that registered <code>SubsystemListeners</code> are invoked synchronously by the
 * <code>Kernel</code> and therefore should avoid starting long running processes.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations are <strong>required</strong> to be thread safe.
 * 
 * @author Rob Harrop
 * @author Glyn Normington
 * @since 1.0
 */
public interface SubsystemListener {

    /**
     * Signals that the given {@link Subsystem} has changed state to the given state.
     * 
     * @param subsystem the subsystem that has changed state
     * @param newState the new state of the given subsystem
     */
    void subSystemStateChange(Subsystem subsystem, Subsystem.State newState);

}
