/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core.internal;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.framework.ServiceRegistration;

import com.springsource.server.bootstrap.BootstrapConfiguration;
import com.springsource.server.kernel.core.BundleStarter;
import com.springsource.server.osgi.framework.OsgiFramework;

/**
 * OSGi {@link BundleActivator} that starts a Kernel.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public class KernelBundleActivator implements BundleActivator {

    private final Object monitor = new Object();

    private ServiceRegistration bundleStarterRegistration;

    private StandardBundleStarter starter;

    /**
     * {@inheritDoc}
     * 
     * Starts the Kernel.
     */
    public void start(BundleContext context) throws Exception {
        String serviceName = OsgiFramework.class.getName();
        ServiceReference sr = context.getServiceReference(serviceName);

        if (sr == null) {
            throw new RuntimeException("Unable to get reference for service '" + serviceName + "'.");
        }
        OsgiFramework osgi = (OsgiFramework) context.getService(sr);

        if (osgi == null) {
            throw new RuntimeException("Unable to obtain service '" + serviceName + "'.");
        }

        serviceName = BootstrapConfiguration.class.getName();
        sr = context.getServiceReference(serviceName);

        if (sr == null) {
            throw new RuntimeException("Unable to get reference for service '" + serviceName + "'.");
        }

        BootstrapConfiguration bootstrapConfiguration = (BootstrapConfiguration) context.getService(sr);

        if (bootstrapConfiguration == null) {
            throw new RuntimeException("Unable to obtain service '" + serviceName + "'.");
        }

        StandardBundleStarter starter = new StandardBundleStarter(context);
        ServiceRegistration registration = context.registerService(BundleStarter.class.getName(), starter, null);

        synchronized (this.monitor) {
            this.starter = starter;
            this.bundleStarterRegistration = registration;
        }
        new KernelSubsystem(context.getBundle(), osgi, bootstrapConfiguration, starter).start();
    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext context) throws Exception {
        ServiceRegistration reg = null;

        synchronized (this.monitor) {
            reg = this.bundleStarterRegistration;
            this.starter.destroy();
        }
        if (reg != null) {
            reg.unregister();
        }
    }

}
