/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core.internal.install;

import java.util.List;

import com.springsource.server.common.math.OrderedPair;
import com.springsource.server.osgi.manifest.VersionRange;

/**
 * Describes a subsystem that can be installed into the server.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Glyn Normington
 * @author Rob Harrop
 * @since 1.0
 */
public interface SubsystemDescriptor {

    /**
     * Gets the subsystem name.
     * 
     * @return the subsystem name.
     */
    String getName();

    /**
     * Gets the subsystem description.
     * 
     * @return the description of the subsystem.
     */
    String getDescription();

    /**
     * Gets the list of bundles that make up this subsystem. Each {@link OrderedPair} in the returned {@link List}
     * contains the bundle symbolic name and the {@link VersionRange}.
     * 
     * @return the bundle definitions.
     */
    List<OrderedPair<String, VersionRange>> getBundleDefinitions();

}
