/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core.internal.install;

import com.springsource.server.kernel.core.KernelException;

/**
 * Resolves a subsystem name into a {@link SubsystemDescriptor} <p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Glyn Normington
 * @author Rob Harrop
 * @since 1.0
 */
public interface SubsystemResolver {

    /**
     * Resolves the supplied subsystem name into that subsystem's descriptor.
     * 
     * @param subsystemName the name of the subsystem.
     * @return the subsystem descriptor.
     * @throws KernelException if the subsystem name could not be resolved into a valid descriptor
     */
    SubsystemDescriptor resolveSubsystemDescriptor(String subsystemName) throws KernelException;

}
