/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.dm;

import java.util.Set;

import org.osgi.framework.BundleContext;
import org.springframework.osgi.context.DelegatedExecutionOsgiBundleApplicationContext;
import org.springframework.osgi.context.support.OsgiBundleXmlApplicationContext;
import org.springframework.osgi.extender.OsgiApplicationContextCreator;
import org.springframework.osgi.extender.support.ApplicationContextConfiguration;
import org.springframework.osgi.extender.support.DefaultOsgiApplicationContextCreator;

/**
 * {@link OsgiApplicationContextCreator} that delegates to any <code>OsgiApplicationContextCreator</code> configured
 * in the {@link OsgiApplicationContextCreatorRegistry}. If no configured <code>OsgiApplicationContextCreator</code>
 * creates a context, then the {@link DefaultOsgiApplicationContextCreator default context} is created.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public class ServerOsgiApplicationContextCreator implements OsgiApplicationContextCreator {

    /**
     * {@inheritDoc}
     */
    public DelegatedExecutionOsgiBundleApplicationContext createApplicationContext(BundleContext bundleContext) throws Exception {
        ApplicationContextConfiguration config = new ApplicationContextConfiguration(bundleContext.getBundle());
        
        if(!config.isSpringPoweredBundle()) {
            return null;
        }
        DelegatedExecutionOsgiBundleApplicationContext context = null;
        Set<OsgiApplicationContextCreator> contextCreators = OsgiApplicationContextCreatorRegistry.getRegisteredContextCreators();
        for (OsgiApplicationContextCreator contextCreator : contextCreators) {
            context = contextCreator.createApplicationContext(bundleContext);
            if (context != null) {
                break;
            }
        }
        if (context == null) {
            context = new OsgiBundleXmlApplicationContext();
            context.setBundleContext(bundleContext);
            context.setPublishContextAsService(config.isPublishContextAsService());
        }
        return context;
    }
}
