/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.application;


/**
 * <p>
 * Provides a wrapper around the underlying Info object to ensure the correct visibility 
 * for the management systems, also provides some basic formatting to avoid common blank 
 * fields.
 * </p>
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is threadsafe.
 *
 * @author Christopher Frost
 * @since 1.0
 */
public class StandardServerModuleInfoAdaptor implements ServerModuleInfo {

    private final ServerModuleInfo serverModuleInfo;
    
    private static final String NO_PERSONALITY = "No personality association";
    

    /**
     * 
     * @param serverModuleInfo
     */
    StandardServerModuleInfoAdaptor(ServerModuleInfo serverModuleInfo) {
        this.serverModuleInfo = serverModuleInfo;
    }

    /**
     * 
     * {@inheritDoc}
     */
    public String getBundleSymbolicName() {
        return this.serverModuleInfo.getBundleSymbolicName() == null ? "No Bundle-SymbolicName present" : this.serverModuleInfo.getBundleSymbolicName();
    }

    /**
     * 
     * {@inheritDoc}
     */
    public String getPersonality() {
        return this.serverModuleInfo.getPersonality() == null ? NO_PERSONALITY : this.serverModuleInfo.getPersonality();
    }

    /**
     * 
     * {@inheritDoc}
     */
    public String getPersonalityIdentifier() {
        return this.serverModuleInfo.getPersonalityIdentifier() == null ? "No personality identifer" : this.serverModuleInfo.getPersonalityIdentifier();
    }

    /**
     * 
     * {@inheritDoc}
     */
    public int compareTo(ServerModuleInfo other) {
        int rank = 0;
        if(NO_PERSONALITY.equals(this.getPersonality()) || "Bundle".equals(this.getPersonality())){
            rank = rank + 500;
        } 
        if(NO_PERSONALITY.equals(other.getPersonality()) || "Bundle".equals(other.getPersonality())){
            rank = rank - 500;
        }
        return rank + this.getBundleSymbolicName().compareToIgnoreCase(other.getBundleSymbolicName());
    }

}
