/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.concurrent;

import com.springsource.server.management.proxy.core.Info;

/**
 * <p>
 * Anything that wants to expose information through the service registry about 
 * executor services must implement this interface. 
 * </p>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public interface ExecutorServiceInfo extends Info {

    /**
     * Gets the average execution time of all executed tasks in mili seconds.
     * 
     * @return the average execution time.
     */
    long getAverageExecutionTime();

    /**
     * Gets the total time spent executing tasks in mili seconds.
     * 
     * @return the total execution time.
     */
    long getExecutionTime();

    /**
     * Gets the number of active tasks within this executor.
     * 
     * @return the active task count.
     */
    int getActiveCount();

    /**
     * Gets the current total capacity of the pool.
     * 
     * @return the current pool size.
     */
    int getPoolSize();

    /**
     * Gets the largest size the pool has ever reached.
     * 
     * @return the largest pool size.
     */
    int getLargestPoolSize();

    /**
     * Gets the maximum pool size.
     * 
     * @return the maximum pool size.
     */
    int getMaximumPoolSize();

    /**
     * Gets the name of the pool.
     * 
     * @return the pool name.
     */
    String getPoolName();

    /**
     * Gets the type of the pool.
     * 
     * @return the pool type name.
     */
    String getTypeName();
}
