/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.concurrent;

import com.springsource.server.management.proxy.core.Info;

/**
 * <p> 
 * Standard interface for all implementations of a <code>WorkQueue</code> to 
 * use for exposing information about themselves to management.
 * </p>
 *
 * @author Christopher Frost
 * @since 1.0
 */
public interface WorkQueueInfo extends Info {

    /**
     * The total capacity of this work queue
     * @return
     */
    public int getQueueSize();
    
    /**
     * How many additional item the work queue can take
     * @return
     */
    public int getQueueRemainingCapacity();
    
    /**
     * How many work items the work queue has had stolen by other work queues
     * @return
     */
    public long getQueueStealCount();
    
    /**
     * How many work items the work queue has stolen from other work queues
     * @return
     */
    public long getQueueStolenCount();
    
    /**
     * How many work items are waiting in the queue
     * @return
     */
    public long getQueueEnqueueCount();
    
    /**
     * A useful description of this queues specific type and/or implementation semantics
     * @return
     */
    public String getQueueType();
    
    /**
     * The unique name of this specific queue
     * @return
     */
    public String getQueueName();
    
}
