/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.configuration;

import com.springsource.server.management.proxy.core.Info;

/**
 * 
 * <p> 
 * Standard interface for all <code>Configuration Points</code> to 
 * use for exposing information about themselves to management.
 * </p>
 *
 * @author Christopher Frost
 * @since 1.0
 */
public interface ConfigPointInfo extends Info {
    
    /**
     * The file name of the configuration file containing this configuration point
     * @return
     */
    public String getShortFileName();
        
    /**
     * The full path and file name of the configuration file containing this configuration point
     * @return
     */
    public String getLongFileName();
    
    /**
     * The name of the node in the configuration tree of this configuration point
     * @return
     */
    public String getNodeName();
    
    /**
     * The path through the configuration tree to the node of this configurations point
     * @return
     */
    public String getNodePath();
    
    /**
     * The unprocessed contents of the configuration point
     * @return
     */
    public String getRawConfigPoint();
    
}
