/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.serviceability;

import com.springsource.server.management.proxy.core.Info;

/**
 * <p>
 * Implementations of this interface expose information about a single 
 * destination from the serviceability subsystem
 * </p>
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * Implementations of this interface should be thread safe
 *
 * @author Christopher Frost
 * @since 1.0
 */
public interface DestinationServiceInfo extends Info {

    /**
     * The unique name of the destination
     * 
     * @return the assigned name of the destination
     */
    public String getName();
    
    /**
     * Something descriptive about the destination, if the destination in 
     * a file then the path to that file is good.
     * 
     * @return descriptive text about the destination
     */
    public String getDestinationString();
    
}
