/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework;


/**
 * {@link ImportMergeException} is thrown when conflicting imports are detected.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is immutable and therefore thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public class ImportMergeException extends OsgiFrameworkException {

    private static final long serialVersionUID = 56985682345987L;

    private final String conflictingPackageName;

    private final String sources;

    /**
     * Creates a new <code>ImportMergeException</code> with the supplied error message.
     * 
     * @param message The exception's message
     */
    public ImportMergeException(String conflictingPackageName, String sources, String message) {
        super("cannot merge imports of package '" + conflictingPackageName + "' from sources '" + sources + "' because of " + message);
        this.conflictingPackageName = conflictingPackageName;
        this.sources = sources;
    }

    /**
     * Get the name of the package that failed to merge.
     * 
     * @return the name of the package that failed to merge
     */
    public final String getConflictingPackageName() {
        return this.conflictingPackageName;
    }

    /**
     * Get the sources of the package that failed to merge.
     * 
     * @return the sources of the package that failed to merge
     */
    public final String getSources() {
        return this.sources;
    }

}
