/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * {@link LogEvent} for the OSGi provisioning bundle.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public enum OsgiFrameworkLogEvent implements LogEvent {
    OSGI_CONSOLE_PORT(1, Level.INFO),
    OSGI_CONSOLE_PORT_IN_USE(2, Level.ERROR),
    IMMEDIATE_SHUTDOWN_INITIATED(3, Level.INFO),
    SHUTDOWN_INITIATED(4, Level.INFO),
    SYSTEM_BUNDLE_OVERLAP(5, Level.WARN);

    private final LogEventDelegate delegate;

    private static final String NAME = "OsgiFramework";

    private static final String CODE = "OF";

    private OsgiFrameworkLogEvent(int messageId, Level level) {
        this.delegate = new LogEventDelegate(NAME, CODE, messageId, level);
    }

    /**
     * {@inheritDoc}
     */
    public String getEventCode() {
        return this.delegate.getEventCode();
    }

    /**
     * {@inheritDoc}
     */
    public String getSubsystemName() {
        return this.delegate.getSubsystemName();
    }

    /**
     * {@inheritDoc}
     */
    public Level getLevel() {
        return this.delegate.getLevel();
    }
}
