/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.equinox;

import java.io.File;

import com.springsource.server.osgi.framework.support.AbstractOsgiConfiguration;
import com.springsource.server.osgi.framework.support.LocationUtils;

/**
 * Defines configuration options for the {@link EquinoxOsgiFramework}.
 * 
 * @author Rob Harrop
 * @author Andy Wilkinson
 * @since 1.0
 */
public final class EquinoxOsgiConfiguration extends AbstractOsgiConfiguration {

    private static final String DEFAULT_JAVA_PROFILE_PATH = determineDefaultProfilePath();

    private String javaProfilePath = DEFAULT_JAVA_PROFILE_PATH;

    private static final String DEFAULT_INSTALL_AREA = ".install";

    private static final String DEFAULT_CONFIG_AREA = System.getProperty("osgi.configuration.area", "equinox-config");

    private String installAreaPath = DEFAULT_INSTALL_AREA;

    private String configAreaPath = DEFAULT_CONFIG_AREA;

    private boolean clean = false;

    private boolean runConsole = false;

    private int consolePort = 0;

    /**
     * Creates a new <code>EquinoxOsgiConfiguration</code>.
     * 
     * @param searchPaths the bundle search paths.
     */
    public EquinoxOsgiConfiguration(String workDirectory, String installPath, String absoluteRoot, String... searchPaths) {
        super(searchPaths, installPath, workDirectory, absoluteRoot);
    }

    /**
     * Gets the install area path.
     */
    public String getInstallAreaPath() {
        return this.installAreaPath;
    }

    /**
     * Sets the install area path.
     */
    public void setInstallAreaPath(String installAreaPath) {
        this.installAreaPath = installAreaPath;
    }

    /**
     * Gets the config area path.
     */
    public String getConfigAreaPath() {
        return this.configAreaPath;
    }

    /**
     * Sets the config area path.
     */
    public void setConfigAreaPath(String configAreaPath) {
        this.configAreaPath = configAreaPath;
    }

    /**
     * Gets the clean flag.
     */
    public boolean isClean() {
        return this.clean;
    }

    /**
     * Sets the clean flag.
     */
    public void setClean(boolean clean) {
        this.clean = clean;
    }

    /**
     * Gets the run console flag.
     */
    public boolean isRunConsole() {
        return this.runConsole;
    }

    /**
     * Sets the run console flag.
     */
    public void setRunConsole(boolean runConsole) {
        this.runConsole = runConsole;
    }

    /**
     * Gets the console port.
     */
    public int getConsolePort() {
        return this.consolePort;
    }

    /**
     * Sets the console port.
     */
    public void setConsolePort(int consolePort) {
        this.consolePort = consolePort;
    }

    /**
     * Gets the java profile path.
     */
    public void setJavaProfilePath(String path) {

        this.javaProfilePath = LocationUtils.convertToCanonicalFilePath(new File(path));
    }

    /**
     * Sets the java profile path.
     */
    public String getJavaProfilePath() {
        return this.javaProfilePath;
    }
    
    private static String determineDefaultProfilePath() {
        if ("1.6".equals(System.getProperty("java.specification.version"))) {
            return new File(System.getProperty("osgi.java.profile", "../../com.springsource.server.osgi/java6-server.profile")).toURI().toString();
        } else {
            return new File(System.getProperty("osgi.java.profile", "../../com.springsource.server.osgi/java5-server.profile")).toURI().toString();
        }
    }
}
