/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.equinox;

import com.springsource.server.osgi.framework.OsgiFramework;
import com.springsource.server.osgi.framework.OsgiLauncher;

/**
 * Implementation of {@link OsgiLauncher} for the Equinox OSGi framework.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public class EquinoxOsgiLauncher implements OsgiLauncher {

    private final EquinoxOsgiConfiguration configuration;

    /**
     * Creates a new <code>EquinoxOsgiLauncher</code> using the supplied {@link EquinoxOsgiConfiguration}.
     * 
     * @param configuration the configuration for Equinox.
     */
    public EquinoxOsgiLauncher(EquinoxOsgiConfiguration configuration) {
        this.configuration = configuration;
    }

    /**
     * {@inheritDoc}
     */
    public OsgiFramework start() {
        EquinoxOsgiFramework framework = new EquinoxOsgiFramework(this.configuration);
        framework.start();
        return framework;
    }

}
