/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.support.merge;

import java.util.ArrayList;

import com.springsource.server.osgi.framework.ImportMergeException;
import com.springsource.server.osgi.manifest.BundleManifest.ImportPackageHeader.PackageImport;


/**
 * {@link ContainingTrackedPackageImports} is used to collect a series of {@link TrackedPackageImports} into a containing source.
 * Only contained <code>TrackedPackageImports</code> should be merged into the containing <code>ContainingTrackedPackageImports</code>.
 * <p />
 * The contained sources are wrapped in the containing source name to show the nesting.
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is thread safe.
 *
 * @author Glyn Normington
 * @since 1.0
 */
public final class ContainingTrackedPackageImports extends AdditionalTrackedPackageImports {
    
    private final String containingSource;

    /**
     * Construct a {@link ContainingTrackedPackageImports}.
     * @param containingSource
     */
    public ContainingTrackedPackageImports(String containingSource) {
        super(new ArrayList<PackageImport>(), containingSource);
        this.containingSource = containingSource;
    }

    /** 
     * {@inheritDoc}
     */
    @Override public String getSources(String pkg) {
        return this.containingSource + "(" + super.getSources(pkg) + ")";
    }
    
    /** 
     * {@inheritDoc}
     */
    @Override public final void merge(TrackedPackageImports importsToMerge) throws ImportMergeException {
        super.merge(importsToMerge);
    }

}
