/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.support.merge;

import java.util.List;

import com.springsource.server.osgi.manifest.BundleManifest;
import com.springsource.server.osgi.manifest.BundleManifest.ImportPackageHeader.PackageImport;

/**
 * {@link StandardTrackedPackageImportsFactory} provides a standard way of creating {@link TrackedPackageImports}
 * instances.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public final class StandardTrackedPackageImportsFactory implements TrackedPackageImportsFactory {

    private static final EmptyTrackedPackageImports EMPTY_TRACKED_PACKAGE_IMPORTS = new EmptyTrackedPackageImports();

    /**
     * {@inheritDoc}
     */
    public TrackedPackageImports create(BundleManifest bundleManifest) {
        return new BundleTrackedPackageImports(bundleManifest);
    }

    /** 
     * {@inheritDoc}
     */
    public TrackedPackageImports create(List<PackageImport> packageImports, String source) {
        return new AdditionalTrackedPackageImports(packageImports, source);
    }

    /** 
     * {@inheritDoc}
     */
    public TrackedPackageImports createCollector() {
        return new CollectingTrackedPackageImports();
    }

    /** 
     * {@inheritDoc}
     */
    public TrackedPackageImports createContainer(String containingSource) {
        return new ContainingTrackedPackageImports(containingSource);
    }

    /** 
     * {@inheritDoc}
     */
    public TrackedPackageImports createEmpty() {
        return EMPTY_TRACKED_PACKAGE_IMPORTS;
    }

}
