/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.jar.Attributes;

/**
 * 
 * TODO Document ExportPackageDelegate
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * TODO Document concurrent semantics of ExportPackageDelegate
 * 
 * @author Christopher Frost
 * @since 1.0
 */
class ExportPackageDelegate implements Delegate {

    private static final String EXPORT_PACKAGE_HEADER_NAME = "Export-Package";

    private BundleManifest.ExportPackageHeader exportPackageHeader;

    private final Attributes mainAttributes;

    ExportPackageDelegate(Attributes mainAttributes, BundleManifestFactory bundleManifestFactory) {
        this.mainAttributes = mainAttributes;
        String creationValue = this.mainAttributes.getValue(EXPORT_PACKAGE_HEADER_NAME);
        if (creationValue != null) {
            this.exportPackageHeader = bundleManifestFactory.parseExportPackageHeader(creationValue);
        } else {
            this.exportPackageHeader = null;
        }
    }

    BundleManifest.ExportPackageHeader getExportPackageHeader() {
        return this.exportPackageHeader;
    }

    void setExportPackageHeader(BundleManifest.ExportPackageHeader exportPackageHeader) {
        this.exportPackageHeader = exportPackageHeader;
    }

    /**
     * If this header contains any values they are written out to the provided <code>Attributes</code>
     * 
     * @param outputAttributes
     */
    void write(Attributes outputAttributes) {
        if (this.exportPackageHeader != null) {
            this.exportPackageHeader.checkWellFormed();
            String value = this.exportPackageHeader.toString();
            if (value != null) {
                outputAttributes.putValue(EXPORT_PACKAGE_HEADER_NAME, value);
            } else {
                outputAttributes.remove(new Attributes.Name(EXPORT_PACKAGE_HEADER_NAME));
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final ExportPackageDelegate other = (ExportPackageDelegate) obj;
        if (this.exportPackageHeader == null) {
            if (other.exportPackageHeader != null) {
                return false;
            }
        } else if (!this.exportPackageHeader.equals(other.exportPackageHeader)) {
            return false;
        }
        return true;
    }

    public void checkHeaderValidity() {
        if (this.exportPackageHeader != null) {
            this.exportPackageHeader.checkWellFormed();
        }
    }

}
