/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.jar.Attributes;

import com.springsource.server.osgi.manifest.BundleManifest.FragmentHostHeader;

/**
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
class FragmentHostDelegate implements Delegate {

    private static final String FRAGMENT_HOST_HEADER_NAME = "Fragment-Host";

    private FragmentHostHeader fragmentHostHeader;

    private final Attributes mainAttributes;

    FragmentHostDelegate(Attributes mainAttributes, BundleManifestFactory bundleManifestFactory) {
        this.mainAttributes = mainAttributes;
        String creationValue = this.mainAttributes.getValue(FRAGMENT_HOST_HEADER_NAME);
        if (creationValue != null) {
            this.fragmentHostHeader = bundleManifestFactory.parseFragmentHostHeader(creationValue);
        } else {
            this.fragmentHostHeader = null;
        }
    }

    FragmentHostHeader getFragmentHostHeader() {
        return this.fragmentHostHeader;
    }

    void setFragmentHostHeader(FragmentHostHeader fragmentHostHeader) {
        this.fragmentHostHeader = fragmentHostHeader;
    }

    /**
     * If this header contains any values they are written out to the provided <code>Attributes</code>
     * 
     * @param outputAttributes
     */
    void write(Attributes outputAttributes) {
        if (this.fragmentHostHeader != null) {
            String value = this.fragmentHostHeader.toString();
            if (value != null) {
                outputAttributes.putValue(FRAGMENT_HOST_HEADER_NAME, value);
            } else {
                outputAttributes.remove(new Attributes.Name(FRAGMENT_HOST_HEADER_NAME));
            }
        }
    }

    /**
     * 
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final FragmentHostDelegate other = (FragmentHostDelegate) obj;
        if (this.fragmentHostHeader == null) {
            if (other.fragmentHostHeader != null) {
                return false;
            }
        } else if (!this.fragmentHostHeader.equals(other.fragmentHostHeader)) {
            return false;
        }
        return true;
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    public void checkHeaderValidity() {
        if (this.fragmentHostHeader != null) {
            this.fragmentHostHeader.checkWellFormed();
        }
    }
}
