/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.jar.Attributes;

import com.springsource.server.osgi.manifest.BundleManifest.ImportLibraryHeader;

/**
 * TODO Document ImportLibraryDelegate
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class ImportLibraryDelegate implements Delegate {

    private static final String IMPORT_LIBRARY_HEADER_NAME = "Import-Library";

    private ImportLibraryHeader importLibraryHeader;

    private final Attributes mainAttributes;

    ImportLibraryDelegate(Attributes mainAttributes, BundleManifestFactory bundleManifestFactory) {
        this.mainAttributes = mainAttributes;
        String creationValue = this.mainAttributes.getValue(IMPORT_LIBRARY_HEADER_NAME);
        if (creationValue != null) {
            this.importLibraryHeader = bundleManifestFactory.parseImportLibraryHeader(creationValue);
        } else {
            this.importLibraryHeader = null;
        }
    }

    ImportLibraryHeader getImportLibraryHeader() {
        return this.importLibraryHeader;
    }

    void setImportLibraryHeader(ImportLibraryHeader importLibraryHeader) {
        this.importLibraryHeader = importLibraryHeader;
    }

    /**
     * If this header contains any values they are written out to the provided <code>Attributes</code>
     * 
     * @param outputAttributes
     */
    void write(Attributes outputAttributes) {
        String value = null;
        if (this.importLibraryHeader != null) {
            value = this.importLibraryHeader.toString();
        }
        if (value != null) {
            outputAttributes.putValue(IMPORT_LIBRARY_HEADER_NAME, value);
        } else {
            outputAttributes.remove(new Attributes.Name(IMPORT_LIBRARY_HEADER_NAME));
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final ImportLibraryDelegate other = (ImportLibraryDelegate) obj;
        if (this.importLibraryHeader == null) {
            if (other.importLibraryHeader != null) {
                return false;
            }
        } else if (!this.importLibraryHeader.equals(other.importLibraryHeader)) {
            return false;
        }
        return true;
    }

    public void checkHeaderValidity() {
        if (this.importLibraryHeader != null) {
            this.importLibraryHeader.checkWellFormed();
        }
    }
}
