/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.jar.Attributes;

/**
 * 
 * TODO Document RequireBundleDelegate
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * TODO Document concurrent semantics of RequireBundleDelegate
 * 
 * @author Christopher Frost
 * @since 1.0
 */
class RequireBundleDelegate implements Delegate {

    private static final String REQUIRE_BUNDLE_HEADER_NAME = "Require-Bundle";

    private BundleManifest.RequireBundleHeader requireBundleHeader;

    private final Attributes mainAttributes;

    RequireBundleDelegate(Attributes mainAttributes, BundleManifestFactory bundleManifestFactory) {
        this.mainAttributes = mainAttributes;
        String creationValue = this.mainAttributes.getValue(REQUIRE_BUNDLE_HEADER_NAME);
        if (creationValue != null) {
            this.requireBundleHeader = bundleManifestFactory.parseRequireBundleHeader(creationValue);
        } else {
            this.requireBundleHeader = null;
        }
    }

    BundleManifest.RequireBundleHeader getRequireBundleHeader() {
        return this.requireBundleHeader;
    }

    void setRequireBundleHeader(BundleManifest.RequireBundleHeader requireBundleHeader) {
        this.requireBundleHeader = requireBundleHeader;
    }

    /**
     * If this header contains any values they are written out to the provided <code>Attributes</code>
     * 
     * @param outputAttributes
     */
    void write(Attributes outputAttributes) {
        if (this.requireBundleHeader != null) {
            String value = this.requireBundleHeader.toString();
            if (value != null) {
                outputAttributes.putValue(REQUIRE_BUNDLE_HEADER_NAME, value);
            } else {
                outputAttributes.remove(new Attributes.Name(REQUIRE_BUNDLE_HEADER_NAME));
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final RequireBundleDelegate other = (RequireBundleDelegate) obj;
        if (this.requireBundleHeader == null) {
            if (other.requireBundleHeader != null) {
                return false;
            }
        } else if (!this.requireBundleHeader.equals(other.requireBundleHeader)) {
            return false;
        }
        return true;
    }

    public void checkHeaderValidity() {
        if (this.requireBundleHeader != null) {
            this.requireBundleHeader.checkWellFormed();
        }
    }

}
