/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.ArrayList;
import java.util.List;

import com.springsource.server.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.server.osgi.manifest.parse.HeaderParser;
import com.springsource.server.osgi.manifest.parse.HeaderParserFactory;
import com.springsource.server.osgi.manifest.parse.ParseUtils;
import com.springsource.server.osgi.manifest.parse.ParserLogger;

public class StandardRequireBundleHeader implements BundleManifest.RequireBundleHeader {

    private static final String BUNDLE_SEPARATOR = ",";

    private List<BundleManifest.RequireBundleHeader.RequireBundle> requireBundles;

    /**
     * 
     * @param parserLogger
     * @param value
     */
    public StandardRequireBundleHeader(ParserLogger parserLogger, String value) {
        this.requireBundles = new ArrayList<BundleManifest.RequireBundleHeader.RequireBundle>();
        HeaderParser headerParser = HeaderParserFactory.newHeaderParser(parserLogger);
        List<HeaderDeclaration> requireBundleDeclarations = headerParser.parseRequireBundleHeader(value);
        for (HeaderDeclaration requireBundleDeclaration : requireBundleDeclarations) {
            this.requireBundles.add(new StandardRequireBundle(requireBundleDeclaration));
        }
    }

    /**
     * 
     * @param requiredBundles
     */
    public StandardRequireBundleHeader(List<RequireBundle> requiredBundles) {
        this.requireBundles = requiredBundles;
    }

    /**
     * 
     * {@inheritDoc}
     */
    public List<RequireBundle> getRequiredBundles() {
        return this.requireBundles;
    }

    /**
     * 
     * {@inheritDoc}
     */
    public void setRequiredBundles(List<RequireBundle> requireBundles) {
        this.requireBundles = requireBundles;

    }

    /**
     * 
     * {@inheritDoc}
     */
    public void checkWellFormed() {
        for (RequireBundle rb : this.requireBundles) {
            rb.checkWellFormed();
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        if (this.requireBundles.size() != 0) {
            StringBuffer result = new StringBuffer(20);
            result.append(ParseUtils.collectionToDelimitedString(this.requireBundles, BUNDLE_SEPARATOR));
            return result.toString();
        } else {
            return null;
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    /**
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof StandardRequireBundleHeader)) {
            return false;
        }
        final StandardRequireBundleHeader other = (StandardRequireBundleHeader) obj;
        if (!this.requireBundles.equals(other.requireBundles)) {
            return false;
        }
        return true;
    }

}
