/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest.parse;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.antlr.runtime.BaseRecognizer;
import org.antlr.runtime.BitSet;
import org.antlr.runtime.DFA;
import org.antlr.runtime.EarlyExitException;
import org.antlr.runtime.MismatchedSetException;
import org.antlr.runtime.NoViableAltException;
import org.antlr.runtime.Parser;
import org.antlr.runtime.ParserRuleReturnScope;
import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.Token;
import org.antlr.runtime.TokenStream;

public class OsgiHeaderParser extends Parser {
    public static final String[] tokenNames = new String[] {
        "<invalid>", "<EOR>", "<DOWN>", "<UP>", "QUOTED_STRING", "STAR", "ALPHA", "DIGIT", "DOTSTAR", "WS", "','", "';'", "':='", "'='", "'/'", "'-'", "'_'", "'.'", "'+'", "'!'", "'\\''", "'('", "')'", "'$'"
    };
    public static final int QUOTED_STRING=4;
    public static final int WS=9;
    public static final int EOF=-1;
    public static final int ALPHA=6;
    public static final int DOTSTAR=8;
    public static final int DIGIT=7;
    public static final int STAR=5;

        public OsgiHeaderParser(TokenStream input) {
            super(input);
        }
        

    public String[] getTokenNames() { return tokenNames; }
    public String getGrammarFileName() { return "/Users/awilkinson/Documents/dev/tm/engine/com.springsource.server.osgi/com.springsource.server.osgi.manifest/src/main/java/com/springsource/server/osgi/manifest/parse/OsgiHeader.g"; }



    private List<String> names; 
    private Map<String, String> attributes;
    private Map<String, String> directives = new HashMap<String, String>();
    protected List<HeaderDeclaration> declarations = new ArrayList<HeaderDeclaration>();
        
    protected void displayError(RecognitionException e){
    }
        



    public final void header() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_pkgDecl_in_header57);
            pkgDecl();
            _fsp--;

            loop1:
            do {
                int alt1=2;
                int LA1_0 = input.LA(1);

                if ( (LA1_0==10) ) {
                    alt1=1;
                }


                switch (alt1) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_header60); 
                    pushFollow(FOLLOW_pkgDecl_in_header62);
                    pkgDecl();
                    _fsp--;


                    }
                    break;

                default :
                    break loop1;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void pkgDecl() throws RecognitionException {

        this.names = new ArrayList<String>();
        this.attributes = new HashMap<String, String>();
        this.directives = new HashMap<String, String>();

        try {
            {
            pushFollow(FOLLOW_packageNames_in_pkgDecl88);
            packageNames();
            _fsp--;

            loop2:
            do {
                int alt2=2;
                int LA2_0 = input.LA(1);

                if ( (LA2_0==11) ) {
                    alt2=1;
                }


                switch (alt2) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_pkgDecl92); 
                    pushFollow(FOLLOW_parameter_in_pkgDecl94);
                    parameter();
                    _fsp--;


                    }
                    break;

                default :
                    break loop2;
                }
            } while (true);


            }


            this.declarations.add(new ImmutableHeaderDeclaration(this.names, this.attributes, this.directives));

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void packageNames() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_packageName_in_packageNames108);
            packageName();
            _fsp--;

            loop3:
            do {
                int alt3=2;
                alt3 = dfa3.predict(input);
                switch (alt3) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_packageNames111); 
                    pushFollow(FOLLOW_packageName_in_packageNames113);
                    packageName();
                    _fsp--;


                    }
                    break;

                default :
                    break loop3;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void dynHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_dynPkgDecl_in_dynHeader129);
            dynPkgDecl();
            _fsp--;

            loop4:
            do {
                int alt4=2;
                int LA4_0 = input.LA(1);

                if ( (LA4_0==10) ) {
                    alt4=1;
                }


                switch (alt4) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_dynHeader132); 
                    pushFollow(FOLLOW_dynPkgDecl_in_dynHeader134);
                    dynPkgDecl();
                    _fsp--;


                    }
                    break;

                default :
                    break loop4;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void dynPkgDecl() throws RecognitionException {

        this.names = new ArrayList<String>();
        this.attributes = new HashMap<String, String>();
        this.directives = new HashMap<String, String>();

        try {
            {
            pushFollow(FOLLOW_dynPackageNames_in_dynPkgDecl160);
            dynPackageNames();
            _fsp--;

            loop5:
            do {
                int alt5=2;
                int LA5_0 = input.LA(1);

                if ( (LA5_0==11) ) {
                    alt5=1;
                }


                switch (alt5) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_dynPkgDecl164); 
                    pushFollow(FOLLOW_parameter_in_dynPkgDecl166);
                    parameter();
                    _fsp--;


                    }
                    break;

                default :
                    break loop5;
                }
            } while (true);


            }


            this.declarations.add(new ImmutableHeaderDeclaration(this.names, this.attributes, this.directives));

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void dynPackageNames() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_dynPackageName_in_dynPackageNames180);
            dynPackageName();
            _fsp--;

            loop6:
            do {
                int alt6=2;
                alt6 = dfa6.predict(input);
                switch (alt6) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_dynPackageNames183); 
                    pushFollow(FOLLOW_dynPackageName_in_dynPackageNames185);
                    dynPackageName();
                    _fsp--;


                    }
                    break;

                default :
                    break loop6;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void dynPackageName() throws RecognitionException {
        try {
            int alt7=3;
            alt7 = dfa7.predict(input);
            switch (alt7) {
                case 1 :
                    {
                    pushFollow(FOLLOW_wildcardedPackageName_in_dynPackageName206);
                    wildcardedPackageName();
                    _fsp--;


                    }
                    break;
                case 2 :
                    {
                    pushFollow(FOLLOW_star_in_dynPackageName212);
                    star();
                    _fsp--;


                    }
                    break;
                case 3 :
                    {
                    pushFollow(FOLLOW_packageName_in_dynPackageName218);
                    packageName();
                    _fsp--;


                    }
                    break;

            }
        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void requireBundleHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_requireBundleHeader234);
            bundleDescription();
            _fsp--;

            loop8:
            do {
                int alt8=2;
                int LA8_0 = input.LA(1);

                if ( (LA8_0==10) ) {
                    alt8=1;
                }


                switch (alt8) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_requireBundleHeader237); 
                    pushFollow(FOLLOW_bundleDescription_in_requireBundleHeader239);
                    bundleDescription();
                    _fsp--;


                    }
                    break;

                default :
                    break loop8;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void bundleDescription() throws RecognitionException {

        this.names = new ArrayList<String>();
        this.attributes = new HashMap<String, String>();
        this.directives = new HashMap<String, String>();

        try {
            {
            pushFollow(FOLLOW_symbolicName_in_bundleDescription276);
            symbolicName();
            _fsp--;

            loop9:
            do {
                int alt9=2;
                int LA9_0 = input.LA(1);

                if ( (LA9_0==11) ) {
                    alt9=1;
                }


                switch (alt9) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_bundleDescription279); 
                    pushFollow(FOLLOW_parameter_in_bundleDescription281);
                    parameter();
                    _fsp--;


                    }
                    break;

                default :
                    break loop9;
                }
            } while (true);


            }


            this.declarations.add(new ImmutableHeaderDeclaration(this.names, this.attributes, this.directives));

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void symbolicName() throws RecognitionException {
        identifier_return identifier1 = null;


        try {
            {
            pushFollow(FOLLOW_identifier_in_symbolicName304);
            identifier1=identifier();
            _fsp--;

            this.names.add(input.toString(identifier1.start,identifier1.stop));

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void fragmentHostHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_fragmentHostHeader324);
            bundleDescription();
            _fsp--;


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void bundleSymbolicNameHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_bundleSymbolicNameHeader342);
            bundleDescription();
            _fsp--;


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void importBundleHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_importBundleHeader393);
            bundleDescription();
            _fsp--;

            loop10:
            do {
                int alt10=2;
                int LA10_0 = input.LA(1);

                if ( (LA10_0==10) ) {
                    alt10=1;
                }


                switch (alt10) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_importBundleHeader396); 
                    pushFollow(FOLLOW_bundleDescription_in_importBundleHeader398);
                    bundleDescription();
                    _fsp--;


                    }
                    break;

                default :
                    break loop10;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void importLibraryHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_importLibraryHeader452);
            bundleDescription();
            _fsp--;

            loop11:
            do {
                int alt11=2;
                int LA11_0 = input.LA(1);

                if ( (LA11_0==10) ) {
                    alt11=1;
                }


                switch (alt11) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_importLibraryHeader455); 
                    pushFollow(FOLLOW_bundleDescription_in_importLibraryHeader457);
                    bundleDescription();
                    _fsp--;


                    }
                    break;

                default :
                    break loop11;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void librarySymbolicNameHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_librarySymbolicNameHeader513);
            bundleDescription();
            _fsp--;


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void webContextParamsHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_webContextParamsHeader562);
            bundleDescription();
            _fsp--;

            loop12:
            do {
                int alt12=2;
                int LA12_0 = input.LA(1);

                if ( (LA12_0==10) ) {
                    alt12=1;
                }


                switch (alt12) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_webContextParamsHeader565); 
                    pushFollow(FOLLOW_bundleDescription_in_webContextParamsHeader567);
                    bundleDescription();
                    _fsp--;


                    }
                    break;

                default :
                    break loop12;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void webFilterMappingsHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_webFilterMappingsHeader619);
            bundleDescription();
            _fsp--;

            loop13:
            do {
                int alt13=2;
                int LA13_0 = input.LA(1);

                if ( (LA13_0==10) ) {
                    alt13=1;
                }


                switch (alt13) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_webFilterMappingsHeader622); 
                    pushFollow(FOLLOW_bundleDescription_in_webFilterMappingsHeader624);
                    bundleDescription();
                    _fsp--;


                    }
                    break;

                default :
                    break loop13;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void webServletsHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_bundleDescription_in_webServletsHeader676);
            bundleDescription();
            _fsp--;

            loop14:
            do {
                int alt14=2;
                int LA14_0 = input.LA(1);

                if ( (LA14_0==10) ) {
                    alt14=1;
                }


                switch (alt14) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_webServletsHeader679); 
                    pushFollow(FOLLOW_bundleDescription_in_webServletsHeader681);
                    bundleDescription();
                    _fsp--;


                    }
                    break;

                default :
                    break loop14;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void webErrorPagesHeader() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_webErrorPageDeclaration_in_webErrorPagesHeader733);
            webErrorPageDeclaration();
            _fsp--;

            loop15:
            do {
                int alt15=2;
                int LA15_0 = input.LA(1);

                if ( (LA15_0==10) ) {
                    alt15=1;
                }


                switch (alt15) {
                case 1 :
                    {
                    match(input,10,FOLLOW_10_in_webErrorPagesHeader736); 
                    pushFollow(FOLLOW_webErrorPageDeclaration_in_webErrorPagesHeader738);
                    webErrorPageDeclaration();
                    _fsp--;


                    }
                    break;

                default :
                    break loop15;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void webErrorPageDeclaration() throws RecognitionException {

        this.names = new ArrayList<String>();
        this.attributes = new HashMap<String, String>();
        this.directives = new HashMap<String, String>();

        try {
            {
            pushFollow(FOLLOW_webErrorPages_in_webErrorPageDeclaration802);
            webErrorPages();
            _fsp--;

            loop16:
            do {
                int alt16=2;
                int LA16_0 = input.LA(1);

                if ( (LA16_0==11) ) {
                    alt16=1;
                }


                switch (alt16) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_webErrorPageDeclaration806); 
                    pushFollow(FOLLOW_parameter_in_webErrorPageDeclaration808);
                    parameter();
                    _fsp--;


                    }
                    break;

                default :
                    break loop16;
                }
            } while (true);


            }


            this.declarations.add(new ImmutableHeaderDeclaration(this.names, this.attributes, this.directives));

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void webErrorPages() throws RecognitionException {
        try {
            {
            pushFollow(FOLLOW_webErrorPage_in_webErrorPages822);
            webErrorPage();
            _fsp--;

            loop17:
            do {
                int alt17=2;
                alt17 = dfa17.predict(input);
                switch (alt17) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_webErrorPages825); 
                    pushFollow(FOLLOW_webErrorPage_in_webErrorPages827);
                    webErrorPage();
                    _fsp--;


                    }
                    break;

                default :
                    break loop17;
                }
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void webErrorPage() throws RecognitionException {
        filePath_return filePath2 = null;


        try {
            {
            pushFollow(FOLLOW_filePath_in_webErrorPage845);
            filePath2=filePath();
            _fsp--;

            this.names.add(input.toString(filePath2.start,filePath2.stop));

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void bundleActivationPolicyHeader() throws RecognitionException {

            this.names = new ArrayList<String>();
            this.attributes = new HashMap<String, String>();
            this.directives = new HashMap<String, String>();

        try {
            {
            pushFollow(FOLLOW_activationPolicy_in_bundleActivationPolicyHeader876);
            activationPolicy();
            _fsp--;

            loop18:
            do {
                int alt18=2;
                int LA18_0 = input.LA(1);

                if ( (LA18_0==11) ) {
                    alt18=1;
                }


                switch (alt18) {
                case 1 :
                    {
                    match(input,11,FOLLOW_11_in_bundleActivationPolicyHeader879); 
                    pushFollow(FOLLOW_directive_in_bundleActivationPolicyHeader881);
                    directive();
                    _fsp--;


                    }
                    break;

                default :
                    break loop18;
                }
            } while (true);


            }


                this.declarations.add(new ImmutableHeaderDeclaration(this.names, this.attributes, this.directives));

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void activationPolicy() throws RecognitionException {
        identifier_return identifier3 = null;


        try {
            {
            pushFollow(FOLLOW_identifier_in_activationPolicy928);
            identifier3=identifier();
            _fsp--;

            this.names.add(input.toString(identifier3.start,identifier3.stop));

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void parameter() throws RecognitionException {
        try {
            int alt19=2;
            alt19 = dfa19.predict(input);
            switch (alt19) {
                case 1 :
                    {
                    pushFollow(FOLLOW_directive_in_parameter946);
                    directive();
                    _fsp--;


                    }
                    break;
                case 2 :
                    {
                    pushFollow(FOLLOW_attribute_in_parameter950);
                    attribute();
                    _fsp--;


                    }
                    break;

            }
        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void directive() throws RecognitionException {
        identifier_return identifier4 = null;

        argument_return argument5 = null;


        try {
            {
            pushFollow(FOLLOW_identifier_in_directive962);
            identifier4=identifier();
            _fsp--;

            match(input,12,FOLLOW_12_in_directive964); 
            pushFollow(FOLLOW_argument_in_directive966);
            argument5=argument();
            _fsp--;

            this.directives.put(input.toString(identifier4.start,identifier4.stop), input.toString(argument5.start,argument5.stop));

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void attribute() throws RecognitionException {
        identifier_return identifier6 = null;

        argument_return argument7 = null;


        try {
            {
            pushFollow(FOLLOW_identifier_in_attribute979);
            identifier6=identifier();
            _fsp--;

            match(input,13,FOLLOW_13_in_attribute981); 
            pushFollow(FOLLOW_argument_in_attribute983);
            argument7=argument();
            _fsp--;

            this.attributes.put(input.toString(identifier6.start,identifier6.stop), input.toString(argument7.start,argument7.stop));

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }

    public static class argument_return extends ParserRuleReturnScope {
    };

    public final argument_return argument() throws RecognitionException {
        argument_return retval = new argument_return();
        retval.start = input.LT(1);

        try {
            int alt20=2;
            int LA20_0 = input.LA(1);

            if ( ((LA20_0>=ALPHA && LA20_0<=DIGIT)||(LA20_0>=15 && LA20_0<=16)) ) {
                alt20=1;
            }
            else if ( (LA20_0==QUOTED_STRING) ) {
                alt20=2;
            }
            else {
                NoViableAltException nvae =
                    new NoViableAltException("208:1: argument : ( identifier | QUOTED_STRING );", 20, 0, input);

                throw nvae;
            }
            switch (alt20) {
                case 1 :
                    {
                    pushFollow(FOLLOW_identifier_in_argument997);
                    identifier();
                    _fsp--;


                    }
                    break;
                case 2 :
                    {
                    match(input,QUOTED_STRING,FOLLOW_QUOTED_STRING_in_argument1001); 

                    }
                    break;

            }
            retval.stop = input.LT(-1);

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return retval;
    }


    public final void packageName() throws RecognitionException {
        packageIdentifier_return packageIdentifier8 = null;


        try {
            {
            pushFollow(FOLLOW_packageIdentifier_in_packageName1015);
            packageIdentifier8=packageIdentifier();
            _fsp--;

            this.names.add(input.toString(packageIdentifier8.start,packageIdentifier8.stop));

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void wildcardedPackageName() throws RecognitionException {
        wildPackageIdentifier_return wildPackageIdentifier9 = null;


        try {
            {
            pushFollow(FOLLOW_wildPackageIdentifier_in_wildcardedPackageName1028);
            wildPackageIdentifier9=wildPackageIdentifier();
            _fsp--;

            this.names.add(input.toString(wildPackageIdentifier9.start,wildPackageIdentifier9.stop));

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void star() throws RecognitionException {
        Token STAR10=null;

        try {
            {
            STAR10=(Token)input.LT(1);
            match(input,STAR,FOLLOW_STAR_in_star1042); 
            this.names.add(STAR10.getText());

            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }

    public static class filePath_return extends ParserRuleReturnScope {
    };

    public final filePath_return filePath() throws RecognitionException {
        filePath_return retval = new filePath_return();
        retval.start = input.LT(1);

        try {
            {
            loop21:
            do {
                int alt21=2;
                int LA21_0 = input.LA(1);

                if ( (LA21_0==14) ) {
                    alt21=1;
                }


                switch (alt21) {
                case 1 :
                    {
                    match(input,14,FOLLOW_14_in_filePath1109); 

                    }
                    break;

                default :
                    break loop21;
                }
            } while (true);

            pushFollow(FOLLOW_filePathPart_in_filePath1113);
            filePathPart();
            _fsp--;

            loop22:
            do {
                int alt22=2;
                int LA22_0 = input.LA(1);

                if ( (LA22_0==14) ) {
                    alt22=1;
                }


                switch (alt22) {
                case 1 :
                    {
                    match(input,14,FOLLOW_14_in_filePath1116); 
                    pushFollow(FOLLOW_filePathPart_in_filePath1118);
                    filePathPart();
                    _fsp--;


                    }
                    break;

                default :
                    break loop22;
                }
            } while (true);


            }

            retval.stop = input.LT(-1);

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return retval;
    }


    public final void filePathPart() throws RecognitionException {
        try {
            {
            int cnt23=0;
            loop23:
            do {
                int alt23=2;
                int LA23_0 = input.LA(1);

                if ( ((LA23_0>=ALPHA && LA23_0<=DIGIT)||(LA23_0>=15 && LA23_0<=22)) ) {
                    alt23=1;
                }


                switch (alt23) {
                case 1 :
                    {
                    if ( (input.LA(1)>=ALPHA && input.LA(1)<=DIGIT)||(input.LA(1)>=15 && input.LA(1)<=22) ) {
                        input.consume();
                        errorRecovery=false;
                    }
                    else {
                        MismatchedSetException mse =
                            new MismatchedSetException(null,input);
                        recoverFromMismatchedSet(input,mse,FOLLOW_set_in_filePathPart1142);    throw mse;
                    }


                    }
                    break;

                default :
                    if ( cnt23 >= 1 ) break loop23;
                        EarlyExitException eee =
                            new EarlyExitException(23, input);
                        throw eee;
                }
                cnt23++;
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }

    public static class identifier_return extends ParserRuleReturnScope {
    };

    public final identifier_return identifier() throws RecognitionException {
        identifier_return retval = new identifier_return();
        retval.start = input.LT(1);

        try {
            {
            pushFollow(FOLLOW_identifierPart_in_identifier1197);
            identifierPart();
            _fsp--;

            loop24:
            do {
                int alt24=2;
                int LA24_0 = input.LA(1);

                if ( (LA24_0==17) ) {
                    alt24=1;
                }


                switch (alt24) {
                case 1 :
                    {
                    match(input,17,FOLLOW_17_in_identifier1200); 
                    pushFollow(FOLLOW_identifierPart_in_identifier1202);
                    identifierPart();
                    _fsp--;


                    }
                    break;

                default :
                    break loop24;
                }
            } while (true);


            }

            retval.stop = input.LT(-1);

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return retval;
    }

    public static class packageIdentifier_return extends ParserRuleReturnScope {
    };

    public final packageIdentifier_return packageIdentifier() throws RecognitionException {
        packageIdentifier_return retval = new packageIdentifier_return();
        retval.start = input.LT(1);

        try {
            {
            pushFollow(FOLLOW_packageIdentifierPart_in_packageIdentifier1217);
            packageIdentifierPart();
            _fsp--;

            loop25:
            do {
                int alt25=2;
                int LA25_0 = input.LA(1);

                if ( (LA25_0==17) ) {
                    alt25=1;
                }


                switch (alt25) {
                case 1 :
                    {
                    match(input,17,FOLLOW_17_in_packageIdentifier1220); 
                    pushFollow(FOLLOW_packageIdentifierPart_in_packageIdentifier1222);
                    packageIdentifierPart();
                    _fsp--;


                    }
                    break;

                default :
                    break loop25;
                }
            } while (true);


            }

            retval.stop = input.LT(-1);

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return retval;
    }

    public static class wildPackageIdentifier_return extends ParserRuleReturnScope {
    };

    public final wildPackageIdentifier_return wildPackageIdentifier() throws RecognitionException {
        wildPackageIdentifier_return retval = new wildPackageIdentifier_return();
        retval.start = input.LT(1);

        try {
            {
            pushFollow(FOLLOW_packageIdentifierPart_in_wildPackageIdentifier1237);
            packageIdentifierPart();
            _fsp--;

            loop26:
            do {
                int alt26=2;
                int LA26_0 = input.LA(1);

                if ( (LA26_0==17) ) {
                    alt26=1;
                }


                switch (alt26) {
                case 1 :
                    {
                    match(input,17,FOLLOW_17_in_wildPackageIdentifier1240); 
                    pushFollow(FOLLOW_packageIdentifierPart_in_wildPackageIdentifier1242);
                    packageIdentifierPart();
                    _fsp--;


                    }
                    break;

                default :
                    break loop26;
                }
            } while (true);

            match(input,DOTSTAR,FOLLOW_DOTSTAR_in_wildPackageIdentifier1247); 

            }

            retval.stop = input.LT(-1);

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return retval;
    }


    public final void identifierPart() throws RecognitionException {
        try {
            {
            int cnt27=0;
            loop27:
            do {
                int alt27=2;
                int LA27_0 = input.LA(1);

                if ( ((LA27_0>=ALPHA && LA27_0<=DIGIT)||(LA27_0>=15 && LA27_0<=16)) ) {
                    alt27=1;
                }


                switch (alt27) {
                case 1 :
                    {
                    if ( (input.LA(1)>=ALPHA && input.LA(1)<=DIGIT)||(input.LA(1)>=15 && input.LA(1)<=16) ) {
                        input.consume();
                        errorRecovery=false;
                    }
                    else {
                        MismatchedSetException mse =
                            new MismatchedSetException(null,input);
                        recoverFromMismatchedSet(input,mse,FOLLOW_set_in_identifierPart1259);    throw mse;
                    }


                    }
                    break;

                default :
                    if ( cnt27 >= 1 ) break loop27;
                        EarlyExitException eee =
                            new EarlyExitException(27, input);
                        throw eee;
                }
                cnt27++;
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    public final void packageIdentifierPart() throws RecognitionException {
        try {
            {
            int cnt28=0;
            loop28:
            do {
                int alt28=2;
                int LA28_0 = input.LA(1);

                if ( ((LA28_0>=ALPHA && LA28_0<=DIGIT)||LA28_0==16||LA28_0==23) ) {
                    alt28=1;
                }


                switch (alt28) {
                case 1 :
                    {
                    if ( (input.LA(1)>=ALPHA && input.LA(1)<=DIGIT)||input.LA(1)==16||input.LA(1)==23 ) {
                        input.consume();
                        errorRecovery=false;
                    }
                    else {
                        MismatchedSetException mse =
                            new MismatchedSetException(null,input);
                        recoverFromMismatchedSet(input,mse,FOLLOW_set_in_packageIdentifierPart1286);    throw mse;
                    }


                    }
                    break;

                default :
                    if ( cnt28 >= 1 ) break loop28;
                        EarlyExitException eee =
                            new EarlyExitException(28, input);
                        throw eee;
                }
                cnt28++;
            } while (true);


            }

        }

        catch(RecognitionException e) {
            input.consume();
            displayError(e);
        }
        finally {
        }
        return ;
    }


    protected DFA3 dfa3 = new DFA3(this);
    protected DFA6 dfa6 = new DFA6(this);
    protected DFA7 dfa7 = new DFA7(this);
    protected DFA17 dfa17 = new DFA17(this);
    protected DFA19 dfa19 = new DFA19(this);
    static final String DFA3_eotS =
        "\7\uffff";
    static final String DFA3_eofS =
        "\1\2\2\uffff\1\4\2\uffff\1\4";
    static final String DFA3_minS =
        "\1\12\1\6\1\uffff\1\6\1\uffff\2\6";
    static final String DFA3_maxS =
        "\1\13\1\27\1\uffff\1\27\1\uffff\2\27";
    static final String DFA3_acceptS =
        "\2\uffff\1\2\1\uffff\1\1\2\uffff";
    static final String DFA3_specialS =
        "\7\uffff}>";
    static final String[] DFA3_transitionS = {
            "\1\2\1\1",
            "\2\3\7\uffff\1\2\1\3\6\uffff\1\4",
            "",
            "\2\3\2\uffff\2\4\2\2\1\uffff\1\2\1\3\1\5\5\uffff\1\4",
            "",
            "\2\6\7\uffff\1\2\1\6\6\uffff\1\4",
            "\2\6\2\uffff\2\4\2\2\1\uffff\1\2\1\6\1\5\5\uffff\1\4"
    };

    static final short[] DFA3_eot = DFA.unpackEncodedString(DFA3_eotS);
    static final short[] DFA3_eof = DFA.unpackEncodedString(DFA3_eofS);
    static final char[] DFA3_min = DFA.unpackEncodedStringToUnsignedChars(DFA3_minS);
    static final char[] DFA3_max = DFA.unpackEncodedStringToUnsignedChars(DFA3_maxS);
    static final short[] DFA3_accept = DFA.unpackEncodedString(DFA3_acceptS);
    static final short[] DFA3_special = DFA.unpackEncodedString(DFA3_specialS);
    static final short[][] DFA3_transition;

    static {
        int numStates = DFA3_transitionS.length;
        DFA3_transition = new short[numStates][];
        for (int i=0; i<numStates; i++) {
            DFA3_transition[i] = DFA.unpackEncodedString(DFA3_transitionS[i]);
        }
    }

    class DFA3 extends DFA {

        public DFA3(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 3;
            this.eot = DFA3_eot;
            this.eof = DFA3_eof;
            this.min = DFA3_min;
            this.max = DFA3_max;
            this.accept = DFA3_accept;
            this.special = DFA3_special;
            this.transition = DFA3_transition;
        }
        public String getDescription() {
            return "()* loopback of 59:16: ( ';' packageName )*";
        }
    }
    static final String DFA6_eotS =
        "\7\uffff";
    static final String DFA6_eofS =
        "\1\2\2\uffff\1\4\2\uffff\1\4";
    static final String DFA6_minS =
        "\1\12\1\5\1\uffff\1\6\1\uffff\2\6";
    static final String DFA6_maxS =
        "\1\13\1\27\1\uffff\1\27\1\uffff\2\27";
    static final String DFA6_acceptS =
        "\2\uffff\1\2\1\uffff\1\1\2\uffff";
    static final String DFA6_specialS =
        "\7\uffff}>";
    static final String[] DFA6_transitionS = {
            "\1\2\1\1",
            "\1\4\2\3\7\uffff\1\2\1\3\6\uffff\1\4",
            "",
            "\2\3\1\4\1\uffff\2\4\2\2\1\uffff\1\2\1\3\1\5\5\uffff\1\4",
            "",
            "\2\6\7\uffff\1\2\1\6\6\uffff\1\4",
            "\2\6\1\4\1\uffff\2\4\2\2\1\uffff\1\2\1\6\1\5\5\uffff\1\4"
    };

    static final short[] DFA6_eot = DFA.unpackEncodedString(DFA6_eotS);
    static final short[] DFA6_eof = DFA.unpackEncodedString(DFA6_eofS);
    static final char[] DFA6_min = DFA.unpackEncodedStringToUnsignedChars(DFA6_minS);
    static final char[] DFA6_max = DFA.unpackEncodedStringToUnsignedChars(DFA6_maxS);
    static final short[] DFA6_accept = DFA.unpackEncodedString(DFA6_acceptS);
    static final short[] DFA6_special = DFA.unpackEncodedString(DFA6_specialS);
    static final short[][] DFA6_transition;

    static {
        int numStates = DFA6_transitionS.length;
        DFA6_transition = new short[numStates][];
        for (int i=0; i<numStates; i++) {
            DFA6_transition[i] = DFA.unpackEncodedString(DFA6_transitionS[i]);
        }
    }

    class DFA6 extends DFA {

        public DFA6(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 6;
            this.eot = DFA6_eot;
            this.eof = DFA6_eof;
            this.min = DFA6_min;
            this.max = DFA6_max;
            this.accept = DFA6_accept;
            this.special = DFA6_special;
            this.transition = DFA6_transition;
        }
        public String getDescription() {
            return "()* loopback of 79:19: ( ';' dynPackageName )*";
        }
    }
    static final String DFA7_eotS =
        "\7\uffff";
    static final String DFA7_eofS =
        "\1\uffff\1\5\4\uffff\1\5";
    static final String DFA7_minS =
        "\1\5\1\6\1\uffff\1\6\2\uffff\1\6";
    static final String DFA7_maxS =
        "\2\27\1\uffff\1\27\2\uffff\1\27";
    static final String DFA7_acceptS =
        "\2\uffff\1\2\1\uffff\1\1\1\3\1\uffff";
    static final String DFA7_specialS =
        "\7\uffff}>";
    static final String[] DFA7_transitionS = {
            "\1\2\2\1\10\uffff\1\1\6\uffff\1\1",
            "\2\1\1\4\1\uffff\2\5\4\uffff\1\1\1\3\5\uffff\1\1",
            "",
            "\2\6\10\uffff\1\6\6\uffff\1\6",
            "",
            "",
            "\2\6\1\4\1\uffff\2\5\4\uffff\1\6\1\3\5\uffff\1\6"
    };

    static final short[] DFA7_eot = DFA.unpackEncodedString(DFA7_eotS);
    static final short[] DFA7_eof = DFA.unpackEncodedString(DFA7_eofS);
    static final char[] DFA7_min = DFA.unpackEncodedStringToUnsignedChars(DFA7_minS);
    static final char[] DFA7_max = DFA.unpackEncodedStringToUnsignedChars(DFA7_maxS);
    static final short[] DFA7_accept = DFA.unpackEncodedString(DFA7_acceptS);
    static final short[] DFA7_special = DFA.unpackEncodedString(DFA7_specialS);
    static final short[][] DFA7_transition;

    static {
        int numStates = DFA7_transitionS.length;
        DFA7_transition = new short[numStates][];
        for (int i=0; i<numStates; i++) {
            DFA7_transition[i] = DFA.unpackEncodedString(DFA7_transitionS[i]);
        }
    }

    class DFA7 extends DFA {

        public DFA7(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 7;
            this.eot = DFA7_eot;
            this.eof = DFA7_eof;
            this.min = DFA7_min;
            this.max = DFA7_max;
            this.accept = DFA7_accept;
            this.special = DFA7_special;
            this.transition = DFA7_transition;
        }
        public String getDescription() {
            return "82:1: dynPackageName : ( wildcardedPackageName | star | packageName );";
        }
    }
    static final String DFA17_eotS =
        "\7\uffff";
    static final String DFA17_eofS =
        "\1\2\2\uffff\1\4\1\uffff\2\4";
    static final String DFA17_minS =
        "\1\12\1\6\1\uffff\1\6\1\uffff\2\6";
    static final String DFA17_maxS =
        "\1\13\1\26\1\uffff\1\26\1\uffff\2\26";
    static final String DFA17_acceptS =
        "\2\uffff\1\2\1\uffff\1\1\2\uffff";
    static final String DFA17_specialS =
        "\7\uffff}>";
    static final String[] DFA17_transitionS = {
            "\1\2\1\1",
            "\2\3\6\uffff\1\4\2\3\6\4",
            "",
            "\2\3\2\uffff\2\4\2\2\1\4\2\3\1\5\5\4",
            "",
            "\2\6\2\uffff\2\4\2\uffff\1\4\2\6\6\4",
            "\2\6\2\uffff\2\4\2\2\1\4\2\6\1\5\5\4"
    };

    static final short[] DFA17_eot = DFA.unpackEncodedString(DFA17_eotS);
    static final short[] DFA17_eof = DFA.unpackEncodedString(DFA17_eofS);
    static final char[] DFA17_min = DFA.unpackEncodedStringToUnsignedChars(DFA17_minS);
    static final char[] DFA17_max = DFA.unpackEncodedStringToUnsignedChars(DFA17_maxS);
    static final short[] DFA17_accept = DFA.unpackEncodedString(DFA17_acceptS);
    static final short[] DFA17_special = DFA.unpackEncodedString(DFA17_specialS);
    static final short[][] DFA17_transition;

    static {
        int numStates = DFA17_transitionS.length;
        DFA17_transition = new short[numStates][];
        for (int i=0; i<numStates; i++) {
            DFA17_transition[i] = DFA.unpackEncodedString(DFA17_transitionS[i]);
        }
    }

    class DFA17 extends DFA {

        public DFA17(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 17;
            this.eot = DFA17_eot;
            this.eof = DFA17_eof;
            this.min = DFA17_min;
            this.max = DFA17_max;
            this.accept = DFA17_accept;
            this.special = DFA17_special;
            this.transition = DFA17_transition;
        }
        public String getDescription() {
            return "()* loopback of 173:17: ( ';' webErrorPage )*";
        }
    }
    static final String DFA19_eotS =
        "\6\uffff";
    static final String DFA19_eofS =
        "\6\uffff";
    static final String DFA19_minS =
        "\3\6\2\uffff\1\6";
    static final String DFA19_maxS =
        "\1\20\1\21\1\20\2\uffff\1\21";
    static final String DFA19_acceptS =
        "\3\uffff\1\2\1\1\1\uffff";
    static final String DFA19_specialS =
        "\6\uffff}>";
    static final String[] DFA19_transitionS = {
            "\2\1\7\uffff\2\1",
            "\2\1\4\uffff\1\4\1\3\1\uffff\2\1\1\2",
            "\2\5\7\uffff\2\5",
            "",
            "",
            "\2\5\4\uffff\1\4\1\3\1\uffff\2\5\1\2"
    };

    static final short[] DFA19_eot = DFA.unpackEncodedString(DFA19_eotS);
    static final short[] DFA19_eof = DFA.unpackEncodedString(DFA19_eofS);
    static final char[] DFA19_min = DFA.unpackEncodedStringToUnsignedChars(DFA19_minS);
    static final char[] DFA19_max = DFA.unpackEncodedStringToUnsignedChars(DFA19_maxS);
    static final short[] DFA19_accept = DFA.unpackEncodedString(DFA19_acceptS);
    static final short[] DFA19_special = DFA.unpackEncodedString(DFA19_specialS);
    static final short[][] DFA19_transition;

    static {
        int numStates = DFA19_transitionS.length;
        DFA19_transition = new short[numStates][];
        for (int i=0; i<numStates; i++) {
            DFA19_transition[i] = DFA.unpackEncodedString(DFA19_transitionS[i]);
        }
    }

    class DFA19 extends DFA {

        public DFA19(BaseRecognizer recognizer) {
            this.recognizer = recognizer;
            this.decisionNumber = 19;
            this.eot = DFA19_eot;
            this.eof = DFA19_eof;
            this.min = DFA19_min;
            this.max = DFA19_max;
            this.accept = DFA19_accept;
            this.special = DFA19_special;
            this.transition = DFA19_transition;
        }
        public String getDescription() {
            return "196:1: parameter : ( directive | attribute );";
        }
    }
 

    public static final BitSet FOLLOW_pkgDecl_in_header57 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_header60 = new BitSet(new long[]{0x00000000008100C0L});
    public static final BitSet FOLLOW_pkgDecl_in_header62 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_packageNames_in_pkgDecl88 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_pkgDecl92 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_parameter_in_pkgDecl94 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_packageName_in_packageNames108 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_packageNames111 = new BitSet(new long[]{0x00000000008100C0L});
    public static final BitSet FOLLOW_packageName_in_packageNames113 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_dynPkgDecl_in_dynHeader129 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_dynHeader132 = new BitSet(new long[]{0x00000000008100E0L});
    public static final BitSet FOLLOW_dynPkgDecl_in_dynHeader134 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_dynPackageNames_in_dynPkgDecl160 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_dynPkgDecl164 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_parameter_in_dynPkgDecl166 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_dynPackageName_in_dynPackageNames180 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_dynPackageNames183 = new BitSet(new long[]{0x00000000008100E0L});
    public static final BitSet FOLLOW_dynPackageName_in_dynPackageNames185 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_wildcardedPackageName_in_dynPackageName206 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_star_in_dynPackageName212 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_packageName_in_dynPackageName218 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_bundleDescription_in_requireBundleHeader234 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_requireBundleHeader237 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_bundleDescription_in_requireBundleHeader239 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_symbolicName_in_bundleDescription276 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_bundleDescription279 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_parameter_in_bundleDescription281 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_identifier_in_symbolicName304 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_bundleDescription_in_fragmentHostHeader324 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_bundleDescription_in_bundleSymbolicNameHeader342 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_bundleDescription_in_importBundleHeader393 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_importBundleHeader396 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_bundleDescription_in_importBundleHeader398 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_bundleDescription_in_importLibraryHeader452 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_importLibraryHeader455 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_bundleDescription_in_importLibraryHeader457 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_bundleDescription_in_librarySymbolicNameHeader513 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_bundleDescription_in_webContextParamsHeader562 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_webContextParamsHeader565 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_bundleDescription_in_webContextParamsHeader567 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_bundleDescription_in_webFilterMappingsHeader619 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_webFilterMappingsHeader622 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_bundleDescription_in_webFilterMappingsHeader624 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_bundleDescription_in_webServletsHeader676 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_webServletsHeader679 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_bundleDescription_in_webServletsHeader681 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_webErrorPageDeclaration_in_webErrorPagesHeader733 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_10_in_webErrorPagesHeader736 = new BitSet(new long[]{0x00000000007FC0C0L});
    public static final BitSet FOLLOW_webErrorPageDeclaration_in_webErrorPagesHeader738 = new BitSet(new long[]{0x0000000000000402L});
    public static final BitSet FOLLOW_webErrorPages_in_webErrorPageDeclaration802 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_webErrorPageDeclaration806 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_parameter_in_webErrorPageDeclaration808 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_webErrorPage_in_webErrorPages822 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_webErrorPages825 = new BitSet(new long[]{0x00000000007FC0C0L});
    public static final BitSet FOLLOW_webErrorPage_in_webErrorPages827 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_filePath_in_webErrorPage845 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_activationPolicy_in_bundleActivationPolicyHeader876 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_11_in_bundleActivationPolicyHeader879 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_directive_in_bundleActivationPolicyHeader881 = new BitSet(new long[]{0x0000000000000802L});
    public static final BitSet FOLLOW_identifier_in_activationPolicy928 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_directive_in_parameter946 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_attribute_in_parameter950 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_identifier_in_directive962 = new BitSet(new long[]{0x0000000000001000L});
    public static final BitSet FOLLOW_12_in_directive964 = new BitSet(new long[]{0x00000000000180D0L});
    public static final BitSet FOLLOW_argument_in_directive966 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_identifier_in_attribute979 = new BitSet(new long[]{0x0000000000002000L});
    public static final BitSet FOLLOW_13_in_attribute981 = new BitSet(new long[]{0x00000000000180D0L});
    public static final BitSet FOLLOW_argument_in_attribute983 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_identifier_in_argument997 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_QUOTED_STRING_in_argument1001 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_packageIdentifier_in_packageName1015 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_wildPackageIdentifier_in_wildcardedPackageName1028 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_STAR_in_star1042 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_14_in_filePath1109 = new BitSet(new long[]{0x00000000007FC0C0L});
    public static final BitSet FOLLOW_filePathPart_in_filePath1113 = new BitSet(new long[]{0x0000000000004002L});
    public static final BitSet FOLLOW_14_in_filePath1116 = new BitSet(new long[]{0x00000000007F80C0L});
    public static final BitSet FOLLOW_filePathPart_in_filePath1118 = new BitSet(new long[]{0x0000000000004002L});
    public static final BitSet FOLLOW_set_in_filePathPart1142 = new BitSet(new long[]{0x00000000007F80C2L});
    public static final BitSet FOLLOW_identifierPart_in_identifier1197 = new BitSet(new long[]{0x0000000000020002L});
    public static final BitSet FOLLOW_17_in_identifier1200 = new BitSet(new long[]{0x00000000000180C0L});
    public static final BitSet FOLLOW_identifierPart_in_identifier1202 = new BitSet(new long[]{0x0000000000020002L});
    public static final BitSet FOLLOW_packageIdentifierPart_in_packageIdentifier1217 = new BitSet(new long[]{0x0000000000020002L});
    public static final BitSet FOLLOW_17_in_packageIdentifier1220 = new BitSet(new long[]{0x00000000008100C0L});
    public static final BitSet FOLLOW_packageIdentifierPart_in_packageIdentifier1222 = new BitSet(new long[]{0x0000000000020002L});
    public static final BitSet FOLLOW_packageIdentifierPart_in_wildPackageIdentifier1237 = new BitSet(new long[]{0x0000000000020100L});
    public static final BitSet FOLLOW_17_in_wildPackageIdentifier1240 = new BitSet(new long[]{0x00000000008100C0L});
    public static final BitSet FOLLOW_packageIdentifierPart_in_wildPackageIdentifier1242 = new BitSet(new long[]{0x0000000000020100L});
    public static final BitSet FOLLOW_DOTSTAR_in_wildPackageIdentifier1247 = new BitSet(new long[]{0x0000000000000002L});
    public static final BitSet FOLLOW_set_in_identifierPart1259 = new BitSet(new long[]{0x00000000000180C2L});
    public static final BitSet FOLLOW_set_in_packageIdentifierPart1286 = new BitSet(new long[]{0x00000000008100C2L});

}
