/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest.parse;

import java.util.List;

import org.antlr.runtime.BitSet;
import org.antlr.runtime.IntStream;
import org.antlr.runtime.MismatchedTokenException;
import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.Token;
import org.antlr.runtime.TokenStream;
import org.springframework.util.StringUtils;

/**
 * <p>
 * Subclass of the generated parser to allow hooking in mainly 
 * for the purpose of logging and tracing.
 * </p>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public class StandardOsgiHeaderParser extends OsgiHeaderParser {

    private final ManifestHeaderParserErrorHandler parserErrorHandler;

    private final String headerName;

    private final String header;

    public void setLogService(ParserLogger logger) {

    }

    /**
     * Creates a new header parser with additional information about 
     * the name of the header being parsed and a logger implementation 
     * to output any log messages to. 
     * 
     * @param logger
     * @param input
     * @param headerName
     */
    public StandardOsgiHeaderParser(ManifestHeaderParserErrorHandler parserErrorHandler, TokenStream input, String headerName, String header) {
        super(input);
        this.parserErrorHandler = parserErrorHandler;
        this.headerName = headerName;
        this.header = header;
    }
    
    /**
     * 
     * @return
     */
    public List<HeaderDeclaration> getDeclarations() {
        return this.declarations;
    }

    /**
     * This is called from all the rules if that rule causes an error
     */
    @Override
    protected void displayError(RecognitionException re) {
        this.parserErrorHandler.exitError(re, this.headerName, this.header, null);
    }

    @Override
    protected void mismatch(IntStream input, int ttype, BitSet follow) throws RecognitionException {
        RecognitionException throwMe = new MismatchedTokenException(ttype, input);
        this.parserErrorHandler.recoverableError(throwMe, this.headerName, this.header, input.index());
        throw throwMe;
    }

    @Override
    public void recoverFromMismatchedSet(IntStream input, RecognitionException re, BitSet follow) throws RecognitionException {
        this.parserErrorHandler.recoverableError(re, this.headerName, this.header, input.index());
        throw re;
    }

    @Override
    public String getErrorMessage(RecognitionException re, String[] tokens) {
        return super.getErrorMessage(re, tokens);
    }

    @Override
    public String getTokenErrorDisplay(Token t) {
        return super.getTokenErrorDisplay(t);
    }

    @Override
    public void displayRecognitionError(String[] tokenNames, RecognitionException re) {
        String tokens = "Tokens [" + StringUtils.arrayToCommaDelimitedString(tokenNames) + "]";
        this.parserErrorHandler.exitError(re, this.headerName, this.header, tokens);
    }

}
