/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.provisioning.repository;

import java.io.File;

import com.springsource.server.osgi.provisioning.LibraryDefinition;
import com.springsource.server.osgi.provisioning.support.LibraryDefinitionFactory;

/**
 * {@link CachingLocationTable} for {@link LibraryDefinition LibraryDefinitions}<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class LibraryDefinitionTable extends CachingLocationTable<LibraryDefinition> {

    /**
     * Creates a new <code>LibraryDefinitionTable</code>.
     */
    public LibraryDefinitionTable(File cacheFile, long repositoryAge) {
        super(false, cacheFile, repositoryAge);
    }

    /**
     * {@inheritDoc}
     */
    @Override protected LibraryDefinition fromLocation(String location) {
        return LibraryDefinitionFactory.createLibraryDefinition(new File(location));
    }

    /**
     * {@inheritDoc}
     */
    @Override protected String toLocation(LibraryDefinition definition) {
        return definition.getLocation().getAbsolutePath();
    }

}
