/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.provisioning.repository;

import java.io.File;

import com.springsource.server.osgi.provisioning.BundleDefinition;
import com.springsource.server.osgi.provisioning.LibraryDefinition;

/**
 * Extension to {@link BundleRepository} that allows for new bundles and libraries to be installed at runtime.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface MutableBundleRepository extends BundleRepository {

    /**
     * Adds the bundle at <code>location</code> to the repository.
     * 
     * @param location the bundle location.
     * @return the <code>BundleDefinition</code> for the newly added bundle.
     */
    BundleDefinition addBundle(File location);

    /**
     * Adds the library at <code>location</code> into the repository.
     * 
     * @param location the library location.
     * @return the <code>LibraryDefinition</code> for the newly added library.
     */
    LibraryDefinition addLibrary(File location);
}
