/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.provisioning.support;

import java.io.File;
import java.io.Reader;

import com.springsource.server.osgi.provisioning.BundleDefinition;

/**
 * Implementation of {@link BundleDefinition} that is backed by an exploded bundle directory.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class DirectoryBundleDefinition extends AbstractLocalBundleDefinition {

    /**
     * Creates a new <code>DirectoryBundleDefinition</code>.
     * 
     * @param file the directory of the bundle.
     */
    public DirectoryBundleDefinition(File file) {
        super(file);
    }

    /**
     * {@inheritDoc}
     */
    @Override protected Reader getManifestReader() {
        return extractManifest(getLocation());
    }

    /**
     * @param file
     * @return
     */
    private static Reader extractManifest(File file) {
        return ManifestUtils.manifestReaderFromExplodedDirectory(file);
    }

    static boolean isDirectoryBundle(File file) {
        return file.isDirectory();
    }
}
