/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.profile.core.internal;

import com.springsource.server.kernel.core.Subsystem;
import com.springsource.server.management.proxy.profile.ProfileSubsystemInfo;

/**
 * <p>
 * Standard implementation of <code>ProfileSubsystemInfo</code>
 * </p>
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is thread safe
 *
 * @author Christopher Frost
 * @since 1.0
 */
public class StandardProfileSubsystemInfo implements ProfileSubsystemInfo {

    private String profileName;

    private Subsystem subsystem;

    /**
     * Standard constructor that takes references to the subsystem 
     * being represented and the name of the profile that declared it.
     * 
     * @param subsystem
     * @param profileName
     */
    public StandardProfileSubsystemInfo(Subsystem subsystem, String profileName) {
        this.profileName = profileName;
        this.subsystem = subsystem;
    }
    
    /**
     * 
     * {@inheritDoc}
     */
    public String getProfileName(){
        return profileName;
    }
    
    /**
     * 
     * {@inheritDoc}
     */
    public String getSubsystemName(){
        return this.subsystem.getName();
    }
    
    /**
     * 
     * {@inheritDoc}
     */
    public String getSubsystemState(){
        return this.subsystem.getState().toString();
    }

    /**
     * 
     * @return
     */
    public Class<ProfileSubsystemInfo> getInfoType() {
        return ProfileSubsystemInfo.class;
    }
    

}
