/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.ffdc;


/**
 * DumpExtension is an interface which subsystems can implement in order to contribute information about their state to
 * the dump file, which is created by the {@link DumpGenerator}. Subsystems should register a concrete instance of the
 * DumpExtension in the OSGi service registry.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations <code>must</code> be threadsafe.
 * 
 * @author Damilola Senbanjo
 * @since 1.0
 */

public interface DumpExtension extends Dumpable {

    /**
     * The name of the dump extension point in the extension registry.
     */
    static final String EXTENSION_POINT_NAME = "dump";

    /**
     * Gets the name of the subsystem
     * 
     * @return subsystem name
     */
    String getName();

}
