/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.ffdc;

/**
* Server exceptions are thrown when a non-fatal error is detected in the
* Server which simply needs throwing as a checked exception. This
* class is thread safe.
* 
* Subsystems should throw their own specific subclasses.
* 
* @author Glyn Normington
* @since 1.0
*/
abstract public class ServerException extends Exception {

    /**
     * Stable serial UID.
     */
	private static final long serialVersionUID = 6855357491003716651L;
	
	/**
     * Construct a server exception.
     * 
     * @param message an English description of the error
     */
    public ServerException(String message) {
        super(message);
    }
    
    /**
     * Construct a server exception.
     * 
     * @param message an English description of the error
     * @param cause a {@link Throwable} which caused the exception
     */
    public ServerException(String message, Throwable cause) {
        super(message, cause);
    }

}
