/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.logging;

import com.springsource.server.serviceability.output.Level;

/**
 * Delegate class to back {@link LogEvent} enums for each subsystem. Can also be subclassed by a subsytem to enable
 * dynamic construction of <code>LogEvents<code>.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public class LogEventDelegate implements LogEvent {

    private final String subsystemCode;

    private final String subsystemName;

    private final int code;

    private Level level;

    private final String fullEventCode;

    /**
     * Create a new <code>LogEventDelegate</code>.
     * @param subsystemName The name of the subsystem from which the <code>LogEvent</code> originates.
     * @param subsystemCode The unique code for the subsystem from which the <code>LogEvent</code> originates.
     * @param level The level at which the <code>LogEvent</code> should be published.
     */
    public LogEventDelegate(String subsystemName, String subsystemCode, int code, Level level) {
        this.subsystemName = subsystemName;
        this.subsystemCode = subsystemCode;
        this.level = level;
        this.code = code;
        this.fullEventCode = formatEventCode();
    }

    private final String formatEventCode() {
        return String.format("%s%04d%1.1s", this.subsystemCode, this.code, level);
    }

    /**
     * {@inheritDoc}
     */
    public final String getEventCode() {
        return this.fullEventCode;
    }

    /**
     * {@inheritDoc}
     */
    public final Level getLevel() {
        return this.level;
    }

    /**
     * {@inheritDoc}
     */
    public final String getSubsystemName() {
        return this.subsystemName;
    }
}
