/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.logging;

import java.util.Locale;


/**
 * A LogEventMessageResolver is used to resolve the message of a {@link LogEvent}, typically
 * by using the LogEvent's {@link LogEvent#getEventCode() code}.  
 *
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 *
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface LogEventMessageResolver {

	/**
	 * Resolves the message for the specified {@link LogEvent}
	 * Construct the String message for the specified <code>LogEvent</code>.
	 * 
	 * @param event The event for which the message is to be resolved
	 * @return The resolved message
	 */
	String resolveLogEventMessage(LogEvent event);
	
	/**
	 * Resolves the message for the specified {@link LogEvent} in the
	 * specified {@link Locale}.
	 * 
	 * @param locale The <code>Locale</code> in which the message is to be resolved
	 * @param event The <code>LogEvent</code> for which the message is to be resolved
	 * @return The resolved message
	 */
	String resolveLogEventMessage(Locale locale, LogEvent event);
}
