/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.logging;

import com.springsource.server.serviceability.logging.internal.LoggingBootstrap;
import com.springsource.server.serviceability.logging.internal.ResourceBundleEventMessageResolver;
import com.springsource.server.serviceability.logging.internal.StandardLogService;

/**
 * A factory for obtaining {@link LogService} instances.
 * 
 * <p/> <strong>Concurrent Semantics</strong><br/>
 * This class is <strong>thread-safe</strong>.
 * 
 * @author Christopher Frost
 * @author Andy Wilkinson
 * @since 1.0
 */
public abstract class LogServiceFactory {

    private static final LogService LOG_SERVICE = new StandardLogService(new ResourceBundleEventMessageResolver(), LoggingBootstrap.getLoggingEntryPublisher(), LoggingBootstrap.getTracingEntryPublisher());

    /**
     * Create a <code>LogService</code>
     * 
     * @return a <code>LogService</code> instance
     */
    public static LogService getLogService() {
        return LOG_SERVICE;
    }
}
