/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output;

/**
 * A <code>DestinationCreationListener</code> implementation can be registered with a {@link DestinationRegistry} to
 * receive notifications for destinations created by the registry.
 * <p />
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 * @see DestinationRegistry#addDestinationCreationListener(DestinationCreationListener)
 */
public interface DestinationCreationListener {

    /**
     * Notification that a {@link Destination} has been created by the registry with which the listener is registered.
     * 
     * @param destinationIdentifier The identifier by which the <code>Destination</code> is known to the registry
     * @param destination The destination that has been created
     */
    void destinationCreated(String destinationIdentifier, Destination destination);
    
    /**
     * Notification that a {@link Destination} has been destroyed by the registry with which the listener is registered.
     * 
     * @param destination The identifier by which the <code>Destination</code> was known to the registry.
     */
    void destinationDestroyed(String destinationIdentifier);
}
