/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output;

/**
 * A serviceability output Entry represents an individual entry in the Server's
 * serviceability output, i.e. logging and tracing. Entry instances are created
 * by calls to the logging and tracing components and are output to one or more
 * {@link Destination Destinations}
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface Entry {
    /**
     * Returns the complete text for this entry suitable for writing by a {@link Destination}
     * @return the entry's complete text
     */
    String getText();
    /**
     * Returns the source of the entry suitable for use by an {@link EntryFilter} when determining
     * whether or not the entry should be published.
     * @return the source of the entry
     */
    String getSource();
    
    /**
     * Returns the Level at which this entry should be output.
     * @return The entry's level
     */
    Level getLevel();
}
