/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output.internal;

import com.springsource.server.serviceability.output.Destination;
import com.springsource.server.serviceability.output.Entry;
import com.springsource.server.serviceability.output.EntryPublisher;

/**
 * Standard implementation of {@link EntryPublisher}.
 * <p />
 * <strong>Concurrent Semantics</strong><br />
 * This class is <strong>thread-safe</strong>.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
class StandardEntryPublisher implements EntryPublisher {

    private final Destination[] destinations;

    /**
     * Creates a new <code>StandardEntryPublisher</code> that will publish {@link Entry Entries} to the supplied
     * {@link Destination Destinations}
     * 
     * @param destinations The <code>Destinations</code> to which <code>Entries</code> will be published.
     */
    StandardEntryPublisher(Destination[] destinations) {
        this.destinations = destinations.clone();
        for (Destination destination : destinations) {
            destination.open();
        }
    }

    /** 
     * {@inheritDoc}
     */
    public void publish(Entry entry) {
        for (Destination destination : destinations) {
            destination.write(entry);
        }
    }

    /** 
     * {@inheritDoc}
     */
    public void flush() {
        for (Destination destination : destinations) {
            destination.flush();
        }
    }
    
    public void close() {
        for (Destination destination : destinations) {
            destination.close();
        }
    }
}
