/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.tracing;

import static com.springsource.server.serviceability.output.Level.DEBUG;
import static com.springsource.server.serviceability.output.Level.ERROR;
import static com.springsource.server.serviceability.output.Level.INFO;
import static com.springsource.server.serviceability.output.Level.VERBOSE;
import static com.springsource.server.serviceability.output.Level.WARN;

import com.springsource.server.serviceability.output.Level;


/**
 * Base implementation of a {@link Tracer}. Sub-classes only need to
 * implement {@link Tracer#trace(com.springsource.server.serviceability.output.Level, String, Throwable, Object...)}. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementation is stateless.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public abstract class AbstractTracer implements Tracer {

    /** 
     * {@inheritDoc}
     */
    public final void traceVerbose(String message, Object... inserts) {
        trace(VERBOSE, message, inserts);
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceDebug(String message, Object... inserts) {
        trace(DEBUG, message, inserts);
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceInfo(String message, Object... inserts) {
        trace(INFO, message, inserts);
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceWarning(String message, Object... inserts) {
        trace(WARN, message, inserts);
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceError(String message, Object... inserts) {
        trace(ERROR, message, inserts);
    }
   
    /** 
     * {@inheritDoc}
     */
    public final void traceDebug(String message, Throwable throwable, Object... inserts) {
        trace(DEBUG, message, throwable, inserts);     
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceVerbose(String message, Throwable throwable, Object... inserts) {
        trace(VERBOSE, message, throwable, inserts);       
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceError(String message, Throwable throwable, Object... inserts) {
        trace(ERROR, message, throwable, inserts);       
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceInfo(String message, Throwable throwable, Object... inserts) {
        trace(INFO, message, throwable, inserts);       
    }

    /** 
     * {@inheritDoc}
     */
    public final void traceWarning(String message, Throwable throwable, Object... inserts) {
        trace(WARN, message, throwable, inserts);     
    }
    
    /** 
     * {@inheritDoc}
     */
    public final void trace(Level level, String message, Object... inserts) {
        trace(level, message, null, inserts);
    }
}
