/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.tracing;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import com.springsource.server.serviceability.output.Level;

/**
 * EntryExitTraceLevel can be used to specify the level at which entry and exit trace
 * will be generated on a per-method basis. For example the following will cause the
 * method foo's entry and exit trace to be generated at the verbose trace level:
 * 
 * <pre>
 * &#64;EntryExitTraceLevel(VERBOSE)
 * public void foo() { 
 * }
 * </pre>
 * 
 * @see Level
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
@Documented()
public @interface EntryExitTraceLevel {
    public Level value();
}
