/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.tracing;

import com.springsource.server.serviceability.tracing.internal.InternalTracerFactory;

/**
 * A factory object used to create tracers.
 * 
 * Implementation is thread-safe.
 * 
 * @see Tracer
 * @author Glyn Normington
 * @author Rob Harrop
 * @author Andy Wilkinson
 * @since 1.0
 * 
 */
public abstract class TracerFactory {    
    /**
     * Create a tracer for the specified class.
     * 
     * @param clazz a non-null Class
     * @return a tracer for the specified class
     */
    public static Tracer createTracer(Class<?> clazz) {
        return InternalTracerFactory.createTracer(clazz);
    }
}
