/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.tracing.internal;

import java.util.Map;

import com.springsource.server.serviceability.output.EntryFilter;
import com.springsource.server.serviceability.output.Level;
import com.springsource.server.serviceability.tracing.TracingService;

/**
 * Standard implementation of {@link TracingService}
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 * This class as thread-safe as the {@link EntryFilter} implementation that it uses.
 *
 * @author Andy Wilkinson
 * @since 1.0
 */
public class StandardTracingService implements TracingService {

    private final InheritableThreadLocal<String> applicationNameThreadLocal;
    
    /**
     * Creates a new <code>StandardTracingService</code>
     * 
     * @param traceEntryFilter
     * @param applicationNameThreadLocal
     */
    public StandardTracingService(EntryFilter traceEntryFilter, InheritableThreadLocal<String> applicationNameThreadLocal) {
        this.applicationNameThreadLocal = applicationNameThreadLocal;
    }

    /** 
     * {@inheritDoc}
     */
    public void setCurrentApplicationName(String applicationName) {
        this.applicationNameThreadLocal.set(applicationName);      
    }

    /** 
     * {@inheritDoc}
     */
    public String getCurrentApplicationName() {
        return this.applicationNameThreadLocal.get();
    }

    /** 
     * {@inheritDoc}
     */
    public void applicationUndeployed(String applicationName) {
        InternalTracerFactory.getEntryPublisherAccessor().applicationUndeployed(applicationName);
    }

    /** 
     * {@inheritDoc}
     */
    public void applicationDeployed(String applicationName, Map<String, Level> configuredLevels) {
        InternalTracerFactory.getEntryPublisherAccessor().applicationDeployed(applicationName, configuredLevels); 
    }     
}
