/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.admin.service;

import java.util.List;
import java.util.Map;

import org.springframework.web.multipart.MultipartFile;

import com.springsource.server.management.proxy.application.ServerApplicationInfo;

/**
 * <code>ApplicationManagerService</code> defines a simple service API for managing applications within the server.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations should be thread-safe.
 * 
 * @author Christopher Frost
 * @author Sam Brannen
 * @since 1.0
 */
public interface ApplicationManagerService {

    /**
     * Returns a list of {@link ServerApplicationInfo} instances for all deployed applications.
     */
    public List<ServerApplicationInfo> findAppInfoForDeployedApplications();

    /**
     * @param multipartFile
     * @return
     */
    public String deploy(MultipartFile multipartFile);

    /**
     * Attempts to undeploy the application with the supplied path. If an application with the supplied path does not
     * exist, this method will essentially have no effect.
     * 
     * @return
     */
    public String undeploy(String path);

    /**
     * Gets a map of server properties for informational display purposes.
     */
    public Map<String, String> getServerProperties();

    /**
     * Gets a map of the serviceability destinations currently in use by the server
     */
    public Map<String, String> getDestinations();

}
