/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.core;

/**
 * <code>DeployedWebApplicationNamesRegistry</code> serves as a central registry for looking up the application names
 * of deployed web applications.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations must be thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
public interface DeployedWebApplicationNamesRegistry {

    /**
     * Registers the web application with the supplied <code>contextPath</code> and <code>applicationName</code>.
     */
    void registerWebApplication(String contextPath, String applicationName);

    /**
     * Unregisters the web application with the supplied <code>contextPath</code>.
     */
    void unregisterWebApplication(String contextPath);

    /**
     * Gets the name of the web application with the supplied <code>contextPath</code>.
     */
    String getWebApplicationName(String contextPath);

}
