/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.core;

/**
 * An unchecked exception which is thrown for errors which occur within a {@link ServletContainer} and associated
 * classes.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
public class ServletContainerException extends RuntimeException {

    private static final long serialVersionUID = -2484573525557843394L;

    /**
     * Default constructor using no specified cause or detailed message.
     */
    public ServletContainerException() {
        super();
    }

    /**
     * Construct a new <code>ServletContainerException</code> instance.
     * 
     * @param message detailed message
     * @param cause exception cause
     */
    public ServletContainerException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Construct a new <code>ServletContainerException</code> instance.
     * 
     * @param message detailed message
     */
    public ServletContainerException(String message) {
        super(message);
    }

    /**
     * Construct a new <code>ServletContainerException</code> instance.
     * 
     * @param cause exception cause
     */
    public ServletContainerException(Throwable cause) {
        super(cause);
    }

}
