/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.core.internal;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import com.springsource.server.serviceability.output.Level;
import com.springsource.server.serviceability.tracing.EntryExitTraceLevel;
import com.springsource.server.serviceability.tracing.Tracer;
import com.springsource.server.serviceability.tracing.TracerFactory;
import com.springsource.server.servlet.core.DeployedWebApplicationNamesRegistry;

/**
 * Standard implementation of {@link DeployedWebApplicationNamesRegistry}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
public class StandardDeployedWebApplicationNamesRegistry implements DeployedWebApplicationNamesRegistry {

    private final Tracer TRACER = TracerFactory.createTracer(StandardDeployedWebApplicationNamesRegistry.class);

    private final Map<String, String> deployedWebAppNames = new ConcurrentHashMap<String, String>();

    /**
     * {@inheritDoc}
     */
    @EntryExitTraceLevel(Level.VERBOSE)
    public String getWebApplicationName(String contextPath) {
        return this.deployedWebAppNames.get(contextPath);
    }

    /**
     * {@inheritDoc}
     */
    @EntryExitTraceLevel(Level.INFO)
    public void registerWebApplication(String contextPath, String applicationName) {
        TRACER.traceDebug("Registering web application with context path [%s] and application name [%s].", contextPath, applicationName);
        this.deployedWebAppNames.put(contextPath, applicationName);
    }

    /**
     * {@inheritDoc}
     */
    @EntryExitTraceLevel(Level.INFO)
    public void unregisterWebApplication(String contextPath) {
        TRACER.traceDebug("Unregistering web application with context path [%s].", contextPath);
        this.deployedWebAppNames.remove(contextPath);
    }

}
