/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.tomcat;

import org.apache.catalina.Executor;
import org.springframework.beans.factory.FactoryBean;

import com.springsource.server.concurrent.core.ExecutorManager;
import com.springsource.server.concurrent.core.ServerExecutorService;
import com.springsource.server.kernel.core.SubsystemRegistry;

/**
 * {@link FactoryBean} for creating a Catalina {@link Executor} that is backed by a {@link ServerExecutorService}.
 * <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @author Ben Hale
 * @since 1.0
 */
final class ExecutorFactoryBean implements FactoryBean {

    private static final String EXECUTOR_NAME = "server-tomcat";

    private final Executor executor;

    /**
     * Creates a new <code>ExecutorFactoryBean</code>.
     * 
     * @param executorManager the {@link ExecutorManager}.
     * @param subsystemRegistry the {@link SubsystemRegistry}.
     */
    public ExecutorFactoryBean(ExecutorManager executorManager, SubsystemRegistry subsystemRegistry, TomcatServletContainerConfiguration configuration) {
        this.executor = new DelegatingExecutor(executorManager, subsystemRegistry, configuration.getThreadPoolMinSize(), configuration.getThreadPoolMaxSize(),
            configuration.getThreadPoolKeepAlivePeriod(), EXECUTOR_NAME);
    }

    /**
     * {@inheritDoc}
     */
    public Object getObject() throws Exception {
        return this.executor;
    }

    /**
     * {@inheritDoc}
     */
    public Class<?> getObjectType() {
        return Executor.class;
    }

    /**
     * {@inheritDoc}
     */
    public boolean isSingleton() {
        return true;
    }
}
