/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.test.framework;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.concurrent.atomic.AtomicReference;

import org.springframework.osgi.context.event.OsgiBundleApplicationContextEvent;
import org.springframework.osgi.context.event.OsgiBundleApplicationContextListener;
import org.springframework.osgi.context.event.OsgiBundleContextFailedEvent;

/**
 * TODO Document Listener
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * TODO Document concurrent semantics of Listener
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public class Listener implements OsgiBundleApplicationContextListener {

    private final Object monitor = new Object();

    private final AtomicReference<String> failure;

    /**
     * @param cause
     */
    public Listener(AtomicReference<String> failure) {
        this.failure = failure;
        this.failure.set(null);
    }

    /**
     * {@inheritDoc}
     */
    public void onOsgiApplicationEvent(OsgiBundleApplicationContextEvent event) {
        synchronized (this.monitor) {
            if (this.failure.get() == null && event instanceof OsgiBundleContextFailedEvent) {
                OsgiBundleContextFailedEvent failedEvent = (OsgiBundleContextFailedEvent) event;
                StringBuilder sb = new StringBuilder();
                sb.append("App Context '").append(failedEvent.getApplicationContext().getDisplayName()).append("' failed to start because:\n ").append(
                    throwableToString(failedEvent.getFailureCause()));
                this.failure.set(sb.toString());
            }
        }
    }

    /**
     * @param failureCause
     * @return
     */
    private String throwableToString(Throwable failureCause) {
        StringWriter sw = new StringWriter();
        failureCause.printStackTrace(new PrintWriter(sw));
        return sw.toString();
    }

}
