/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.test.framework.junit4;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Map;

import org.osgi.framework.Bundle;
import org.springframework.util.ReflectionUtils;

/**
 * Handles injection of field values on test classes.
 * 
 * <p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Immutable and therefore concurrent.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class InjectionHandler {

    @SuppressWarnings("unused")
    private final Bundle testFrameworkBundle;

    private final Map<String, Object> injectionValues = new HashMap<String, Object>();

    /**
     * @param osgiFramework
     */
    public InjectionHandler(Bundle testFrameworkBundle) throws Exception {
        this.testFrameworkBundle = testFrameworkBundle;
    }

    public void registerInjectionValue(Class<? extends Annotation> annotationClass, Object value) throws Exception {
        this.injectionValues.put(annotationClass.getName(), value);
    }

    public void injectFieldValues(final Object testInstance) {
        ReflectionUtils.doWithFields(testInstance.getClass(), new ReflectionUtils.FieldCallback() {

            public void doWith(Field field) throws IllegalArgumentException, IllegalAccessException {
                Annotation[] annotations = field.getAnnotations();
                for (Annotation annotation : annotations) {
                    Class<? extends Annotation> annotationClass = annotation.annotationType();
                    Object value = injectionValues.get(annotationClass.getName());
                    if (value != null) {
                        field.setAccessible(true);
                        field.set(testInstance, value);
                        break;
                    }
                }
            }

        });
    }

}
