/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.web.dm;

import org.osgi.framework.Bundle;
import org.springframework.core.io.Resource;
import org.springframework.osgi.io.OsgiBundleResourceLoader;
import org.springframework.util.Assert;

/**
 * <code>ServerOsgiBundleResourceLoader</code> is a custom extension of {@link OsgiBundleResourceLoader} which
 * returns {@link ServerOsgiBundleResource ServerOsgiBundleResources}.
 * <p />
 * 
 * @author Sam Brannen
 * @since 1.0
 */
public class ServerOsgiBundleResourceLoader extends OsgiBundleResourceLoader {

    /**
     * Creates an OSGi aware <code>ResourceLoader</code> using the given bundle.
     * 
     * @param bundle OSGi <code>Bundle</code> to be used by this resource loader.
     */
    public ServerOsgiBundleResourceLoader(Bundle bundle) {
        super(bundle);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected Resource getResourceByPath(String path) {
        Assert.notNull(path, "'path' is required");
        return new ServerOsgiBundleResource(getBundle(), path);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Resource getResource(String location) {
        Assert.notNull(location, "'location' is required");
        return new ServerOsgiBundleResource(getBundle(), location);
    }

}
