/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package org.slf4j.impl;



import org.slf4j.ILoggerFactory;
import org.slf4j.IMarkerFactory;
import org.slf4j.LoggerFactory;
import org.slf4j.MarkerFactory;
import org.slf4j.spi.LoggerFactoryBinder;

import com.springsource.server.serviceability.tracing.slf4j.ServerTracerFactory;



/**

 * The binding of {@link LoggerFactory} class with an actual instance of 

 * {@link ILoggerFactory} is performed using information returned by this class. 

 * 

 * <p>

 * This class also contains the information for binding {@link MarkerFactory}

 * with the appropriate {@link IMarkerFactory} instance.

 * 

 * @author Ceki G&uuml;lc&uuml;

 */

public class StaticLoggerBinder implements LoggerFactoryBinder {



  /**

   * The unique instance of this class.

   */

  public static final StaticLoggerBinder SINGLETON = new StaticLoggerBinder();

  // Note: JCL gets substituted at build time by an appropriate Ant task

  private static final String loggerFactoryClassStr = ServerTracerFactory.class.getName();



  /** The ILoggerFactory instance returned by the {@link #getLoggerFactory} method

   * should always be the same object

   */

  private final ILoggerFactory loggerFactory;

  

  private StaticLoggerBinder() {

//  Note: JCL gets substituted at build time by an appropriate Ant task

    loggerFactory = new ServerTracerFactory();

  }

  

  public ILoggerFactory getLoggerFactory() {

    return loggerFactory;

  }

  

  public String getLoggerFactoryClassStr() {

    return loggerFactoryClassStr;

  }   

}
