/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.bootstrap.util;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.ServerSocket;

/**
 * Utility methods for working with network IO code.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public final class NetUtils {

    /**
     * Checks whether the supplied port is available on any local address.
     * 
     * @param port the port to check for.
     * @return <code>true</code> if the port is available, otherwise <code>false</code>.
     */
    public static boolean isPortAvailable(int port) {
        ServerSocket socket;
        try {
            socket = new ServerSocket();
        } catch (IOException e) {
            throw new IllegalStateException("Unable to create ServerSocket.", e);
        }

        try {
            InetSocketAddress sa = new InetSocketAddress(port);
            socket.bind(sa);
            return true;
        } catch (IOException ex) {
            return false;
        } finally {
            try {
                socket.close();
            } catch (IOException ex) {
            }
        }
    }
}
