/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.common.math;

import java.util.Collection;
import java.util.Iterator;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

public final class ConcurrentHashSet<Elem> implements ConcurrentSet<Elem> {

    private final ConcurrentMap<Elem, Boolean> elems = new ConcurrentHashMap<Elem, Boolean>();

    public boolean add(Elem e) {
        return null == this.elems.putIfAbsent(e, Boolean.TRUE);
    }

    public boolean addAll(Collection<? extends Elem> c) {
        boolean updated = false;
        for (Elem e : c) {
            updated = updated | add(e);
        }
        return updated;
    }

    public void clear() {
        this.elems.clear();
    }

    public boolean contains(Object o) {
        return this.elems.containsKey(o);
    }

    public boolean containsAll(Collection<?> c) {
        for (Object o : c) {
            if (!contains(o)) {
                return false;
            }
        }
        return true;
    }

    public boolean isEmpty() {
        return this.elems.isEmpty();
    }

    public Iterator<Elem> iterator() {
        return this.elems.keySet().iterator();
    }

    public boolean remove(Object o) {
        return null != this.elems.remove(o);
    }

    public boolean removeAll(Collection<?> c) {
        boolean updated = false;
        for (Object o : c) {
            updated = updated | remove(o);
        }
        return updated;
    }

    public boolean retainAll(Collection<?> c) {
        boolean updated = false;
        for (Elem e : this.elems.keySet()) {
            if (!c.contains(e)) {
                updated = true;
                this.elems.remove(e);
            }
        }
        return updated;
    }

    public int size() {
        return this.elems.size();
    }

    public Object[] toArray() {
        return this.elems.keySet().toArray();
    }

    public <T> T[] toArray(T[] a) {
        return this.elems.keySet().toArray(a);
    }

}
