/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core;

/**
 * Creates managed instances of {@link Thread}. Also allows for an existing <code>Thread</code> to be 'dubbed' as a
 * managed <code>Thread</code>.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface ThreadManager {

    /**
     * Creates a new <code>Thread</code> associated with the given {@link Runnable}.
     * 
     * @param runnable the <code>Runnable</code> to associate to the thread.
     * @return the newly created <code>Thread</code>.
     */
    Thread newThread(Runnable runnable);

    /**
     * Creates a new <code>Thread</code> associated with the given {@link Runnable} and name.
     * 
     * @param runnable the <code>Runnable</code> to associate to the thread.
     * @param name the name of the thread.
     * @return the newly created <code>Thread</code>.
     */
    Thread newThread(Runnable runnable, String name);

    /**
     * Dub this <code>Thread</code> as an Engine-managed <code>Thread</code>.
     * 
     * @param thread the <code>Thread</code> to dub.
     */
    void dub(Thread thread);

    /**
     * Queries whether or not the supplied {@link Thread} is managed by the Engine.
     * 
     * @param thread the {@link Thread} to query.
     * @return <code>true</code> if the <code>Thread</code> is Engine-managed, otherwise <code>false</code>.
     */
    boolean isEngineManagedThread(Thread thread);

}
