/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core;

import java.util.concurrent.ThreadFactory;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * {@link ThreadFactory} implementation that delegates to the {@link ThreadManager}. Automatic naming of threads in the
 * pool is handled by this class.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class ThreadManagerPoolThreadFactory implements ThreadFactory {

    private final String poolName;

    private final ThreadManager threadManager;

    private final AtomicInteger threadCount = new AtomicInteger(1);

    /**
     * Creates a new <code>ThreadManagerPoolThreadFactory</code>.
     * 
     * @param poolName the name of the thread pool.
     * @param threadManager the {@link ThreadManager}.
     */
    public ThreadManagerPoolThreadFactory(String poolName, ThreadManager threadManager) {
        this.poolName = poolName;
        this.threadManager = threadManager;
    }

    /**
     * {@inheritDoc}
     */
    public Thread newThread(Runnable r) {
        return this.threadManager.newThread(r, this.poolName + "-thread-" + this.threadCount.getAndIncrement());
    }
}
