/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.accessor;

/**
 * Implementation of {@link ThreadLocalAccessor} that always returns an empty <code>ThreadLocal</code> array. Used on
 * servers where <code>ThreadLocal</code> access is not supported.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class NoOpThreadLocalAccessor implements ThreadLocalAccessor {

    /**
     * {@inheritDoc}
     */
    public ThreadLocalData[] threadLocals(Thread thread) {
        return new ThreadLocalData[0];
    }

    /**
     * {@inheritDoc}
     */
    public <T> void setThreadLocalValue(ThreadLocal<T> threadLocal, T value, Thread thread) {

    }

    /**
     * {@inheritDoc}
     */
    public void removeThreadLocal(ThreadLocal<?> threadLocal, Thread thread) {

    }

}
