/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.accessor;

/**
 * Accessor for <code>ThreadLocal</code> data. Instances are bound to the state of a <code>ThreadLocal</code> on a
 * given <code>Thread</code>.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * See {@link ThreadLocalAccessor}.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface ThreadLocalData {

    /**
     * Gets the raw <code>ThreadLocal</code>.
     * 
     * @return the <code>ThreadLocal</code>.
     */
    ThreadLocal<?> getThreadLocal();

    /**
     * Gets the value of the <code>ThreadLocal</code> for the bound <code>Thread</code>.
     * 
     * @return the value.
     * @see ThreadLocal#get
     */
    Object get();

    /**
     * Sets the value of the <code>ThreadLocal</code> for the bound <code>Thread</code>.
     * 
     * @param value the value.
     * @see ThreadLocal#set
     */
    void set(Object value);

}
