/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.config;

import java.util.concurrent.ScheduledExecutorService;

import org.springframework.beans.factory.FactoryBean;

import com.springsource.server.concurrent.core.ExecutorManager;
import com.springsource.server.kernel.core.Subsystem;
import com.springsource.server.kernel.core.SubsystemRegistry;
import com.springsource.server.serviceability.ffdc.Assert;

/**
 * {@link FactoryBean} for creating {@link ScheduledExecutorService} instances.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public final class ScheduledExecutorServiceFactoryBean extends AbstractExecutorServiceFactoryBean {

    private static final int DEFAULT_CORE_SIZE = 1;

    private volatile int coreSize = DEFAULT_CORE_SIZE;

    private final String name;

    public ScheduledExecutorServiceFactoryBean(ExecutorManager executorManager, SubsystemRegistry registry, String name) {
        super(executorManager, registry);
        Assert.notNull(name, "ScheduledExecutorService name cannot be null.");
        this.name = name;
    }

    /**
     * @param coreSize The core size for the executor
     */
    public void setCoreSize(int coreSize) {
        this.coreSize = coreSize;
    }

    /**
     * {@inheritDoc}
     */
    @Override protected Object doGetObject(Subsystem owner) {
        return getExecutorManager().newScheduledExecutorService(this.name, owner, this.coreSize);
    }

    /**
     * {@inheritDoc}
     */
    public Class<?> getObjectType() {
        return ScheduledExecutorService.class;
    }

}
