/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.diagnostics;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * {@link LogEvent} for the concurrent subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public enum ConcurrentLogEvent implements LogEvent {

    DEADLOCK_DETECTED(0, Level.ERROR),
    APPLICATION_CONTEXT_MANDATORY_DEPENDENCY_DELAYED(1, Level.WARN),
    APPLICATION_CONTEXT_OPTIONAL_DEPENDENCY_DELAYED(2, Level.INFO),
    APPLICATION_CONTEXT_DEPENDENCY_SATISFIED(3, Level.INFO),
    APPLICATION_CONTEXT_MANDATORY_DEPENDENCY_TIMED_OUT(4, Level.ERROR),
    APPLICATION_CONTEXT_OPTIONAL_DEPENDENCY_TIMED_OUT(5, Level.INFO);

    private static final String SUBSYSTEM_NAME = "Concurrent";

    private static final String SUBSYSTEM_CODE = "CC";

    private final LogEventDelegate delegate;

    /**
     * @param subsystemName
     * @param subsystemCode
     * @param severity
     */
    private ConcurrentLogEvent(int code, Level level) {
        this.delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, code, level);
    }

    /**
     * {@inheritDoc}
     */
    public String getEventCode() {
        return this.delegate.getEventCode();
    }

    /**
     * {@inheritDoc}
     */
    public Level getLevel() {
        return this.delegate.getLevel();
    }

    /**
     * {@inheritDoc}
     */
    public String getSubsystemName() {
        return this.delegate.getSubsystemName();
    }
}
