/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.queue;

import java.util.Collection;
import java.util.Iterator;
import java.util.concurrent.TimeUnit;

/**
 * {@link BlockingDeque} that wraps another <code>BlockingDeque</code> and delegates all calls to it. <p/>
 * 
 * Subclasses may override any method to add behaviour. The delegate can be accessed using {@link #getDelegate}.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe if the delegate is threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
/**
 * TODO Document DelegatingBlockingDeque
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * TODO Document concurrent semantics of DelegatingBlockingDeque
 *
 * @author Andy Wilkinson
 * @since TODO Document 'since'
 */
/**
 * TODO Document DelegatingBlockingDeque
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * TODO Document concurrent semantics of DelegatingBlockingDeque
 *
 * @author Andy Wilkinson
 * @since TODO Document 'since'
 */
/**
 * TODO Document DelegatingBlockingDeque
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * TODO Document concurrent semantics of DelegatingBlockingDeque
 *
 * @author Andy Wilkinson
 * @since TODO Document 'since'
 */
class DelegatingBlockingDeque<E> implements BlockingDeque<E> {

    private final BlockingDeque<E> delegate;

    /**
     * Creates a new <code>DelegatingBlockingQueue</code> delegating to the supplied <code>BlockingQueue</code>.
     * 
     * @param delegate the <code>BlockingQueue</code> to delegate to.
     */
    public DelegatingBlockingDeque(BlockingDeque<E> delegate) {
        this.delegate = delegate;
    }

    /** 
     * {@inheritDoc}
     */
    public boolean add(E o) {
        return this.delegate.add(o);
    }
    
    /** 
     * {@inheritDoc}
     */
    public boolean addAll(Collection<? extends E> c) {
        return this.delegate.addAll(c);
    }

    /**
     * 
     * @see java.util.Collection#clear()
     */
    public void clear() {
        this.delegate.clear();
    }

    /** 
     * {@inheritDoc}
     */
    public boolean contains(Object o) {
        return this.delegate.contains(o);
    }

    /** 
     * {@inheritDoc}
     */
    public boolean containsAll(Collection<?> c) {
        return this.delegate.containsAll(c);
    }

    /** 
     * {@inheritDoc}
     */
    public int drainTo(Collection<? super E> c, int maxElements) {
        return this.delegate.drainTo(c, maxElements);
    }

    /** 
     * {@inheritDoc}
     */
    public int drainTo(Collection<? super E> c) {
        return this.delegate.drainTo(c);
    }

    /** 
     * {@inheritDoc}
     */
    public E element() {
        return this.delegate.element();
    }

    /** 
     * {@inheritDoc}
     */
    @Override public boolean equals(Object o) {
        return this.delegate.equals(o);
    }

    /** 
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        return this.delegate.hashCode();
    }

    /** 
     * {@inheritDoc}
     */
    public boolean isEmpty() {
        return this.delegate.isEmpty();
    }

    /** 
     * {@inheritDoc}
     */
    public Iterator<E> iterator() {
        return this.delegate.iterator();
    }

    /** 
     * {@inheritDoc}
     */
    public boolean offer(E o, long timeout, TimeUnit unit) throws InterruptedException {
        return this.delegate.offer(o, timeout, unit);
    }

    /** 
     * {@inheritDoc}
     */
    public boolean offer(E o) {
        return this.delegate.offer(o);
    }

    /** 
     * {@inheritDoc}
     */
    public E peek() {
        return this.delegate.peek();
    }

    /** 
     * {@inheritDoc}
     */
    public E poll() {
        return this.delegate.poll();
    }


    /** 
     * {@inheritDoc}
     */
    public E poll(long timeout, TimeUnit unit) throws InterruptedException {
        return this.delegate.poll(timeout, unit);
    }

    /**
     * @param o
     * @throws InterruptedException
     * @see java.util.concurrent.BlockingQueue#put(java.lang.Object)
     */
    public void put(E o) throws InterruptedException {
        this.delegate.put(o);
    }

    /** 
     * {@inheritDoc}
     */
    public int remainingCapacity() {
        return this.delegate.remainingCapacity();
    }

    /** 
     * {@inheritDoc}
     */
    public E remove() {
        return this.delegate.remove();
    }

    /** 
     * {@inheritDoc}
     */
    public boolean remove(Object o) {
        return this.delegate.remove(o);
    }

    /** 
     * {@inheritDoc}
     */
    public boolean removeAll(Collection<?> c) {
        return this.delegate.removeAll(c);
    }

    /** 
     * {@inheritDoc}
     */
    public boolean retainAll(Collection<?> c) {
        return this.delegate.retainAll(c);
    }

    /** 
     * {@inheritDoc}
     */
    public int size() {
        return this.delegate.size();
    }

    /** 
     * {@inheritDoc}
     */
    public E take() throws InterruptedException {
        return this.delegate.take();
    }

    /** 
     * {@inheritDoc}
     */
    public Object[] toArray() {
        return this.delegate.toArray();
    }

    /** 
     * {@inheritDoc}
     */
    public <T> T[] toArray(T[] a) {
        return this.delegate.toArray(a);
    }

    /**
     * Gets the delegate {@link BlockingDeque}.
     * 
     * @return the delegate <code>BlockingDeque</code>.
     */
    protected final BlockingDeque<E> getDelegate() {
        return this.delegate;
    }

    /** 
     * {@inheritDoc}
     */
    public E pollLast() {
        return this.delegate.pollLast();
    }

}
