/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.concurrent.core.queue;

import java.util.concurrent.BlockingQueue;

/**
 * Factory for creating {@link Runnable work} queues. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface WorkQueueFactory {

    /**
     * Creates a new, unbounded {@link BlockingQueue work queue} that is capable of stealing work from other work queues
     * when empty.
     * 
     * @return the new work queue.
     */
    BlockingQueue<Runnable> newStealingWorkQueue();

    /**
     * Creates a new, bounded {@link BlockingQueue work queue} that is capable of stealing work from other work queues
     * when empty.
     * 
     * @param capacity the capacity of the work queue.
     * @return the new work queue.
     */
    BlockingQueue<Runnable> newStealingWorkQueue(int capacity);
}
