/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core;

/**
 * A configuration point is the configuration subsystem's unit of configuration data. It has a name and a recursive tree
 * structure which can be arbitrarily deep.
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface ConfigPoint extends ConfigNode {

    /**
     * Get the name of this configuration point.
     * 
     * @return the configuration point name
     */
    String getName();

    /**
     * Get the root of the tree of data for this configuration point. Equivalent to calling
     * {@link ConfigNode#getNode(java.util.List)} with an empty path.
     * 
     * @return the root node of the tree
     */
    ConfigNode getRootNode();

}
