/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core;

import org.osgi.framework.BundleContext;

/**
 * A factory API for creating {@link ConfigTree ConfigTrees}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations of this class must be thread safe.
 * 
 * @author Glyn Normington
 * @author Sam Brannen
 * @since 1.0
 */
public interface ConfigTreeFactory {

    /**
     * Locate the Server configuration file with the given base name and return a parsed and possibly validated
     * abstract syntax tree of the contents.
     * <p />
     * 
     * The given base name is used to find a configuration point schema and, if one is found and if the schema has a
     * version range, the version range is used in selecting the configuration file. Otherwise an empty version range is
     * used.
     * <p />
     * 
     * If a configuration point schema is not found, the configuration file will not be validated.
     * <p />
     * 
     * Configuration files are searched for within the configured <em>configuration path list</em>, which is a list
     * of directories from which the Server will read each subsystem's configuration. The
     * <em>configuration path list</em> is itself configured in the <code>server.config</code> file located in the
     * Server's default <code>config</code> directory.
     * <p />
     * 
     * Each configuration directory is searched for files with the specified base name. A filename containing the
     * highest version in the above version range is preferred or, if there is no such file, a filename with no version,
     * or if there is no such file, a filename with the highest version outside the above range.
     * <p />
     * 
     * If a configuration file is not found in the configuration directory, the Server falls back to the configuration
     * file included in the given bundle.
     * <p />
     * 
     * A configuration file with a version outside the preferred range is used rather than defaulting to the owning
     * bundle's configuration file in order to avoid ignoring a user-supplied configuration file. However, it is likely
     * that a validation error will occur in this case due to the configuration version being outside the range allowed
     * by the corresponding schema. This forces the user to delete the problematic configuration file or supply a
     * version that is valid.
     * 
     * @param filename the configuration file base name
     * @param configOwner the context of the bundle owning the configuration
     * @return an abstract syntax tree of the configuration file
     */
    ConfigTree createConfigTree(String filename, BundleContext configOwner);

}
