/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core;

import java.util.Set;

/**
 * A MapConfigNode contains a keyed collection of nodes.
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface MapConfigNode extends ConfigNode {

    /**
     * Get the node with the given key.
     * 
     * @param key the key of the required node
     * @return the required node or null if the key was not found
     */
    ConfigNode getNode(String key);

    /**
     * Get the set of keys in the collection
     * 
     * @return the set of keys
     */
    Set<String> getKeys();

}
