/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.springsource.server.config.core.ConfigNode;
import com.springsource.server.config.core.FatalConfigurationException;

/**
 * TODO Document AbstractConfigNode
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Glyn Normington
 * @author Sam Brannen
 * @since 1.0
 */
abstract class AbstractConfigNode implements ConfigNode {

    private static final List<String> EMPTY_PATH = new ArrayList<String>();

    private final ConfigNode parent;

    public AbstractConfigNode(ConfigNode parent) {
        if (parent == null) {
            throw new FatalConfigurationException("Invalid null parent", null);
        }
        this.parent = parent;
    }

    protected String head(List<String> path) {
        if (path.isEmpty()) {
            return null;
        } else {
            return path.get(0);
        }
    }

    protected List<String> tail(List<String> path) {
        if (path.isEmpty()) {
            return null;
        } else {
            return path.size() > 1 ? path.subList(1, path.size()) : EMPTY_PATH;
        }
    }

    /**
     * {@inheritDoc}
     */
    public ConfigNode getParent() {
        return this.parent;
    }

    /**
     * {@inheritDoc}
     */
    public final String getPath() {
        return getParent().getPath(this);
    }

    /**
     * {@inheritDoc}
     */
    public final String getPath(ConfigNode childNode) {
        if (childNode.getParent() == this) {
            return doGetPath(childNode);
        } else {
            throw new FatalConfigurationException("Invalid child node", null);
        }
    }

    protected abstract String doGetPath(ConfigNode childNode);

    /**
     * {@inheritDoc}
     */
    public ConfigNode getNode(String... path) {
        ConfigNode result = null;
        if (path != null && path.length > 0) {
            result = getNode(Arrays.asList(path));
        } else {
            result = this;
        }
        return result;
    }

}
