grammar EngineConfigPointSchema ;
options {
	output=AST ;
}

tokens {
	ConfigPointSchema ;
	MAPSCHEMA ;
	MAPLETSCHEMA ;
	LISTSCHEMA ;
	KEY ;
	STRINGSCHEMA ;
	ANYSTRING ;
	ENUM ;
	INTEGER ;
	INTEGERRANGE ;
	INTGE ;
	INTG ;
	INTLE ;
	INTL ;
	SIGNED ;
	NEGATIVE ;
	POSITIVE ;
	VERSION ;
	VERSIONRANGE ;
	VERSIONVALUE ;
	VERGE ;
	VERG ;
	VERLE ;
	VERL ;
}

@header {
package com.springsource.engine.config.core.validate;
}

@lexer::header {
package com.springsource.engine.config.core.validate;
}

@members {

public void recoverFromMismatchedSet(IntStream input, RecognitionException e, BitSet follow) throws RecognitionException {
	throw e;
}
}

@rulecatch {
catch(RecognitionException e) {
	reportError(e);
	throw e;
}
}

// EOF is crucial below to ensure invalid syntax is not quietly consumed
configPointSchema
	:	IDENTIFIER ':' configurationSchema EOF -> ^( ConfigPointSchema IDENTIFIER configurationSchema )
	;
	
configurationSchema 
	:	mapSchema | listSchema
	;
	
mapSchema
	:	'{' mapletSchema ( ',' mapletSchema )* '}' -> ^( MAPSCHEMA mapletSchema+ )
	;

mapletSchema	:	key ':' valueSchema -> ^( MAPLETSCHEMA key valueSchema )
	;

valueSchema
	:	stringSchema | configurationSchema
	;

// Since list elements share a common schema, the list schema syntax does not get confused with closed ranges such as [1,2]
listSchema	: 	'[' valueSchema ']' -> ^( LISTSCHEMA valueSchema )
	;
	
key	: 	IDENTIFIER -> ^( KEY IDENTIFIER )
	;
			
stringSchema  :	( anyString | enumeration | integer | integerRange | version | versionRange )
		-> ^( STRINGSCHEMA anyString? enumeration? integer? integerRange? version? versionRange?)
	;
	
IDENTIFIER
	:	( ALPHA | '_' ) ( ALPHA | '_' | DIGIT )*
	;
	
anyString : ( 'String' | 'string' ) -> ANYSTRING
	;
	
enumeration : ( 'Enumeration' | 'enumeration' ) '{' IDENTIFIER (',' IDENTIFIER)* '}' -> ^( ENUM IDENTIFIER+ )
	;

integer : ( 'Int' | 'int' ) -> INTEGER
	;
	
integerRange : integerRangeStart ',' integerRangeEnd -> ^( INTEGERRANGE integerRangeStart integerRangeEnd)
	;
	
integerRangeStart : '[' '-' NUMBER -> ^( INTGE NUMBER NEGATIVE ) | '[' NUMBER -> ^( INTGE NUMBER POSITIVE ) | '(' '-' NUMBER -> ^( INTG NUMBER NEGATIVE ) | '(' NUMBER -> ^( INTG NUMBER POSITIVE )
	;

integerRangeEnd : '-' NUMBER ']' -> ^( INTLE NUMBER NEGATIVE ) | NUMBER ']' -> ^( INTLE NUMBER POSITIVE ) | '-' NUMBER ')' -> ^( INTL NUMBER NEGATIVE ) | NUMBER ')' -> ^( INTL NUMBER POSITIVE )
	;
	
version : ( 'versionNumber' | 'VersionNumber' ) -> VERSION
	;

versionValue : NUMBER '.' NUMBER ('.' NUMBER)* -> ^( VERSIONVALUE NUMBER+ )
	; 

// Version range distinguished from integer range by at least one period ('.') in one of the limits	
versionRange : versionRangeStart ',' versionRangeEnd -> ^( VERSIONRANGE versionRangeStart versionRangeEnd)
	;
	
versionRangeStart : '[' versionValue -> ^( VERGE versionValue ) | '(' versionValue -> ^( VERG versionValue )
	;
	
versionRangeEnd : versionValue ']' -> ^( VERLE versionValue ) | versionValue ')' -> ^( VERL versionValue )
	;
	
NUMBER : DIGIT ( DIGIT )*
	;

fragment	
ALPHA	:	'a' .. 'z' | 'A' .. 'Z'
	;
	
fragment
DIGIT	:	'0' .. '9'
	;

COMMENT :	 '/*' .* '*/' { skip() ;}
	;

LINE_COMMENT
	:	'//' ~( '\n' | '\r' )* '\r'? '\n' { skip() ;}
	;
	
WS
	:	( ' ' | '\n' | '\r' | '\t' )+ { skip() ;}
	;
