/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal.validate;

import java.net.URL;

import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.tree.CommonTreeNodeStream;
import org.antlr.runtime.tree.Tree;

import com.springsource.server.config.core.FatalConfigurationException;

/**
 * {@link StandardEngineConfigPointValidatorFactory} is a standard implementation of {@link EngineConfigPointValidatorFactory}.
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is thread safe.
 *
 * @author Glyn Normington
 * @since 1.0
 */
public class StandardEngineConfigPointValidatorFactory implements EngineConfigPointValidatorFactory {

    /** 
     * {@inheritDoc}
     */
    public ConfigValidator createConfigPointValidator(URL configPointSchemaURL) {
        ConfigPointSchemaParser configPointSchemaParser = new AntlrConfigPointSchemaParser();

        Tree t = configPointSchemaParser.parseConfigPointSchema(configPointSchemaURL);

        EngineConfigPointSchemaWalker w = new EngineConfigPointSchemaWalker(new CommonTreeNodeStream(t));
        try {
            w.configPointSchema();
        } catch (RecognitionException e) {
            throw new FatalConfigurationException("Engine configuration abstract syntax tree does not parse", e);
        }

        return w.getConfigPointValidator();
    }

}
