/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.config.core.internal.validate;

import com.springsource.server.config.core.ConfigNode;
import com.springsource.server.config.core.ScalarConfigNode;
import com.springsource.server.config.core.diagnostics.ConfigLogEvent;
import com.springsource.server.serviceability.logging.LogService;
import com.springsource.server.serviceability.logging.LogServiceFactory;

/**
 * This class validates any scalar node as valid. Subclasses define more specific validations.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
class StandardScalarConfigNodeValidator implements ConfigValidator {

    private static final LogService LOGGER = LogServiceFactory.getLogService();

    /**
     * Create a scalar configuration node validator.
     */
    public StandardScalarConfigNodeValidator() {
    }

    /**
     * {@inheritDoc}
     */
    public boolean validate(ConfigNode configNode) {
        if (!(configNode instanceof ScalarConfigNode)) {
            LOGGER.log(ConfigLogEvent.INVALID_SCALAR, configNode.getPath());
            return false;
        }
        return true;
    }
}
