/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.control.core;

import java.util.Map;

/**
 * A <code>ControlExporter</code> provides a mechanism by which
 * Controls may be exported. Exactly what it means for a control
 * to be exported is an implementation detail.
 * <p/>
 *
 * <strong>Concurrent Semantics</strong><br />
 * Implementations are <strong>required</strong> to be thread-safe.
 *
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface ControlExporter {
    
    /**
     * Exports the given Object as a new control. The methods available on the control
     * are defined by those of the given controlInterface Class.
     * 
     * @param control The control implementation to export
     * @param controlInterface The Class that defines the control's interface
     * @return A handle to the exported control.
     */
    ControlHandle exportControl(Object control, Class<?> controlInterface);
    
    /**
     * Exports the given Object as a new control. The methods available on the control
     * are defined by those of the given controlInterface Class. The exported control
     * is annotated with the given properties.
     * 
     * @param control The control implementation to export
     * @param controlInterface The Class that defines the control's interface
     * @param properties The properties with which the exported control should be annotated
     * @return A handle to the exported control.
     */
    ControlHandle exportControl(Object control, Class<?> controlInterface, Map<String, String> properties);
}
