/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.control.core.controls;

import com.springsource.server.control.core.diagnostics.ControlLogEvent;
import com.springsource.server.osgi.framework.OsgiFramework;
import com.springsource.server.osgi.provisioning.repository.BundleRepository;
import com.springsource.server.serviceability.logging.LogService;
import com.springsource.server.serviceability.logging.LogServiceFactory;

/**
 * Standard implementation of the ProvisioningRepository control.<p />
 *
 * <strong>Concurrent Semantics</strong><br />
 * Thread-safe.
 *
 * @author Andy Wilkinson
 * @since 1.0
 */
public class StandardProvisioningRepository implements ProvisioningRepository {

    private static final LogService LOG_SERVICE = LogServiceFactory.getLogService();
    
    private final BundleRepository bundleRepository;
    
    public StandardProvisioningRepository(OsgiFramework osgiFramework) {
        this.bundleRepository = osgiFramework.getBundleInstaller().getBundleRepository();    
    }
    
    public void refresh() {        
        this.bundleRepository.refresh();
        LOG_SERVICE.log(ControlLogEvent.PROVISIONING_REPOSITORY_REFRESHED);
    }
}
