/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.control.core.diagnostics;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * {@link LogEvent} for the control subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public enum ControlLogEvent implements LogEvent {

    MBEAN_REGISTER_FAILURE(0, Level.ERROR),
    CLASS_NOT_FOUND_LOADING_SERVICE_REGISTRATION_CLASS(1, Level.ERROR),
    MBEAN_UNREGISTER_FAILURE(2, Level.ERROR),
    IMMEDIATE_SHUTDOWN_INITIATED(3, Level.INFO),
    SHUTDOWN_INITIATED(4, Level.INFO),
    PORT_IN_USE(5, Level.ERROR),
    PROVISIONING_REPOSITORY_REFRESHED(6, Level.INFO);
    
    private static final String SUBSYSTEM_NAME = "Control";
    private static final String SUBSYSTEM_CODE = "CN";
    
    private final LogEventDelegate delegate;

    ControlLogEvent(int code, Level level) {
        delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, code, level);
    }

    /** 
     * {@inheritDoc}
     */
    public String getEventCode() {
        return delegate.getEventCode();
    }

    /** 
     * {@inheritDoc}
     */
    public Level getLevel() {
        return delegate.getLevel();
    }

    /** 
     * {@inheritDoc}
     */
    public String getSubsystemName() {
        return delegate.getSubsystemName();
    }
}
