/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.app;

import com.springsource.server.common.math.Version;

/**
 * This class represents an OSGi application descriptor.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
final class MultiBundleApplicationDescriptor {

	private final String symbolicName;

	private final Version version;
	
	private final String name;
	
	private final String description;

	public MultiBundleApplicationDescriptor(String symbolicName, Version version,
			String name, String description) {
		this.symbolicName = symbolicName;
		this.version = version;
		this.name = name;
		this.description = description;
	}

	public String getSymbolicName() {
		return this.symbolicName;
	}

	public Version getVersion() {
		return this.version;
	}
	
	public String getName() {
		return this.name;
	}
	
	public String getDescription() {
		return this.description;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		return String.format("%s - %s, %s", getClass().getSimpleName(),
				this.symbolicName, this.version.toString());
	}

}
