/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.app.legacy;

import java.net.URI;

import com.springsource.server.deployer.core.Deployable;
import com.springsource.server.deployer.core.DeployableFactory;
import com.springsource.server.deployer.core.DeploymentContextFactory;
import com.springsource.server.deployer.core.DeploymentException;
import com.springsource.server.deployer.core.InformedDeployable;
import com.springsource.server.deployer.core.ModuleDeployerSet;
import com.springsource.server.deployer.core.ModuleFactory;
import com.springsource.server.deployer.core.ApplicationDeployer.DeploymentOptions;
import com.springsource.server.osgi.framework.OsgiFramework;
import com.springsource.server.serviceability.tracing.TracingService;

/**
 * {@link SingleBundleApplicationFactory} is a factory for {@link SingleBundleApplication} {@link Deployable Deployables}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @author Andy Wilkinson
 * @since 1.0
 */
class SingleBundleApplicationFactory implements DeployableFactory {

    private final OsgiFramework osgi;

    private final ModuleDeployerSet moduleDeployerSet;

    private final ModuleFactory moduleFactory;

    private final DeploymentContextFactory deploymentContextFactory;

    private final TracingService tracingService;

    SingleBundleApplicationFactory(OsgiFramework osgi, ModuleDeployerSet moduleDeployerSet, ModuleFactory moduleFactory,
        DeploymentContextFactory deploymentContextFactory, TracingService tracingService) {
        this.osgi = osgi;
        this.moduleDeployerSet = moduleDeployerSet;
        this.moduleFactory = moduleFactory;
        this.deploymentContextFactory = deploymentContextFactory;
        this.tracingService = tracingService;
    }

    /**
     * {@inheritDoc}
     */
    public InformedDeployable create(URI location, URI sourceLocation, DeploymentOptions deploymentOptions) throws DeploymentException {
        return new SingleBundleApplication(this.osgi, location, sourceLocation, deploymentOptions, this.moduleDeployerSet, this.moduleFactory,
            this.deploymentContextFactory, this.tracingService);
    }

}
