/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.controls;

import javax.management.ListenerNotFoundException;
import javax.management.MBeanNotificationInfo;
import javax.management.Notification;
import javax.management.NotificationBroadcaster;
import javax.management.NotificationBroadcasterSupport;
import javax.management.NotificationFilter;
import javax.management.NotificationListener;

/**
 * Monitors the process of the deployer recovery process.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public class RecoveryMonitor implements NotificationBroadcaster, RecoveryMonitorMBean {

    private final NotificationBroadcasterSupport broadcasterSupport = new NotificationBroadcasterSupport();

    private final Object monitor = new Object();

    private boolean recoveryComplete = false;

    /**
     * {@inheritDoc}
     */
    public boolean isRecoveryComplete() {
        synchronized (this.monitor) {
            return this.recoveryComplete;
        }
    }

    /**
     * Signals completion of the deployer recovery process.
     */
    public void signalRecoveryComplete() {
        synchronized (this.monitor) {
            if (!this.recoveryComplete) {
                this.recoveryComplete = true;
                this.broadcasterSupport.sendNotification(new Notification(NOTIFICATION_TYPE, this, 1));
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    public void addNotificationListener(NotificationListener listener, NotificationFilter filter, Object handback) throws IllegalArgumentException {
        this.broadcasterSupport.addNotificationListener(listener, filter, handback);
    }

    /**
     * {@inheritDoc}
     */
    public MBeanNotificationInfo[] getNotificationInfo() {
        return new MBeanNotificationInfo[] { new MBeanNotificationInfo(new String[] { NOTIFICATION_TYPE }, Notification.class.getName(),
            "Deployer Recovery Complete Notification.") };
    }

    /**
     * {@inheritDoc}
     */
    public void removeNotificationListener(NotificationListener listener) throws ListenerNotFoundException {
        this.broadcasterSupport.removeNotificationListener(listener);
    }
}
