/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import java.util.Collection;

/**
 * {@link ContextModuleFactory} is an interface to synthetic context {@link Module} factories.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface ContextModuleFactory {

    /**
     * Synthesise a context module for the given modules and set the context of each of the given modules to the context
     * module.
     * 
     * @param modules the modules for which a context module is required
     * * @param informedDeployable the {@link InformedDeployable} to which the modules belong
     * @return the synthesised context module
     * @throws DeploymentException 
     */
    Module createContext(Collection<Module> modules, InformedDeployable informedDeployable) throws DeploymentException;

}
