/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import java.net.URI;

import com.springsource.server.deployer.core.ApplicationDeployer.DeploymentOptions;
import com.springsource.server.osgi.framework.UnableToSatisfyDependenciesException;

/**
 * {@link DeployableFactory} is an interface to {@link Deployable} factories.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface DeployableFactory {

    /**
     * Create a {@link Deployable} from the artefact at the given staged location which came from the given source
     * location.
     * 
     * @param location the URI of the artefact
     * @param sourceLocation the original URI of the artefact
     * @param deploymentOptions the {@link DeploymentOptions} of the deployable artefact
     * @return a {@link Deployable} created from the given artefact
     * @throws DeploymentException
     * @throws UnableToSatisfyDependenciesException
     */
    InformedDeployable create(URI location, URI sourceLocation, DeploymentOptions deploymentOptions) throws DeploymentException,
        UnableToSatisfyDependenciesException;
}
