/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * Defines all the {@link LogEvent LogEvents} for the deployer subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementation is immutable.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public enum DeployerLogEvent implements LogEvent {

    APP_SYMBOLIC_NAME_MISSING(0, Level.ERROR),
    APP_VERSION_INVALID(2, Level.ERROR),
    CONFLICTING_PACKAGE_EXPORTS(3, Level.ERROR),
    APPLICATION_RESOLUTION_ERROR(4, Level.ERROR),
    HOT_DEPLOY_FAILED(5, Level.ERROR),
    HOT_REDEPLOY_FAILED(6, Level.ERROR),
    HOT_UNDEPLOY_FAILED(7, Level.ERROR),
    RECOVERY_FAILED(8, Level.ERROR),
    DUPLICATE_PACKAGE_DURING_SCOPING(9, Level.ERROR),
    DEPLOYMENT_COMPLETED(10, Level.INFO),
    DEPLOYMENT_FAILED(11, Level.ERROR),
    UNDEPLOYMENT_COMPLETED(12, Level.INFO),
    UNDEPLOYMENT_FAILED(13, Level.ERROR),
    REFRESH_COMPLETED(14, Level.INFO),
    REFRESH_FAILED(15, Level.ERROR),
    APP_SYMBOLIC_NAME_BAD_SYNTAX(16, Level.ERROR),
    DISCARDING_BUNDLE_UPDATE_LOCATION(17, Level.WARN),
    UNABLE_TO_SATISFY_CONSTRAINTS(18, Level.ERROR),
    DEPLOYMENT_FAILED_URI(19, Level.ERROR),
    BUNDLE_CONTEXT_FAILED(20, Level.ERROR),
    DUPLICATE_APP_AT_DIFFERENT_LOCATION(21, Level.ERROR),
    CLASHING_LOCATIONS(22, Level.ERROR),
    APPLICATION_DESCRIPTOR_PARSE_ERROR(23, Level.ERROR),
    CONFIG_FILE_ERROR(24, Level.ERROR),
    MODULE_START_FAILURE(25, Level.ERROR),
    MODULE_ON_STOPPED_FAILURE(26, Level.ERROR),
    MODULE_DEPLOY_FAILURE(27, Level.ERROR), 
    MODULE_STOPPING_FAILURE(28, Level.ERROR),
    START_BUNDLE_FAILURE(29, Level.ERROR),
    STOP_BUNDLE_FAILURE(30, Level.ERROR),
    HOT_DEPLOY_SKIPPED(31, Level.INFO),
    UPDATE_TIMEOUT(32, Level.ERROR),
    UPDATE_WAIT_INTERRUPTED(33, Level.ERROR),
    UPDATE_FAILURE(34, Level.ERROR),
    DEPLOY_INTERRUPTED(35, Level.ERROR),
    DUPLICATE_BSN_IN_SCOPE(36, Level.ERROR),
    MODULE_NOT_FOUND(37, Level.ERROR),
    APP_MANIFEST_NOT_FOUND(38, Level.ERROR),    
    UPDATE_ARTEFACT_NOT_FOUND(39, Level.ERROR),
    DEPLOY_TIMEOUT(40, Level.ERROR),
    MISSING_BUNDLE_SYMBOLIC_NAME(41, Level.ERROR),
    REFRESH_TIMEOUT(42, Level.ERROR),
    REFRESH_WAIT_INTERRUPTED(43, Level.ERROR),
    REFRESH_FAILURE(44, Level.ERROR),
    ARTEFACT_NOT_FOUND(45, Level.ERROR),
    ARTEFACT_UNPACK_ERROR(46, Level.ERROR),
    ARTEFACT_COPY_ERROR(47, Level.ERROR),
    HOT_DEPLOY_PROCESSING_FILE(48, Level.INFO),
    UNDEPLOY_ARTEFACT_NOT_FOUND(49, Level.ERROR),
    UPDATE_ARTEFACT_RECOVERABLE(50, Level.ERROR),
 
    APP_CONTEXT_CREATION_FAILURE_CANNOT_LOAD_BEAN_CLASS(100, Level.ERROR),
    APP_CONTEXT_CREATION_FAILURE_INVALID_PROPERTY(101, Level.ERROR),
    APP_CONTEXT_CREATION_FAILURE_TYPE_MISMATCH(102, Level.ERROR);
    
    private static final String SUBSYSTEM_NAME = "Deployer";
    private static final String SUBSYSTEM_CODE = "DE";
    
    private LogEventDelegate delegate;

    /**
     * @param code
     * @param severity
     */
    private DeployerLogEvent(int code, Level level) {
        this.delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, code, level);
    }

    /**
     * {@inheritDoc}
     */
    public String getEventCode() {
        return delegate.getEventCode();
    }

    /**
     * {@inheritDoc}
     */
    public Level getLevel() {
        return delegate.getLevel();
    }

    /**
     * {@inheritDoc}
     */
    public String getSubsystemName() {
        return delegate.getSubsystemName();
    }

}
