/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import com.springsource.server.common.math.Version;

/**
 * A {@link DeploymentContext} provides per-deployment state tracking for personality deployers. Logically, it provides
 * a map:
 * 
 * <pre>
 * ModuleDeployer +&gt; ModuleDeployerContext.
 * </pre>
 * 
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface should be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface DeploymentContext {
    
    /**
     * Get the symbolic name of the application being deployed.
     * 
     * @return the application's symbolic name
     */
    String getApplicationSymbolicName();
    
    /**
     * Get the {@link Version} of the application being deployed.
     * 
     * @return the application's {@link Version}
     */
    Version getApplicationVersion();

    /**
     * Register a {@link ModuleDeployerContext} on behalf of the given {@link ModuleDeployer} which will be called back
     * when this deployment completes.
     * 
     * @param moduleDeployer the {@link ModuleDeployer} on behalf of which the registration is being performed
     * @param moduleDeployerContext the {@link ModuleDeployerContext} to be called back
     */
    void registerModuleDeployerContext(ModuleDeployer moduleDeployer, ModuleDeployerContext moduleDeployerContext);

    /**
     * Returns the {@link ModuleDeployerContext} registered on behalf of the given {@link ModuleDeployer}. If there is no
     * such {@link ModuleDeployerContext}, return <code>null</code>.
     * 
     * @param moduleDeployer the {@link ModuleDeployer} on behalf of which the registration is being performed
     */
    ModuleDeployerContext getModuleDeployerContext(ModuleDeployer moduleDeployer);

}
