/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import java.io.Serializable;

/**
 * {@link DeploymentIdentity} is an interface for the serializable objects returned when an artefact is deployed.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface DeploymentIdentity extends Serializable {
    
    /**
     * Get the name of the deployed artefact with this {@link DeploymentIdentity}.
     * 
     * @return the symbolic name of the deployed artefact
     */
    String getSymbolicName();
    
    /**
     * Get the version of the deployed artefact with this {@link DeploymentIdentity}.
     * 
     * @return the version of the deployed artefact
     */
    String getVersion();

}
