/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import com.springsource.server.osgi.framework.UnableToSatisfyDependenciesException;
import com.springsource.server.osgi.manifest.Scoper;

/**
 * {@link ModuleImportExpander} is an interface used by {@link Module}s to expand their imports during refresh.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this class must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface ModuleImportExpander {

    /**
     * Expand the imports of the given module as part of refreshing the module.
     * 
     * @param module the module whose imports are to be expanded
     * @param scoper the {@link Scoper} to apply to unscoped bundle symbolic names or <code>null</code> if not required
     * @return <code>true</code> if and only if the module expansion does not require the refresh to be escalated
     * @throws UnableToSatisfyDependenciesException 
     */
    boolean expandImports(Module module, Scoper scoper) throws UnableToSatisfyDependenciesException;

}
