/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core;

import java.net.URI;

import com.springsource.server.deployer.core.parse.DeployerBundleManifest;

/**
 * {@link ZeroModulePersonality} is a default module personality used to deploy modules which do not need a specific
 * personality deployer. <code>ZeroPersonality</code> is also a base class that provides default behaviour for
 * specific module personalities.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * This class is thread-safe.
 * 
 * @author Glyn Normington
 * @author Sam Brannen
 * @since 1.0
 */
public class ZeroModulePersonality implements ModulePersonality {

    private static final String BUNDLE_PERSONALITY = "Bundle";

    protected final Module module;

    public ZeroModulePersonality(Module module) {
        this.module = module;
    }

    /**
     * Convenience method for retrieving the current, underlying {@link ModuleData}.
     */
    protected ModuleData getModuleData() {
        return this.module.getModuleData();
    }

    /**
     * {@inheritDoc}
     */
    public void transform() throws DeploymentException {
        ((DeployerBundleManifest) this.module.getModuleData().getBundleManifest()).getMainAttributes().putValue(
            ModuleDeployer.MODULE_TYPE_MANIFEST_HEADER, ModuleDeployer.BUNDLE_MODULE_TYPE);
    }

    /**
     * {@inheritDoc}
     */
    public void deploy() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public void start() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public void stop() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public void undeploy() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public String getPersonality() {
        return BUNDLE_PERSONALITY;
    }

    /**
     * {@inheritDoc}
     */
    public String getPersonalityIdentifier() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public void onStarting() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public void onStarted() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public void onStopping() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public void onStopped() throws DeploymentException {
    }

    /**
     * {@inheritDoc}
     */
    public void onUnresolved() {
    }

    /**
     * {@inheritDoc}
     */
    public boolean refresh(String symbolicName, ModuleDeployerSet moduleDeployerSet, CompletableDeploymentContext deploymentContext)
        throws DeploymentException {
        return false;
    }

    /** 
     * {@inheritDoc}
     */
    public void deleteResource(String symbolicName, String targetPath) {
        throw new UnsupportedOperationException();
    }

    /** 
     * {@inheritDoc}
     */
    public void updateResource(String symbolicName, URI resourceLocation, String targetPath) {
        throw new UnsupportedOperationException();
    }

}
