/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.event;

import org.osgi.framework.Bundle;

import com.springsource.server.common.math.Version;

/**
 * {@link ApplicationBundleDeploymentEvent} is the base class for all events relating to deployment of bundles of
 * applications.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is immutable and therefore thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public abstract class ApplicationBundleDeploymentEvent extends ApplicationDeploymentEvent {

    private final Bundle bundle;

    /**
     * Construct a {@link ApplicationBundleDeploymentEvent} event with the given application symbolic name, application
     * version, and bundle.
     * 
     * @param applicationSymbolicName
     * @param applicationVersion
     */
    protected ApplicationBundleDeploymentEvent(String applicationSymbolicName, Version applicationVersion, Bundle bundle) {
        super(applicationSymbolicName, applicationVersion);
        this.bundle = bundle;
    }

    /**
     * Get this event's {@link Bundle}.
     * 
     * @return the bundle
     */
    public Bundle getBundle() {
        return this.bundle;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        return this.getClass().getName() + " for bundle " + this.bundle.getSymbolicName() + " of application " + this.getApplicationSymbolicName()
            + " version " + this.getApplicationVersion();
    }

}
