/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.internal;

import com.springsource.server.deployer.core.ApplicationDeployer;
import com.springsource.server.deployer.core.DeploymentIdentity;
import com.springsource.server.serviceability.ffdc.DumpExtension;
import com.springsource.server.serviceability.ffdc.DumpWriter.ListWriter;
import com.springsource.server.serviceability.ffdc.DumpWriter.SectionWriter;

/**
 * Allow the deployer to participate in the FFDC dump.
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is thread safe.
 *
 * @author Christopher Frost
 * @since 1.0
 */
class DeployerDumpExtension implements DumpExtension {

    private ApplicationDeployer applicationDeployer;

    /**
     * Creates a new {@link DeployerDumpExtension}. 
     * @param applicationDeployer the {@link ApplicationDeployer}
     */
    public DeployerDumpExtension(ApplicationDeployer applicationDeployer) {
        this.applicationDeployer = applicationDeployer;
    }
    
    /**
     * {@inheritDoc}
     */
    public void dump(SectionWriter sectionWriter) {
        DeploymentIdentity[] deploymentIdentities = applicationDeployer.getDeploymentIdentities();
        ListWriter<SectionWriter> list = sectionWriter.list("Deployed artefacts");
        for(DeploymentIdentity deploymentIdentity: deploymentIdentities){
            list.map().scalar("symbolic name", deploymentIdentity.getSymbolicName()).scalar("version", deploymentIdentity.getVersion());
        }
        list.end();
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return this.getClass().getCanonicalName().replace(".core.internal.DeployerDumpExtension", "");
    }

}
