/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.deployer.core.parse;

import com.springsource.server.osgi.manifest.parse.AntlrLogMessageService;
import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogService;
import com.springsource.server.serviceability.logging.LogServiceFactory;
import com.springsource.server.serviceability.output.Level;

/**
 * {@link DeployerParserLogger} maps OSGi bundle manifest parsing errors to log messages.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Christopher Frost
 * @author Glyn Normington
 * @since 1.0
 */
final class DeployerParserLogger extends AntlrLogMessageService {

    static final LogService LOGGER = LogServiceFactory.getLogService();

    public DeployerParserLogger() {
        super("DE");// Subsystem code for the deployer subsystem
    }

    @Override
    public void messageProcessed(String eventCode, String message) {
        LOGGER.log(new DeployerLogEventDelegate(eventCode), message);
    }

    private final class DeployerLogEventDelegate implements LogEvent {

        // private static final String SYSTEM_NAME = "SE";
        // private static final String SUBSYSTEM_CODE = "DE";
        private static final String SUBSYSTEM_NAME = "Deployer";

        private final Level level;

        private final String fullEventCode;

        private DeployerLogEventDelegate(String eventCode) {
            char c = eventCode.charAt(6);

            if (c == 'E') {
                this.level = Level.ERROR;
            } else if (c == 'W') {
                this.level = Level.WARN;
            } else {
                this.level = Level.INFO;
            }

            this.fullEventCode = eventCode;
        }

        /**
         * Required by the <code>StandardLogService</code> to retrieve the correct error message.
         * 
         * @return the full and unique code for this log event.
         */
        public String getEventCode() {
            return this.fullEventCode;
        }

        /** 
         * {@inheritDoc}
         */
        public String getSubsystemName() {
            return SUBSYSTEM_NAME;
        }

        /** 
         * {@inheritDoc}
         */
        public Level getLevel() {
            return this.level;
        }

    }

}
