/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.ffdc.core.internal;

import java.util.Set;

import com.springsource.server.bootstrap.BootstrapConfiguration;
import com.springsource.server.serviceability.ffdc.DumpExtension;
import com.springsource.server.serviceability.ffdc.DumpGenerator;
import com.springsource.server.serviceability.ffdc.FFDCService;

/**
 * Implementation of the {@link FFDCService} interface
 * 
 * <p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe.
 * 
 * @author Damilola Senbanjo
 * @author Sam Brannen
 * @since 1.0
 */

public class StandardFFDCService implements FFDCService {

    private final BootstrapConfiguration bootstrapConfiguration;

    private final Set<DumpExtension> dumpExtensions;

    /**
     * Constructs a new implementation of {@link FFDCService}
     * 
     * @param bootstrapConfiguration configuration required to launch the Server
     * @param dumpExtensions set of dump extensions
     * @param subRegistry collection of registered subsystems
     */
    public StandardFFDCService(BootstrapConfiguration bootstrapConfiguration, Set<DumpExtension> dumpExtensions) {
        this.bootstrapConfiguration = bootstrapConfiguration;
        this.dumpExtensions = dumpExtensions;
    }

    /**
     * {@inheritDoc}
     */
    public void generateDump(Throwable throwable) {
        DumpGenerator dumpGenerator = new StandardDumpGenerator(this.bootstrapConfiguration, this.dumpExtensions);
        dumpGenerator.createDumpFile(throwable);
    }

}
