/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.bootstrap;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.osgi.framework.Bundle;

/**
 * @author Glyn Normington
 * 
 */
public final class StandardSubsystemContents implements SubsystemContents {

    private static final class StandardSubsystemConfiguration implements SubsystemConfiguration {

        private final List<Bundle> bundles = new ArrayList<Bundle>(3);

        private final String subsystemName;

        public StandardSubsystemConfiguration(String subsystemName) {
            this.subsystemName = subsystemName;
        }

        public List<Bundle> getBundles() {
            return this.bundles;
        }

        public String getSubsystemName() {
            return this.subsystemName;
        }

        /**
         * Pre-condition: the given bundle is not already in the bundles list.
         * 
         * @param bundle
         */
        public void addBundle(Bundle bundle) {
            this.bundles.add(bundle);
        }
    }

    private final Map<String, StandardSubsystemConfiguration> subsystemConfigurations = new HashMap<String, StandardSubsystemConfiguration>();

    /**
     * {@inheritDoc}
     */
    public void addBundle(String subsystemName, Bundle bundle) {
        if (!this.subsystemConfigurations.containsKey(subsystemName)) {
            this.subsystemConfigurations.put(subsystemName, new StandardSubsystemConfiguration(subsystemName));
        }

        this.subsystemConfigurations.get(subsystemName).addBundle(bundle);
    }

    /**
     * {@inheritDoc}
     */
    public Collection<? extends SubsystemConfiguration> getSubsystemConfigurations() {
        return this.subsystemConfigurations.values();
    }

}
