/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core.internal;

import org.osgi.framework.Bundle;

import com.springsource.server.kernel.core.BundleDescriptor;

/**
 * Immutable implementation of {@link BundleDescriptor} that is backed by the actual {@link Bundle} and thus provides a
 * live representation of the <code>Bundle</code> state. <p/> <strong>Concurrent Semantics</strong><br/>
 * Implementation is immutable and therefore concurrent.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class ImmutableBundleDescriptor implements BundleDescriptor {

    /**
     * The {@link Bundle} being described.
     */
    private final Bundle bundle;

    /**
     * Creates a new <code>ImmutableBundleDescriptor</code> backed by the supplied {@link Bundle}.
     * 
     * @param bundle the backing <code>Bundle</code>.
     */
    public ImmutableBundleDescriptor(Bundle bundle) {
        this.bundle = bundle;
    }

    /**
     * {@inheritDoc}
     */
    public int getState() {
        return this.bundle.getState();
    }

    /**
     * {@inheritDoc}
     */
    public String getSymbolicName() {
        return this.bundle.getSymbolicName();
    }

    /** 
     * {@inheritDoc}
     */
    public Bundle getBundle() {
        return this.bundle;
    }

}
