/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core.internal;

import java.util.List;

import org.osgi.framework.Bundle;

import com.springsource.server.kernel.core.Subsystem;

/**
 * Extends {@link Subsystem} to provide internal access to raw {@link Bundle} state. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations are required to honour the concurrent semantics of the <code>Subsystem</code> interface.
 * 
 * @author Rob Harrop
 * @author Glyn Normington
 * @since 1.0
 */
interface ManagedSubsystem extends Subsystem {

    /**
     * Gets the {@link Bundle Bundles} for the <code>Subsystem</code>.
     * 
     * @return an unmodifiable {@link List} of the installed {@link Bundle Bundles}.
     */
    List<Bundle> getBundles();

    /**
     * Get the subsystem registry.
     * 
     * @return the subsystem registry
     */
    ManagedSubsystemRegistry getSubsystemRegistry();
}
