/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core.internal;

import com.springsource.server.kernel.core.KernelException;
import com.springsource.server.kernel.core.SubsystemInstaller;
import com.springsource.server.kernel.core.internal.install.SubsystemDescriptor;
import com.springsource.server.kernel.core.internal.install.SubsystemResolver;

/**
 * 
 * @author Glyn Normington
 * 
 */
class StandardSubsystemInstaller implements SubsystemInstaller {

    final SubsystemResolver subsystemResolver;

    final ManagedSubsystemRegistry subsystemRegistry;

    StandardSubsystemInstaller(ManagedSubsystemRegistry subsystemRegistry, SubsystemResolver subsystemResolver) {
        this.subsystemRegistry = subsystemRegistry;
        this.subsystemResolver = subsystemResolver;
    }

    public ManagedSubsystem installSubsystem(String name) throws KernelException {
        SubsystemDescriptor descriptor = this.subsystemResolver.resolveSubsystemDescriptor(name);

        if (descriptor == null) {
            return null;
        }

        StandardSubsystem subsystem = new StandardSubsystem(this.subsystemRegistry, descriptor.getName(), descriptor.getBundleDefinitions());
        subsystem.install();

        return subsystem;
    }

}
