/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.core.internal.install;

import java.util.List;

import com.springsource.server.common.math.OrderedPair;
import com.springsource.server.osgi.manifest.VersionRange;

/**
 * {@link SubsystemDescriptor} backed by data from an XML formatted subsystem descriptor. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementation is immutable and therefore thread safe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class XmlSubsystemDescriptor implements SubsystemDescriptor {

    private final String name;

    private final String description;

    private final List<OrderedPair<String, VersionRange>> bundleDefinitions;

    /**
     * Creates a new {@link XmlSubsystemDescriptor} with the supplied subsystem name, subsystem description and bundle
     * location list.
     * 
     * @param name the subsystem name.
     * @param description the subsystem description.
     * @param bundleDefinitions the <code>List<code> of bundle definitions.
     */
    public XmlSubsystemDescriptor(String name, String description, List<OrderedPair<String, VersionRange>> bundleDefinitions) {
        this.name = name;
        this.description = description;
        this.bundleDefinitions = bundleDefinitions;
    }

    /**
     * {@inheritDoc}
     */
    public List<OrderedPair<String, VersionRange>> getBundleDefinitions() {
        return this.bundleDefinitions;
    }

    /**
     * {@inheritDoc}
     */
    public String getDescription() {
        return this.description;
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return this.name;
    }

}
