/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.dm;

import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;

import org.springframework.context.ApplicationContext;
import org.springframework.osgi.extender.OsgiApplicationContextCreator;

/**
 * Registry of {@link OsgiApplicationContextCreator OsgiApplicationContextCreators} that are used by personality
 * deployers to customise the {@link ApplicationContext ApplicationContexts} created for their module types.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public final class OsgiApplicationContextCreatorRegistry {

    private static Set<OsgiApplicationContextCreator> CREATORS = new CopyOnWriteArraySet<OsgiApplicationContextCreator>();

    /**
     * Gets all registered {@link OsgiApplicationContextCreator OsgiApplicationContextCreators}.
     * 
     * @return the registered <code>OsgiApplicationContextCreators</code>.
     */
    static Set<OsgiApplicationContextCreator> getRegisteredContextCreators() {
        return CREATORS;
    }

    /**
     * Registers a new {@link OsgiApplicationContextCreator}.
     * 
     * @param contextCreator the new <code>OsgiApplicationContextCreator</code>.
     */
    public static void registerContextCreator(OsgiApplicationContextCreator contextCreator) {
        CREATORS.add(contextCreator);
    }
}
