/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.kernel.dm;

import java.util.Set;

import org.springframework.osgi.extender.OsgiApplicationContextCreator;

import com.springsource.server.serviceability.tracing.Tracer;
import com.springsource.server.serviceability.tracing.TracerFactory;

/**
 * <code>OsgiApplicationContextCreatorRegistryConfigurer</code> is intended to be used as a simple Spring bean for
 * configuring the {@link OsgiApplicationContextCreatorRegistry} (i.e., by allowing one to register
 * {@link OsgiApplicationContextCreator OsgiApplicationContextCreators} within a Spring
 * {@link org.springframework.context.ApplicationContext ApplicationContext}).
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Immutable and therefore thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
public final class OsgiApplicationContextCreatorRegistryConfigurer {

    private static final Tracer TRACER = TracerFactory.createTracer(OsgiApplicationContextCreatorRegistryConfigurer.class);

    /**
     * Creates a new OsgiApplicationContextCreatorRegistryConfigurer, which as a side-effect
     * {@link OsgiApplicationContextCreatorRegistry#registerContextCreator(OsgiApplicationContextCreator) registers} the
     * set of supplied {@link OsgiApplicationContextCreator OsgiApplicationContextCreators} with the
     * {@link OsgiApplicationContextCreatorRegistry}.
     * 
     * @param contextCreators the context creators to register
     */
    public OsgiApplicationContextCreatorRegistryConfigurer(Set<OsgiApplicationContextCreator> contextCreators) {
        for (OsgiApplicationContextCreator contextCreator : contextCreators) {
            TRACER.traceDebug("Registering OsgiApplicationContextCreator [%s].", contextCreator);
            OsgiApplicationContextCreatorRegistry.registerContextCreator(contextCreator);
        }
    }

}
