/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */
package com.springsource.server.kernel.dm;

import javax.management.MBeanException;
import javax.management.modelmbean.ModelMBean;

import org.springframework.jmx.export.annotation.AnnotationMBeanExporter;

import com.springsource.server.serviceability.tracing.TracingService;

/**
 * An extension of {@link AnnotationMBeanExporter} that exports Server-specific MBeans.
 * 
 * <strong>Concurrent Semantics</strong><br /> As thread-safe as <code>MBeanExporter</code>.
 */
public final class ServerAnnotationMBeanExporter extends AnnotationMBeanExporter {

    private final TracingService tracingService;

    ServerAnnotationMBeanExporter(TracingService tracingService) {
	this.tracingService = tracingService;
    }

    @Override
    protected ModelMBean createModelMBean() throws MBeanException {
	return new ServerModelMBean(this.tracingService, tracingService.getCurrentApplicationName());
    }
}
