/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.application;

import java.util.Date;
import java.util.List;

import com.springsource.server.management.proxy.core.Info;

/**
 * <p>
 * Used to expose management information about a deployed application, and it's 
 * constituent modules/deployed bundles. See {@link ServerModuleInfo ServerModuleInfo}
 * </p>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface must be Thread Safe
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public interface ServerApplicationInfo extends Info{

    /**
     * The name of the application as specified in the manifest, other wise something sensible
     * @return
     */
    String getName();

    /**
     * The specified version of the application or '0' if unknown
     * @return
     */
    String getVersion();

    /**
     * The number of milliseconds since midnight, January 1, 1970 UTC, when this application was deployed
     * @return
     */
    Date getDeployTime();

    /**
     * The type of the application, OSGi/non-OSGi etc...
     * @return
     */
    String getType();

    /**
     * Get the {@link ServerModuleInfo ServerModuleInfos} of all the modules of this application.
     * 
     * @return this application's {@link ServerModuleInfo ServerModuleInfos}
     */
    List<ServerModuleInfo> getServerModuleInfo();
    
    /**
     * Get the URI used to deploy this application.
     * 
     * @return the string form of the URI
     */
    String getURI();

}
