/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.application;

import com.springsource.server.management.proxy.core.Info;

/**
 * {@link ServerModuleInfo} provides management information for a deployed module of an application.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public interface ServerModuleInfo extends Comparable<ServerModuleInfo>, Info{

    /**
     * Get the personality of this module.
     * 
     * @return the personality of this module or <code>null</code> if this module is devoid of personality
     */
    String getPersonality();

    /**
     * Get an identifier of this module which uniquely identifies the module among all modules of the same personality.
     * 
     * @return the personality identifier of this module or <code>null</code> if this module is devoid of personality
     */
    String getPersonalityIdentifier();
    
    /**
     * Get the symbolic name that this bundle is based on.
     * @return the symbolic bundle name as specified in the manifest header
     */
    String getBundleSymbolicName();
    
}


