/* 
 * This file is part of the SpringSource DM Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource DM Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource DM Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource DM Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.application;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * This class acts as an adaptor to ensure the correct visibility of the exposed concrete management information and
 * also to wrap the list of <code>ServerModuleInfo</code> objects for easier and ordered display in any using system.
 * </p>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public class StandardServerApplicationInfoAdaptor implements ServerApplicationInfo {

    private final ServerApplicationInfo serverApplicationInfo;

    /**
     * Simple constructor that takes in an existing <code>ServerApplicationInfo</code> and wraps it to provide a public
     * level
     * 
     * @param serverApplicationInfo
     */
    public StandardServerApplicationInfoAdaptor(ServerApplicationInfo serverApplicationInfo) {
        this.serverApplicationInfo = serverApplicationInfo;
    }

    /**
     * {@inheritDoc}
     */
    public Date getDeployTime() {
        return this.serverApplicationInfo.getDeployTime();
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return this.serverApplicationInfo.getName();
    }

    /**
     * {@inheritDoc}
     */
    public String getType() {
        return this.serverApplicationInfo.getType();
    }

    /**
     * {@inheritDoc}
     */
    public String getURI() {
        return this.serverApplicationInfo.getURI();
    }

    /**
     * {@inheritDoc}
     */
    public String getVersion() {
        return this.serverApplicationInfo.getVersion();
    }

    /**
     * {@inheritDoc}
     */
    public List<ServerModuleInfo> getServerModuleInfo() {
        List<ServerModuleInfo> moduleInfos = new ArrayList<ServerModuleInfo>();
        for (ServerModuleInfo serverModuleInfo : this.serverApplicationInfo.getServerModuleInfo()) {
            moduleInfos.add(new StandardServerModuleInfoAdaptor(serverModuleInfo));
        }
        Collections.sort(moduleInfos);
        return moduleInfos;
    }

}
