/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.profile;

import com.springsource.server.management.proxy.core.Info;

/**
 * <p>
 * For each subsystem that the running profile brings up an implementation of this 
 * interface should be created and added to the service registry for the management
 * /admin systems to access.
 * </p>
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * Implementations of this interface should be thread safe
 *
 * @author Christopher Frost
 * @since 1.0
 */
public interface ProfileSubsystemInfo extends Info {
   
    /**
     * e.g. bootstrap
     * @return the name of the profile that brought this subsystem up
     */
    public String getProfileName();
    
    /**
     * e.g. com.springsource.server.web
     * @return the name of the subsystem that is being represented
     */
    public String getSubsystemName();
    
    /**
     * e.g. ACTIVE
     * @return the state of the subsystem within OSGi
     */
    public String getSubsystemState();
    
}
