/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.management.proxy.serviceability;

import com.springsource.server.serviceability.output.Destination;

/**
 * <p>
 * This is the standard implementation of <code>DestinationServiceInfo</code>
 * </p>
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * This class is thread safe
 *
 * @author Christopher Frost
 * @since 1.0
 */
public class StandardDestinationServiceInfo implements DestinationServiceInfo {

    private final Destination destination;
    private final String name;

    /**
     * Stores the provided args for later retrieval by the management 
     * system as required.
     * 
     * @param name
     * @param destination
     */
    public StandardDestinationServiceInfo(String name, Destination destination) {
        this.destination = destination;
        this.name = name;
    }
    
    /**
     * 
     * {@inheritDoc}
     */
    public String getName(){
        return name;
    }
    
    /**
     * 
     * {@inheritDoc}
     */
    public String getDestinationString(){
        return this.destination.toString();
    }

}
