/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework;

import java.lang.instrument.ClassFileTransformer;

/**
 * Provides an interface onto <code>ClassLoaders</code> that support the use of
 * {@link ClassFileTransformer ClassFileTransformers} for load-time weaving.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface InstrumentableClassLoader {

    /**
     * Adds the supplied {@link ClassFileTransformer} to the {@link ClassLoader}. All subsequent class loads will pass
     * through the newly added <code>ClassFileTransformer</code>.
     * 
     * @param transformer the <code>ClassFileTransformer</code>.
     */
    void addClassFileTransformer(ClassFileTransformer transformer);

    /**
     * Creates a throw away {@link ClassLoader} that can be used to explore and introspect on types that will be loaded
     * by this <code>ClassLoader</code>.
     * 
     * @return the throw away <code>ClassLoader</code>.
     */
    ClassLoader createThrowAway();
}
