/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework;

/**
 * Configuration data for an {@link OsgiFramework}.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Rob Harrop
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface OsgiConfiguration {

    /**
     * Get the repository search paths that are searched (in order) for bundles.
     * 
     * @return the search paths.
     */
    String[] getSearchPaths();

    /**
     * Gets the install path.
     * 
     * @return the install path.
     */
    String getInstallPath();

    /**
     * Gets the work directory path.
     * 
     * @return the work directory path.
     */
    String getWorkDirectory();

    /**
     * Get the absolute path to the Server's root to be used to make any relative paths absolute.
     * 
     * @return the absolute path to the Server's root.
     */
    String getAbsoluteRoot();
}
