/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework;

/**
 * A Server-specific extension to {@link NoClassDefFoundError} that provides access to the ClassLoader that attempted
 * the class load. TODO Document ServerClassNotFoundException
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * <strong>Thread-safe</strong>
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public class ServerNoClassDefFoundError extends NoClassDefFoundError {

    private static final long serialVersionUID = 4573722090207901849L;

    private final ClassLoader classLoader;

    public ServerNoClassDefFoundError(ClassLoader classLoader, NoClassDefFoundError cause) {
        super(cause.getMessage() + " in " + classLoader);
        this.classLoader = classLoader;
        initCause(cause);
    }

    public ClassLoader getClassLoader() {
        return this.classLoader;
    }
}
