/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework;

import org.osgi.framework.Version;

/**
 * Signals an error resolving the dependencies of a bundle during installation.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public class UnableToSatisfyBundleDependenciesException extends UnableToSatisfyDependenciesException {

    private static final long serialVersionUID = -4291846255969729124L;

    private static final String BUNDLE_ENTITY = "bundle";

    /**
     * Creates a new <code>UnableToSatisfyBundleDependenciesException</code>.
     * 
     * @param symbolicName the symbolic name of the bundle.
     * @param version the bundle version.
     * @param failureDescription a description of the failure.
     */
    public UnableToSatisfyBundleDependenciesException(String symbolicName, Version version, String failureDescription) {
        super(BUNDLE_ENTITY, symbolicName, version, failureDescription);
    }
}
