/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.equinox;

import java.io.File;
import java.io.InputStream;
import java.util.Dictionary;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.BundleException;
import org.osgi.framework.BundleListener;
import org.osgi.framework.Filter;
import org.osgi.framework.FrameworkListener;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.framework.ServiceListener;
import org.osgi.framework.ServiceReference;
import org.osgi.framework.ServiceRegistration;

/**
 * TODO Document BundleContextWrapper
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class BundleContextWrapper implements BundleContext {

    private final BundleContext delegate;

    /**
     * @param delegate
     */
    public BundleContextWrapper(BundleContext delegate) {
        this.delegate = delegate;
    }

    /**
     * @see org.osgi.framework.BundleContext#addBundleListener(org.osgi.framework.BundleListener)
     */
    public void addBundleListener(BundleListener listener) {
        synchronized (LockManager.getMainLock()) {
            this.delegate.addBundleListener(listener);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#addFrameworkListener(org.osgi.framework.FrameworkListener)
     */
    public void addFrameworkListener(FrameworkListener listener) {
        synchronized (LockManager.getMainLock()) {
            this.delegate.addFrameworkListener(listener);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#addServiceListener(org.osgi.framework.ServiceListener, java.lang.String)
     */
    public void addServiceListener(ServiceListener listener, String filter) throws InvalidSyntaxException {
        synchronized (LockManager.getMainLock()) {
            this.delegate.addServiceListener(listener, filter);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#addServiceListener(org.osgi.framework.ServiceListener)
     */
    public void addServiceListener(ServiceListener listener) {
        synchronized (LockManager.getMainLock()) {
            this.delegate.addServiceListener(listener);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#createFilter(java.lang.String)
     */
    public Filter createFilter(String filter) throws InvalidSyntaxException {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.createFilter(filter);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getAllServiceReferences(java.lang.String, java.lang.String)
     */
    public ServiceReference[] getAllServiceReferences(String clazz, String filter) throws InvalidSyntaxException {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getAllServiceReferences(clazz, filter);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getBundle()
     */
    public Bundle getBundle() {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getBundle();
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getBundle(long)
     */
    public Bundle getBundle(long id) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getBundle(id);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getBundles()
     */
    public Bundle[] getBundles() {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getBundles();
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getDataFile(java.lang.String)
     */
    public File getDataFile(String filename) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getDataFile(filename);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getProperty(java.lang.String)
     */
    public String getProperty(String key) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getProperty(key);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getService(org.osgi.framework.ServiceReference)
     */
    public Object getService(ServiceReference reference) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getService(reference);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getServiceReference(java.lang.String)
     */
    public ServiceReference getServiceReference(String clazz) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getServiceReference(clazz);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#getServiceReferences(java.lang.String, java.lang.String)
     */
    public ServiceReference[] getServiceReferences(String clazz, String filter) throws InvalidSyntaxException {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.getServiceReferences(clazz, filter);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#installBundle(java.lang.String, java.io.InputStream)
     */
    public Bundle installBundle(String location, InputStream input) throws BundleException {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.installBundle(location, input);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#installBundle(java.lang.String)
     */
    public Bundle installBundle(String location) throws BundleException {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.installBundle(location);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#registerService(java.lang.String, java.lang.Object, java.util.Dictionary)
     */
    @SuppressWarnings("unchecked") public ServiceRegistration registerService(String clazz, Object service, Dictionary properties) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.registerService(clazz, service, properties);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#registerService(java.lang.String[], java.lang.Object, java.util.Dictionary)
     */
    @SuppressWarnings("unchecked") public ServiceRegistration registerService(String[] clazzes, Object service, Dictionary properties) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.registerService(clazzes, service, properties);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#removeBundleListener(org.osgi.framework.BundleListener)
     */
    public void removeBundleListener(BundleListener listener) {
        synchronized (LockManager.getMainLock()) {
            this.delegate.removeBundleListener(listener);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#removeFrameworkListener(org.osgi.framework.FrameworkListener)
     */
    public void removeFrameworkListener(FrameworkListener listener) {
        synchronized (LockManager.getMainLock()) {
            this.delegate.removeFrameworkListener(listener);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#removeServiceListener(org.osgi.framework.ServiceListener)
     */
    public void removeServiceListener(ServiceListener listener) {
        synchronized (LockManager.getMainLock()) {
            this.delegate.removeServiceListener(listener);
        }
    }

    /**
     * @see org.osgi.framework.BundleContext#ungetService(org.osgi.framework.ServiceReference)
     */
    public boolean ungetService(ServiceReference reference) {
        synchronized (LockManager.getMainLock()) {
            return this.delegate.ungetService(reference);
        }
    }

}
