/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.equinox;

import java.security.ProtectionDomain;
import java.util.ArrayList;

import org.eclipse.osgi.baseadaptor.BaseData;
import org.eclipse.osgi.baseadaptor.bundlefile.BundleEntry;
import org.eclipse.osgi.baseadaptor.hooks.ClassLoadingHook;
import org.eclipse.osgi.baseadaptor.loader.BaseClassLoader;
import org.eclipse.osgi.baseadaptor.loader.ClasspathEntry;
import org.eclipse.osgi.baseadaptor.loader.ClasspathManager;
import org.eclipse.osgi.framework.adaptor.BundleProtectionDomain;
import org.eclipse.osgi.framework.adaptor.ClassLoaderDelegate;
import org.eclipse.osgi.internal.baseadaptor.DefaultClassLoader;

import com.springsource.server.serviceability.tracing.Tracer;
import com.springsource.server.serviceability.tracing.TracerFactory;

/**
 * {@link ClassLoadingHook} to replace the standard Equinox {@link DefaultClassLoader} with the
 * {@link ServerBundleClassLoader}. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class ServerBundleClassLoaderHook implements ClassLoadingHook {

    private static final Tracer TRACER = TracerFactory.createTracer(ServerBundleClassLoaderHook.class);

    /**
     * {@inheritDoc}
     */
    @SuppressWarnings("unchecked")// Can't add generics to the ArrayList as it breaks inheritence with the super class
    public boolean addClassPathEntry(ArrayList cpEntries, String cp, ClasspathManager hostmanager, BaseData sourcedata, ProtectionDomain sourcedomain) {
        return false;
    }

    /**
     * Creates a {@link ServerBundleClassLoader} in place of the standard Equinox {@link DefaultClassLoader}.
     */
    public BaseClassLoader createClassLoader(ClassLoader parent, ClassLoaderDelegate delegate, BundleProtectionDomain domain, BaseData data,
        String[] bundleclasspath) {
        if (TRACER.isInfoEnabled()) {
            TRACER.traceInfo(String.format("Creating ServerBundleClassLoader for: %s", data.getSymbolicName()));
        }
        return new ServerBundleClassLoader(parent, delegate, domain, data, bundleclasspath);
    }

    /**
     * {@inheritDoc}
     */
    public String findLibrary(BaseData data, String libName) {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public ClassLoader getBundleClassLoaderParent() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public void initializedClassLoader(BaseClassLoader baseClassLoader, BaseData data) {
    }

    /**
     * {@inheritDoc}
     */
    public byte[] processClass(String name, byte[] classbytes, ClasspathEntry classpathEntry, BundleEntry entry, ClasspathManager manager) {
        return null;
    }

}
