/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.support;

import com.springsource.server.osgi.framework.OsgiConfiguration;

/**
 * Abstract implementation of {@link  OsgiConfiguration}.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @author Andy Wilkinson
 * @since 1.0
 */
public abstract class AbstractOsgiConfiguration implements OsgiConfiguration {

    private final String[] providers;

    private final String workDirectory;

    private final String installPath;

    private final String absoluteRoot;

    /**
     * Creates a new <code>AbstractOsgiConfiguration</code> with the repository search paths.
     * 
     * @param searchPaths the bundle definition providers.
     */
    protected AbstractOsgiConfiguration(String[] searchPaths, String installPath, String workDirectory, String absoluteRoot) {
        if (searchPaths == null || searchPaths.length == 0) {
            throw new IllegalArgumentException("Must specify at least one search path.");
        }
        this.providers = searchPaths;
        this.workDirectory = workDirectory;
        this.installPath = installPath;
        this.absoluteRoot = absoluteRoot;
    }

    /**
     * {@inheritDoc}
     */
    public String[] getSearchPaths() {
        return this.providers;
    }

    public String getWorkDirectory() {
        return this.workDirectory;
    }

    /**
     * {@inheritDoc}
     */
    public String getInstallPath() {
        return this.installPath;
    }

    /**
     * {@inheritDoc}
     */
    public String getAbsoluteRoot() {
        return this.absoluteRoot;
    }

}
