/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.support;

/**
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Instances of this class are immutable. All methods are thread-safe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public final class FilePathSanitiser {

    private static final String FILE_SCHEME = "file:";

    /**
     * Sanitises the supplied path, thereby making it suitable for use by OSGi. Specifically this method will ensure
     * that the path is prefixed with file:// and will ensure that drive identifiers at the starts of a Windows path are
     * correctly formatted.
     * 
     * @param path The path to be sanitised
     * @return The sanitised path
     */
    public static String sanitise(String path) {
        String sanitisedPath = path.replace('\\', '/');

        if (sanitisedPath.startsWith(FILE_SCHEME)) {
            sanitisedPath = sanitisedPath.substring(FILE_SCHEME.length());
        }

        int slashCount = 0;

        while (sanitisedPath.charAt(slashCount++) == '/') {
            ;
        }

        sanitisedPath = sanitisedPath.substring(slashCount - 1);
        sanitisedPath = FILE_SCHEME + "///" + sanitisedPath;

        return sanitisedPath;

        /*
         * if (!path.startsWith("file:///")) { if (path.startsWith("file://")) { if (path.lastIndexOf(':') != 4) {
         * sanitisedPath = path.substring(0, 5) + '/' + path.substring(5); } } else { if (path.indexOf(':') != -1) {
         * sanitisedPath = "file:///" + path; } else { sanitisedPath = "file://" + path; } } } return sanitisedPath;
         */
    }
}
