/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.support;

import org.osgi.framework.Bundle;

import com.springsource.server.osgi.framework.Library;

/**
 * Implementation of {@link Library} that maintains an unmodified array of the {@link Bundle Bundles} in the library.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class ImmutableLibrary implements Library {

    private final Bundle[] bundles;

    /**
     * Creates a new <code>ImmutableLibrary</code>.
     * 
     * @param bundles the {@link Bundle Bundles} in the library.
     */
    public ImmutableLibrary(Bundle[] bundles) {
        this.bundles = bundles;
    }

    /**
     * {@inheritDoc}
     */
    public Bundle[] getBundles() {
        Bundle[] copy = new Bundle[this.bundles.length];
        System.arraycopy(this.bundles, 0, copy, 0, this.bundles.length);
        return copy;
    }

}
