/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.framework.support.merge;

import java.util.List;

import com.springsource.server.osgi.manifest.BundleManifest.ImportPackageHeader.PackageImport;

/**
 * {@link AdditionalTrackedPackageImports} is a {@link TrackedPackageImports} representing a collection of package
 * imports to be added to one or more bundles from a given source.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public class AdditionalTrackedPackageImports extends AbstractTrackedPackageImports {

    private final List<PackageImport> packageImports;

    private final String source;

    /**
     * Construct an {@link AdditionalTrackedPackageImports} with the given collection of package imports and the given source.
     * 
     * @param packageImports the list of package imports
     * @param source the source
     */
    public AdditionalTrackedPackageImports(List<PackageImport> packageImports, String source) {
        super(convertPackageImportListToMap(packageImports));
        this.packageImports = packageImports;
        this.source = source;
    }

    /**
     * {@inheritDoc}
     */
    public String getSource(String pkg) {
        return !convertPackageImportListToMap(this.packageImports).containsKey(pkg) ? null : this.source;
    }

}
