/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.HashMap;
import java.util.Map;


/**
 * An abstract base class for import implementations
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 * This class is <strong>thread-safe</strong>.
 * @author Andy Wilkinson
 * @since 1.0
 */
public abstract class AbstractImport {
    
    protected static final String RESOLUTION_OPTIONAL = "optional";

    protected static final String RESOLUTION_MANDATORY = "mandatory";

    protected static final String RESOLUTION_DIRECTIVE_NAME = "resolution";
    
    protected static final String SHARING_DIRECTIVE_NAME = "sharing";

    protected static final String SHARING_SHARE = "share";

    protected static final String SHARING_CLONE = "clone";

    protected static final String SHARING_AUTOMATIC = "automatic";

    protected static final String ATTRIBUTE_VERSION = "version";

    protected static final String ATTRIBUTE_ALTERNATE_VERSION = "specification-version";

    protected final Map<String, String> attributes = new HashMap<String, String>();

    protected static final String ATTRIBUTE_SEPARATOR = ";";

    protected static final String EQUALS = "=";

    protected static final String DIRECTIVE = ":=";
    
    protected static final String IMPORT_SCOPE_DIRECTIVE_NAME = "import-scope";

    protected static final String IMPORT_SCOPE_APPLICATION = "application";

    protected static final String IMPORT_SCOPE_BUNDLE = "bundle";
    
    private static final String DEFAULT_VERSION_RANGE = "0";
    
    /**
     * @param versionRange
     * @return
     */
    protected static String getDefaultedVersionRange(String versionRange) {
        return versionRange != null ? versionRange : DEFAULT_VERSION_RANGE;
    }

}
