/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.jar.Attributes;

import com.springsource.server.osgi.manifest.parse.FatalParseException;

/**
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe.
 * 
 * @author Christopher Frost
 * @since 1.0
 */
abstract class BaseStringHeaderDelegate implements Delegate {

    protected final Attributes mainAttributes;

    private final String fieldName;

    private String fieldValue;

    /**
     * 
     * @param mainAttributes
     * @param fieldName
     */
    BaseStringHeaderDelegate(Attributes mainAttributes, String fieldName) {
        this.mainAttributes = mainAttributes;
        this.fieldName = fieldName;
        this.fieldValue = this.mainAttributes.getValue(fieldName);
    }

    /**
     * 
     * @return the value of the header
     */
    String getField() {
        return this.fieldValue;
    }

    /**
     * 
     * @param fieldValue to be set as the header value
     */
    void setField(String fieldValue) {
        this.fieldValue = fieldValue;
    }

    /**
     * Put the name/value pair of this header in to the supplied Attributes
     * 
     * @param outputAttributes to be written to
     */
    void write(Attributes outputAttributes) {
        if (this.fieldValue != null) {
            outputAttributes.putValue(this.fieldName, this.getField());
        }
    }

    /**
     * 
     * {@inheritDoc}
     */
    public void checkHeaderValidity() {
        if (this.fieldValue != null) {
            if (this.fieldValue.length() == 0) {
                throw new FatalParseException(String.format("%1$s - [%2$s]", "The value of this header is empty", this.fieldName));
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    /**
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof BaseStringHeaderDelegate)) {
            return false;
        }
        final BaseStringHeaderDelegate other = (BaseStringHeaderDelegate) obj;
        getField();
        other.getField();
        if (this.fieldValue == null) {
            if (other.fieldValue != null) {
                return false;
            }
        } else if (!this.fieldValue.equals(other.fieldValue)) {
            return false;
        }
        return true;
    }

}
