/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.jar.Attributes;

import com.springsource.server.osgi.manifest.parse.FatalParseException;

/**
 * @author Glyn Normington
 * @since 1.0
 */
class BundleClassPathDelegate extends BaseStringHeaderDelegate {

    private static final String BUNDLE_CLASSPATH_HEADER_NAME = "Bundle-Classpath";

    private static final String DEFAULT_BUNDLE_CLASSPATH = ".";

    private static final String BUNDLE_CLASSPATH_SEPARATOR = ",";

    private static final int APPROXIMATE_AVERAGE_JAR_PATH_LENGTH = 20;

    private List<String> bundleClassPath;

    public BundleClassPathDelegate(Attributes mainAttributes) {
        super(mainAttributes, BUNDLE_CLASSPATH_HEADER_NAME);
        this.bundleClassPath = new ArrayList<String>(1);
        String classPath = getField();
        if (classPath != null) {
            this.bundleClassPath.addAll(Arrays.asList(classPath.split(BUNDLE_CLASSPATH_SEPARATOR)));
        } else {
            this.bundleClassPath.add(DEFAULT_BUNDLE_CLASSPATH);
        }
    }

    public List<String> getBundleClassPath() {
        return this.bundleClassPath;
    }

    public void setBundleClassPath(List<String> bundleClassPath) {
        this.bundleClassPath = bundleClassPath;

        StringBuffer cp = new StringBuffer(APPROXIMATE_AVERAGE_JAR_PATH_LENGTH * bundleClassPath.size());
        boolean first = true;
        for (String p : this.bundleClassPath) {
            if (!first) {
                cp.append(BUNDLE_CLASSPATH_SEPARATOR);
            }
            cp.append(p);
            first = false;
        }

        setField(cp.toString());
    }

    @Override public void checkHeaderValidity() {
        if (getField() != null) {
            if (getField().length() == 0) {
                throw new FatalParseException("The value of the ClassPath header is empty");
            } else {
                for (String s : this.bundleClassPath) {
                    if (s == null || s.length() == 0) {
                        throw new FatalParseException("The list of ClassPath headers contains a missing value, a comma was probably inserted twice");

                    }
                }
            }
        }
    }

}
