/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.io.Reader;
import java.util.List;

import com.springsource.server.osgi.manifest.BundleManifest.BundleActivationPolicy;
import com.springsource.server.osgi.manifest.BundleManifest.BundleSymbolicName;
import com.springsource.server.osgi.manifest.BundleManifest.DynamicImportPackageHeader;
import com.springsource.server.osgi.manifest.BundleManifest.ExportPackageHeader;
import com.springsource.server.osgi.manifest.BundleManifest.FragmentHostHeader;
import com.springsource.server.osgi.manifest.BundleManifest.ImportBundleHeader;
import com.springsource.server.osgi.manifest.BundleManifest.ImportLibraryHeader;
import com.springsource.server.osgi.manifest.BundleManifest.ImportPackageHeader;
import com.springsource.server.osgi.manifest.BundleManifest.RequireBundleHeader;
import com.springsource.server.osgi.manifest.BundleManifest.DynamicImportPackageHeader.DynamicPackageImport;
import com.springsource.server.osgi.manifest.BundleManifest.ExportPackageHeader.PackageExport;
import com.springsource.server.osgi.manifest.BundleManifest.ImportBundleHeader.BundleImport;
import com.springsource.server.osgi.manifest.BundleManifest.ImportLibraryHeader.LibraryImport;
import com.springsource.server.osgi.manifest.BundleManifest.ImportPackageHeader.PackageImport;
import com.springsource.server.osgi.manifest.BundleManifest.RequireBundleHeader.RequireBundle;

/**
 * This interface provides factory methods for creating empty bundle manifests and empty instances of the more complex
 * bundle headers.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface must be thread safe.
 * 
 * @author Glyn Normington
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface BundleManifestFactory {

    /**
     * Creates a new, empty {@link BundleManifest}.
     * 
     * @return the new <code>BundleManifest</code>.
     */
    BundleManifest createBundleManifest();

    /**
     * Creates a new {@link BundleManifest} from the supplied manifest definition.
     * 
     * @param manifestContents the contents of the manifest.
     * @return the new <code>BundleManifest</code>.
     */
    BundleManifest createBundleManifest(Reader manifestContents);

    String[] isParseClean();

    DynamicImportPackageHeader parseDynamicImportPackageHeader(String creationValue);

    BundleManifest.DynamicImportPackageHeader createDynamicImportPackageHeader(List<DynamicPackageImport> dynamicImports);

    DynamicPackageImport createDynamicPackageImport();

    ExportPackageHeader parseExportPackageHeader(String creationValue);

    ExportPackageHeader createExportPackageHeader(List<PackageExport> packageExports);

    PackageExport createPackageExport();

    FragmentHostHeader parseFragmentHostHeader(String creationValue);

    ImportPackageHeader parseImportPackageHeader(String creationValue);

    ImportPackageHeader createImportPackageHeader(List<PackageImport> imports);
    
    ImportBundleHeader createImportBundleHeader(List<BundleImport> imports);

    PackageImport createPackageImport();

    RequireBundleHeader parseRequireBundleHeader(String creationValue);

    RequireBundle createRequireBundle(String bundleSymbolicName);

    ImportLibraryHeader parseImportLibraryHeader(String creationValue);
    
    ImportBundleHeader parseImportBundleHeader(String creationValue);

    LibraryImport createLibraryImport(String librarySymbolicName);

    BundleSymbolicName parseBundleSymbolicName(String creationValue);

    BundleSymbolicName createBundleSymbolicName(String bundleSymbolicName);
    
    BundleActivationPolicy parseBundleActivationPolicy(String creationValue);
    
    BundleImport createBundleImport(String bundleSymbolicName);
}
