/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.jar.Attributes;

/**
 * @author Glyn Normington
 * @since 1.0
 */
class DynamicImportPackageDelegate implements Delegate {

    private static final String DYNAMIC_IMPORT_PACKAGE_HEADER_NAME = "DynamicImport-Package";

    private BundleManifest.DynamicImportPackageHeader dynamicImportPackageHeader;

    private final Attributes mainAttributes;

    DynamicImportPackageDelegate(Attributes mainAttributes, BundleManifestFactory bundleManifestFactory) {
        this.mainAttributes = mainAttributes;
        String creationValue = this.mainAttributes.getValue(DYNAMIC_IMPORT_PACKAGE_HEADER_NAME);
        if (creationValue != null) {
            this.dynamicImportPackageHeader = bundleManifestFactory.parseDynamicImportPackageHeader(creationValue);
        } else {
            this.dynamicImportPackageHeader = null;
        }
    }

    BundleManifest.DynamicImportPackageHeader getDynamicImportPackageHeader() {
        return this.dynamicImportPackageHeader;
    }

    String getDynamicImportPackageHeaderValue() {
        return getDynamicImportPackageHeader().toString();
    }

    void setDynamicImportPackageHeader(BundleManifest.DynamicImportPackageHeader dynamicImportPackageHeader) {
        this.dynamicImportPackageHeader = dynamicImportPackageHeader;
    }

    /**
     * If this header contains any values they are written out to the provided <code>Attributes</code>
     * 
     * @param outputAttributes
     */
    void write(Attributes outputAttributes) {
        if (this.dynamicImportPackageHeader != null) {
            this.dynamicImportPackageHeader.checkWellFormed();
            String value = this.dynamicImportPackageHeader.toString();
            if (value != null) {
                outputAttributes.putValue(DYNAMIC_IMPORT_PACKAGE_HEADER_NAME, value);
            } else {
                outputAttributes.remove(new Attributes.Name(DYNAMIC_IMPORT_PACKAGE_HEADER_NAME));
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final DynamicImportPackageDelegate other = (DynamicImportPackageDelegate) obj;
        if (this.dynamicImportPackageHeader == null) {
            if (other.dynamicImportPackageHeader != null) {
                return false;
            }
        } else if (!this.dynamicImportPackageHeader.equals(other.dynamicImportPackageHeader)) {
            return false;
        }
        return true;
    }

    public void checkHeaderValidity() {
        if (this.dynamicImportPackageHeader != null) {
            this.dynamicImportPackageHeader.checkWellFormed();
        }
    }

}
