/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.jar.Attributes;

/**
 * @author Glyn Normington
 * @author Christopher Frost
 * @since 1.0
 */
class ImportPackageDelegate implements Delegate {

    private static final String IMPORT_PACKAGE_HEADER_NAME = "Import-Package";

    private BundleManifest.ImportPackageHeader importPackageHeader;

    private final Attributes mainAttributes;

    /**
     * 
     * @param mainAttributes
     */
    ImportPackageDelegate(Attributes mainAttributes, BundleManifestFactory bundleManifestFactory) {
        this.mainAttributes = mainAttributes;
        String creationValue = this.mainAttributes.getValue(IMPORT_PACKAGE_HEADER_NAME);
        if (creationValue != null) {
            this.importPackageHeader = bundleManifestFactory.parseImportPackageHeader(creationValue);
        } else {
            this.importPackageHeader = null;
        }
    }

    BundleManifest.ImportPackageHeader getImportPackageHeader() {
        return this.importPackageHeader;
    }

    /**
     * 
     * @param importPackageHeader
     */
    void setImportPackageHeader(BundleManifest.ImportPackageHeader importPackageHeader) {
        this.importPackageHeader = importPackageHeader;
    }

    /**
     * If this header contains any values they are written out to the provided <code>Attributes</code>
     * 
     * @param outputAttributes
     */
    void write(Attributes outputAttributes) {
        if (this.importPackageHeader != null) {
            this.importPackageHeader.checkWellFormed();
            String value = this.importPackageHeader.toString();
            if (value != null) {
                outputAttributes.putValue(IMPORT_PACKAGE_HEADER_NAME, value);
            } else {
                outputAttributes.remove(new Attributes.Name(IMPORT_PACKAGE_HEADER_NAME));
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final ImportPackageDelegate other = (ImportPackageDelegate) obj;
        if (this.importPackageHeader == null) {
            if (other.importPackageHeader != null) {
                return false;
            }
        } else if (!this.importPackageHeader.equals(other.importPackageHeader)) {
            return false;
        }
        return true;
    }

    public void checkHeaderValidity() {
        if (this.importPackageHeader != null) {
            this.importPackageHeader.checkWellFormed();
        }
    }

}
