/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import org.springframework.util.Assert;

import com.springsource.server.osgi.manifest.BundleManifest.BundleActivationPolicy;
import com.springsource.server.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.server.osgi.manifest.parse.HeaderParserFactory;
import com.springsource.server.osgi.manifest.parse.ParserLogger;


/**
 * TODO Document StandardBundleActivationPolicy
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * TODO Document concurrent semantics of StandardBundleActivationPolicy
 *
 * @author Andy Wilkinson
 * @since TODO Document 'since'
 */
public class StandardBundleActivationPolicy implements BundleActivationPolicy {

    private static final String DIRECTIVE = ":=";

    private static final String SEPARATOR = ";";

    private Policy policy;

    private Map<String, String> directives;

    StandardBundleActivationPolicy(Policy policy) {
        this.policy = policy;
        this.directives = new HashMap<String, String>();
    }

    StandardBundleActivationPolicy(ParserLogger logger, String bundleActivationPolicyString) {
        HeaderDeclaration headerDeclaration = HeaderParserFactory.newHeaderParser(logger).parseBundleActivationPolicy(bundleActivationPolicyString);
        List<String> names = headerDeclaration.getNames();
        Assert.isTrue(names.size() == 1);
        this.policy = Policy.valueOf(names.get(0).toUpperCase(Locale.ENGLISH));
        this.directives = headerDeclaration.getDirectives();
    }

    @Override public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append(this.policy.toString().toLowerCase(Locale.ENGLISH));
        
        for (String directiveName : this.directives.keySet()) {
            appendDirective(directiveName, this.directives.get(directiveName), buffer);
        }

        return buffer.toString();
    }

    private void appendDirective(String name, String value, StringBuffer buffer) {
        buffer.append(SEPARATOR).append(name).append(DIRECTIVE).append(value);
    }

    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof StandardBundleActivationPolicy)) {
            return false;
        }
        final StandardBundleActivationPolicy other = (StandardBundleActivationPolicy) obj;
        if (this.directives == null) {
            if (other.directives != null) {
                return false;
            }
        } else if (!this.directives.equals(other.directives)) {
            return false;
        }
        if (!this.policy.equals(other.policy)) {
            return false;
        }
        return true;
    }

    @Override public int hashCode() {
        return this.policy.hashCode();
    }
    /** 
     * {@inheritDoc}
     */
    public Policy getActivationPolicy() {
        return this.policy;
    }
    
    /** 
     * {@inheritDoc}
     */
    public Map<String, String> getDirectives() {
        return this.directives;
    }
}
