/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.springsource.server.osgi.manifest.parse.FatalParseException;
import com.springsource.server.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.server.osgi.manifest.parse.ParseUtils;

/**
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
class StandardDynamicPackageImport implements BundleManifest.DynamicImportPackageHeader.DynamicPackageImport {

    private static final String PACKAGE_SEPARATOR = ";";

    private static final String ATTRIBUTE_SEPARATOR = ";";

    private static final String EQUALS = "=";

    private final List<String> packageNames = new ArrayList<String>(1);

    private final Map<String, String> attributes = new HashMap<String, String>();

    public StandardDynamicPackageImport(HeaderDeclaration packageDeclaration) {
        this.packageNames.addAll(packageDeclaration.getNames());
        this.attributes.putAll(packageDeclaration.getAttributes());
    }

    public StandardDynamicPackageImport() {
    }

    public Map<String, String> getAttributes() {
        return this.attributes;
    }

    public List<String> getWildcardPackageNames() {
        return this.packageNames;
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    /**
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof StandardDynamicPackageImport)) {
            return false;
        }
        final StandardDynamicPackageImport other = (StandardDynamicPackageImport) obj;
        if (this.attributes == null) {
            if (other.attributes != null) {
                return false;
            }
        } else if (!this.attributes.equals(other.attributes)) {
            return false;
        }
        if (this.packageNames == null) {
            if (other.packageNames != null) {
                return false;
            }
        } else if (!this.packageNames.equals(other.packageNames)) {
            return false;
        }
        return true;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        StringBuffer result = new StringBuffer(20);
        result.append(ParseUtils.collectionToDelimitedString(this.packageNames, PACKAGE_SEPARATOR));
        toStringOfAttributes(result);
        return result.toString();

    }

    private void toStringOfAttributes(StringBuffer result) {
        for (String attrName : this.attributes.keySet()) {
            result.append(ATTRIBUTE_SEPARATOR).append(attrName).append(EQUALS).append(this.attributes.get(attrName));
        }
    }

    public void checkWellFormed() {
        if (this.packageNames.size() == 0) {
            throw new FatalParseException("Dynamic package import with no packages is not well formed");
        }

    }
}
