/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.ArrayList;
import java.util.List;

import com.springsource.server.osgi.manifest.BundleManifest.ExportPackageHeader;
import com.springsource.server.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.server.osgi.manifest.parse.HeaderParser;
import com.springsource.server.osgi.manifest.parse.HeaderParserFactory;
import com.springsource.server.osgi.manifest.parse.ParseUtils;
import com.springsource.server.osgi.manifest.parse.ParserLogger;

/**
 * 
 * TODO Document StandardExportPackageHeader
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * TODO Document concurrent semantics of StandardExportPackageHeader
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public class StandardExportPackageHeader implements ExportPackageHeader {

    private static final String PACKAGES_SEPARATOR = ",";

    private List<BundleManifest.ExportPackageHeader.PackageExport> packageExports = new ArrayList<PackageExport>();

    public StandardExportPackageHeader(ParserLogger parserLogger, String exportPackageHeaderString) {
        this.packageExports = new ArrayList<BundleManifest.ExportPackageHeader.PackageExport>();
        HeaderParser packageHeaderParser = HeaderParserFactory.newHeaderParser(parserLogger);
        List<HeaderDeclaration> packageDeclarations = packageHeaderParser.parsePackageHeader(exportPackageHeaderString, "Export-Package");
        for (HeaderDeclaration packageDeclaration : packageDeclarations) {
            this.packageExports.add(new StandardPackageExport(packageDeclaration));
        }
    }

    public StandardExportPackageHeader(List<PackageExport> packageExports) {
        this.packageExports = packageExports;
    }

    public List<PackageExport> getPackageExports() {
        return this.packageExports;
    }

    public void setPackageExports(List<PackageExport> packageExports) {
        this.packageExports = packageExports;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        if (this.packageExports.size() != 0) {
            StringBuffer result = new StringBuffer(20);
            result.append(ParseUtils.collectionToDelimitedString(this.packageExports, PACKAGES_SEPARATOR));
            return result.toString();
        } else {
            return null;
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    /**
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof StandardExportPackageHeader)) {
            return false;
        }
        final StandardExportPackageHeader other = (StandardExportPackageHeader) obj;
        if (!this.packageExports.equals(other.packageExports)) {
            return false;
        }
        return true;
    }

    /**
     * {@inheritDoc}
     */
    public void checkWellFormed() {
        for (PackageExport packageExport : this.packageExports) {
            packageExport.checkWellFormed();
        }
    }
}
