/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.ArrayList;
import java.util.List;

import org.springframework.util.Assert;

import com.springsource.server.osgi.manifest.BundleManifest.ImportLibraryHeader;
import com.springsource.server.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.server.osgi.manifest.parse.HeaderParser;
import com.springsource.server.osgi.manifest.parse.HeaderParserFactory;
import com.springsource.server.osgi.manifest.parse.ParseUtils;
import com.springsource.server.osgi.manifest.parse.ParserLogger;

/**
 * TODO Document StandardImportLibraryHeader
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe.
 * 
 * @author Rob Harrop
 * @author Andy Wilkinson
 * @since 1.0
 */
final class StandardImportLibraryHeader implements ImportLibraryHeader {

    private static final String SEPARATOR = ",";

    private List<LibraryImport> importedLibraries= new ArrayList<LibraryImport>();

    /**
     * 
     * @param parserLogger
     * @param value
     */
    public StandardImportLibraryHeader(ParserLogger parserLogger, String value) {
        HeaderParser headerParser = HeaderParserFactory.newHeaderParser(parserLogger);
        List<HeaderDeclaration> declarations = headerParser.parseImportLibraryHeader(value);
        for (HeaderDeclaration declaration : declarations) {
            this.importedLibraries.add(new StandardLibraryImport(declaration));
        }
    }

    /**
     * {@inheritDoc}
     */
    public void checkWellFormed() {
        for (LibraryImport library : this.importedLibraries) {
            library.checkWellFormed();
        }
    }

    /**
     * {@inheritDoc}
     */
    public List<LibraryImport> getImportedLibraries() {
        return this.importedLibraries;
    }

    /**
     * {@inheritDoc}
     */
    public void setImportedLibraries(List<LibraryImport> libraries) {
        Assert.notNull(libraries);
        this.importedLibraries = libraries;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        if (this.importedLibraries.size() != 0) {
            StringBuffer result = new StringBuffer(20);
            result.append(ParseUtils.collectionToDelimitedString(this.importedLibraries, SEPARATOR));
            return result.toString();
        } else {
            return null;
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    /**
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof StandardImportLibraryHeader)) {
            return false;
        }
        final StandardImportLibraryHeader other = (StandardImportLibraryHeader) obj;
        if (!this.importedLibraries.equals(other.importedLibraries)) {
            return false;
        }
        return true;
    }
}
