/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest;

import java.util.ArrayList;
import java.util.List;

import com.springsource.server.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.server.osgi.manifest.parse.HeaderParser;
import com.springsource.server.osgi.manifest.parse.HeaderParserFactory;
import com.springsource.server.osgi.manifest.parse.ParseUtils;
import com.springsource.server.osgi.manifest.parse.ParserLogger;

/**
 * 
 * TODO Document StandardImportPackageHeader
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
final class StandardImportPackageHeader implements BundleManifest.ImportPackageHeader {

    private static final String PACKAGES_SEPARATOR = ",";

    private List<BundleManifest.ImportPackageHeader.PackageImport> packageImports;

    public StandardImportPackageHeader(ParserLogger parserLogger, String importPackageHeaderString) {
        this.packageImports = new ArrayList<BundleManifest.ImportPackageHeader.PackageImport>();
        HeaderParser packageHeaderParser = HeaderParserFactory.newHeaderParser(parserLogger);
        List<HeaderDeclaration> packageDeclarations = packageHeaderParser.parsePackageHeader(importPackageHeaderString, "Import-Package");
        for (HeaderDeclaration packageDeclaration : packageDeclarations) {
            this.packageImports.add(new StandardPackageImport(packageDeclaration));
        }
    }

    public StandardImportPackageHeader(List<PackageImport> packageImports) {
        this.packageImports = packageImports;
    }

    public List<PackageImport> getPackageImports() {
        return this.packageImports;
    }

    public void setPackageImports(List<PackageImport> packageImports) {
        this.packageImports = packageImports;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        if (this.packageImports.size() != 0) {
            StringBuffer result = new StringBuffer(20);
            result.append(ParseUtils.collectionToDelimitedString(this.packageImports, PACKAGES_SEPARATOR));
            return result.toString();
        } else {
            return null;
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override public int hashCode() {
        throw new UnsupportedOperationException();
    }

    /**
     * {@inheritDoc}
     */
    @Override public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof StandardImportPackageHeader)) {
            return false;
        }
        final StandardImportPackageHeader other = (StandardImportPackageHeader) obj;
        if (!this.packageImports.equals(other.packageImports)) {
            return false;
        }
        return true;
    }

    /**
     * {@inheritDoc}
     */
    public void checkWellFormed() {
        for (PackageImport packageImport : this.packageImports) {
            packageImport.checkWellFormed();
        }
    }
}
