/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest.parse;

import java.util.List;
import java.util.Map;

/**
 * Describes a header declaration (import, export, or require bundle) in an OSGi manifest header.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations <strong>must</strong> be threadsafe.
 * 
 * @author Rob Harrop
 * @author Glyn Normington
 * @since 1.0
 */
public interface HeaderDeclaration {

    /**
     * Gets the package names or bundle symbolic names included in this declaration.
     * 
     * @return the package or bundle symbolic names.
     */
    List<String> getNames();

    /**
     * Gets the attributes included in this declaration.
     * 
     * @return the attributes.
     */
    Map<String, String> getAttributes();

    /**
     * Gets the directives included in this declaration.
     * 
     * @return the directives.
     */
    Map<String, String> getDirectives();
}
