/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest.parse;

import java.util.List;
import java.util.Map;

import org.springframework.core.style.ToStringCreator;

/**
 * Immutable implementation of {@link HeaderDeclaration}.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Thread-safe.
 * 
 * @author Rob Harrop
 * @author Glyn Normington
 * @author Sam Brannen
 * @since 1.0
 */
public final class ImmutableHeaderDeclaration implements HeaderDeclaration {

    private final List<String> names;

    private final Map<String, String> attributes;

    private final Map<String, String> directives;

    /**
     * Creates a new <code>ImmutableHeaderDeclaration</code>.
     * 
     * @param names the names in the declaration.
     * @param attributes the attributes in the declaration.
     * @param directives the directives in the declaration.
     */
    public ImmutableHeaderDeclaration(List<String> names, Map<String, String> attributes, Map<String, String> directives) {
        this.names = names;
        this.attributes = attributes;
        this.directives = directives;
    }

    /**
     * {@inheritDoc}
     */
    public Map<String, String> getAttributes() {
        return this.attributes;
    }

    /**
     * {@inheritDoc}
     */
    public Map<String, String> getDirectives() {
        return this.directives;
    }

    /**
     * {@inheritDoc}
     */
    public List<String> getNames() {
        return this.names;
    }

    /**
     * {@inheritDoc}
     */
    @Override public String toString() {
        return new ToStringCreator(this)//
        .append("attributes", this.attributes)//
        .append("directives", this.directives)//
        .append("names", this.names)//
        .toString();
    }

}
