/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest.parse;

import com.springsource.server.serviceability.tracing.Tracer;
import com.springsource.server.serviceability.tracing.TracerFactory;

/**
 * 
 * TODO Document OSGiIntegrationLogService
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * TODO Document concurrent semantics of OSGiIntegrationLogService
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public class OSGiIntegrationLogService extends AntlrLogMessageService {

    private static final Tracer TRACER = TracerFactory.createTracer(OSGiIntegrationLogService.class);

    public OSGiIntegrationLogService() {
        super("OI");
    }

    @Override public void messageProcessed(String eventCode, String message) {
        char level = eventCode.charAt(eventCode.length() - 1);
        switch (level) {
            case 'I':
                if (TRACER.isInfoEnabled()) {
                    TRACER.traceInfo(String.format("%1$s - [%2$s]", eventCode, message));
                }
                break;
            case 'W':
                if (TRACER.isWarningEnabled()) {
                    TRACER.traceWarning(String.format("%1$s - [%2$s]", eventCode, message));
                }
                break;
            case 'E':
                if (TRACER.isErrorEnabled()) {
                    TRACER.traceError(String.format("%1$s - [%2$s]", eventCode, message));
                }
                break;
            default:
                if (TRACER.isErrorEnabled()) {
                    TRACER.traceError(String.format("%1$s - [%2$s]", eventCode, "Malformed error code recieved, message is '" + message + "'"));
                }
                break;
        }
    }

}
