/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.manifest.parse;

/**
 * <p>
 * This is a stand-in logging service just for parsing manifests. 
 * It can run before the normal serviceability services have come 
 * up and allow errors to be correctly reported from the start of 
 * the server bootstrap process.
 * </p>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface should be Thread Safe
 * 
 * @author Christopher Frost
 * @since 1.0
 */
public interface ParserLogger {

    /**
     * Deal with a exception at level 'Error' logging it with what 
     * ever services are available.
     * 
     * @param re
     * @param item
     */
    void outputErrorMsg(Exception re, String item);

    /**
     * Deal with a exception at level 'Warn' logging it with what 
     * ever services are available.
     * 
     * @param re
     * @param item
     */
    void outputWarnMsg(Exception re, String item);

    /**
     * Deal with a exception at level 'Info' logging it with what 
     * ever services are available.
     * 
     * @param re
     * @param item
     */
    void outputInfoMsg(Exception re, String item);

    /**
     * This method receives a generated log event code and message
     *  for reporting in an implementation specific way.
     * 
     * @param eventCode
     * @param message
     */
    void messageProcessed(String eventCode, String message);

    /**
     * Reports if this logging service has been used or not. If it has 
     * been used the parsing activities that have taken place since this 
     * logger was created or reset have encountered problems of some kind.
     * 
     * @return String array of all log event messages since the parser was created or cleaned
     */
    String[] errorReports();

    /**
     * Clean the parser of all previous log events and reset it to clean 
     * so that the instance can be reused if needed.
     */
    void resetErrorReport();

}
