/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.provisioning;

import org.osgi.framework.Version;

import com.springsource.server.osgi.manifest.BundleManifest.ImportBundleHeader.BundleImport;

/**
 * Defines a library that can be installed into the OSGi framework. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations must be threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public interface LibraryDefinition extends Definition {

    enum Sharing {
        SHAREABLE, NON_SHAREABLE
    }

    /**
     * Gets the symbolic name of the library.
     * 
     * @return the library's symbolic name
     */
    String getSymbolicName();

    /**
     * Gets the description of the library. <p/>
     * 
     * May return <code>null</code> if no description is defined.
     * 
     * @return the library's description
     */
    String getDescription();

    /**
     * Gets the name of the library.
     * 
     * @return the library's name.
     */
    String getName();
    
    /**
     * Gets the version of the library.
     * 
     * @return the library's version.
     */
    Version getVersion();

    /**
     * Gets the sharing setting of the library.
     * 
     * @return the sharing setting.
     */
    Sharing getSharing();

    /**
     * Gets the bundles in this library.
     * 
     * @return the library's bundles.
     */
    BundleImport[] getLibraryBundles();
}
