/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.provisioning.repository;

import com.springsource.server.osgi.provisioning.Definition;

/**
 * A <code>DuplicateDefinitionException</code> is thrown if a duplicate bundle or library definition is encountered
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * This class is <strong>thread-safe</strong>
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
class DuplicateDefinitionException extends Exception {

    private static final long serialVersionUID = 7326048945711846112L;

    private final Definition existingDefinition;

    /**
     * Creates a new <code>DuplicateDefinitionException</code> encapsulating the supplied existing definition that
     * resulted in a duplicate being identified.
     * 
     * @param existingDefinition The existing definition
     */
    DuplicateDefinitionException(Definition existingDefinition) {
        this.existingDefinition = existingDefinition;
    }

    /**
     * Returns the existing definition
     * @return the existing definition
     */
    Definition getExistingDefinition() {
        return existingDefinition;
    }
}
