/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.osgi.provisioning.support;

import java.io.File;
import java.io.Reader;
import java.util.zip.ZipException;

import com.springsource.server.osgi.provisioning.BundleDefinition;
import com.springsource.server.osgi.provisioning.BundleProvisioningException;
import com.springsource.server.osgi.provisioning.OsgiProvisioningLogEvent;
import com.springsource.server.serviceability.logging.LogService;
import com.springsource.server.serviceability.logging.LogServiceFactory;

/**
 * Implementation of {@link BundleDefinition} that is backed by a JAR.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
final class JarBundleDefinition extends AbstractLocalBundleDefinition {

    private static final LogService TRACER  = LogServiceFactory.getLogService();
    /**
     * Creates a new <code>JarBundleDefinition</code>.
     * 
     * @param file the JAR file.
     */
    public JarBundleDefinition(File file) {
        super(file);
    }

    /**
     * {@inheritDoc}
     */
    @Override protected Reader getManifestReader() {
        try {
            return extractManifest(getLocation());
        } catch (BundleProvisioningException bpe) {
            if (bpe.getCause() instanceof ZipException) {
                TRACER .log(OsgiProvisioningLogEvent.CORRUPT_JAR_FILE, bpe.getCause(), getLocation().getAbsolutePath());
                return null;
            }
            throw bpe;
        }
    }

    /**
     * @param file
     * @return
     */
    private static Reader extractManifest(File file) {
        return ManifestUtils.manifestReaderFromJar(file);
    }

    static boolean isJarBundle(File file) {
        return file.isFile() && file.getName().endsWith(".jar");
    }
}
