/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.profile.core.internal;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/*
 * Copyright 2007-2008 SpringSource Inc.
 */

/**
 * Defines all the {@link LogEvent LogEvents} for the profile subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementation is immutable.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
public enum ProfileLogEvent implements LogEvent {

    PROFILE_IDENTITY(0, Level.INFO),
    PROFILE_INSTALLED(1, Level.INFO),
    PROFILE_STARTED(2, Level.INFO),
    PROFILE_FAILED(3, Level.ERROR),
    INACTIVE_BUNDLE(4, Level.WARN),
    PROFILE_TIMEOUT(5, Level.ERROR);
    
    private static final String SUBSYSTEM_NAME = "Profile";
    private static final String SUBSYSTEM_CODE = "PM";
    
    private final LogEventDelegate delegate;

    /**
     * @param subsystemName
     * @param subsystemCode
     * @param severity
     */
    private ProfileLogEvent(int code, Level level) {
        this.delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, code, level);
    }

    /**
     * {@inheritDoc}
     */
    public String getEventCode() {
        return delegate.getEventCode();
    }

    /**
     * {@inheritDoc}
     */
    public Level getLevel() {
        return delegate.getLevel();
    }

    /**
     * {@inheritDoc}
     */
    public String getSubsystemName() {
        return delegate.getSubsystemName();
    }

}
