/* 
 * This file is part of the SpringSource Application Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource Application Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource Application Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource Application Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.ffdc.aspects;

import com.springsource.server.serviceability.ffdc.FFDCService;

/**
 * Advises throws of {@link RuntimeException} and triggers {@link FFDCService#generateDump(Throwable) a dump}. <p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */

public final aspect FFDCCoordinator {

    pointcut duringFFDCProcessing() : cflow(adviceexecution());

    pointcut engineOperation() : EngineArchitecture.anyEngineMethodExecution();
    
    after() throwing(RuntimeException ex) : engineOperation() && !duringFFDCProcessing() {
        if (this.ffdcService != null && !FFDCExceptionState.seen(ex)) {
            FFDCExceptionState.record(ex);
            this.ffdcService.generateDump(ex);
        }
    }

    private volatile FFDCService ffdcService;

    public void setService(FFDCService ffdcService) {
        this.ffdcService = ffdcService;
    }
}
