/* 
 * This file is part of the SpringSource Application Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource Application Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource Application Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource Application Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.ffdc.aspects;

import com.springsource.server.serviceability.ffdc.Assert;
import com.springsource.server.serviceability.ffdc.NonNull;

/**
 * Aspect that enforces that parameters annotated with {@link NonNull} are, in fact, non null.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @since 1.0
 */
public aspect NonNullAssertionEnforcer {

    pointcut executingOperationWithNonNullFirstParameter(Object obj) :
        EngineArchitecture.anyEngineMethodExecution() && 
        execution(* *(@NonNull (*), ..)) && args(obj, ..);
    
    pointcut executingOperationWithNonNullSecondParameter(Object obj) :
        EngineArchitecture.anyEngineMethodExecution() && 
        execution(* *(*, @NonNull (*), ..)) && args(*, obj, ..);
    
    pointcut executingOperationWithNonNullThirdParameter(Object obj) :
        EngineArchitecture.anyEngineMethodExecution() && 
        execution(* *(*, *, @NonNull (*), ..)) && args(*, * , obj, ..);
    
    pointcut executingOperationWithNonNullFourthParameter(Object obj) :
        EngineArchitecture.anyEngineMethodExecution() && 
        execution(* *(*, *, *, @NonNull (*), ..)) && args(*, *, *, obj, ..);
    
    pointcut executingOperationWithNonNullFifthParameter(Object obj) :
        EngineArchitecture.anyEngineMethodExecution() && 
        execution(* *(*, *, *, *, @NonNull (*), ..)) && args(*, *, *, *, obj, ..);
    
    before(Object argValue) : executingOperationWithNonNullFirstParameter(argValue) {
        Assert.notNull(argValue, "Argument [1] cannot be null");
    }
    
    before(Object argValue) : executingOperationWithNonNullSecondParameter(argValue) {
        Assert.notNull(argValue, "Argument [2] cannot be null");
    }
    
    before(Object argValue) : executingOperationWithNonNullThirdParameter(argValue) {
        Assert.notNull(argValue, "Argument [3] cannot be null");
    }
    
    before(Object argValue) : executingOperationWithNonNullFourthParameter(argValue) {
        Assert.notNull(argValue, "Argument [4] cannot be null");
    }
    
    before(Object argValue) : executingOperationWithNonNullFifthParameter(argValue) {
        Assert.notNull(argValue, "Argument [5] cannot be null");
    }
}
