/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.ffdc;

/**
 * Fatal server exceptions are thrown when a severe error is detected in the
 * Server which requires the Server to crash after generating diagnostics. This
 * class is thread safe.
 * 
 * Subsystems should throw their own specific subclasses.
 * 
 * @author Glyn Normington
 * @since 1.0
 */
abstract public class FatalServerException extends RuntimeException {

    /**
     * Stable serial UID.
     */
    private static final long serialVersionUID = -4396605664802060768L;

    /**
     * An aspect will do FFDC when this exception, or subclasses of this
     * exception, is thrown.
     * 
     * @param message an English description of the error
     */
    public FatalServerException(String message) {
        super(message);
    }
    
    public FatalServerException(String message, Throwable cause) {
        super(message, cause);
    }

}
