/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.logging;

import com.springsource.server.serviceability.output.Level;

/**
 * A <code>LogEvent</code> encapsulates the details of an event that is to be logged.<p/>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface LogEvent {

    /**
     * Returns the code that uniquely identifies this <code>LogEvent</code>.
     * 
     * @return The event's code
     */
    public String getEventCode();

    /**
     * Returns the name of the subsystem from which this <code>LogEvent</code> originates.
     * 
     * @return The name of the subsystem
     */
    public String getSubsystemName();

    /**
     * Returns the {@link Level} at which this <code>LogEvent</code> should be published.
     * 
     * @return The level of the event.
     */
    public Level getLevel();
}
