/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.logging;

import com.springsource.server.serviceability.output.Destination;

/**
 * LogService provides methods for logging events that will be output to the Server's logging
 * {@link Destination Destination(s)}.
 * <p />
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 * 
 * @author Chris Frost
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface LogService {

    /**
     * Requests that the supplied event be logged with the supplied inserts being inserted into the generated log
     * message.
     * 
     * @param event The event to be logged
     * @param inserts The inserts for the generated message.
     */
    void log(LogEvent event, Object... inserts);

    /**
     * Requests that the supplied event be logged with the supplied inserts being inserted into the generated log
     * message. The stack trace of the supplied <code>Throwable</code> is appended to the message.
     * 
     * @param event The event to be logged
     * @param throwable A <code>Throwable</code>, the stack trace of which will be appended to the message.
     * @param inserts The inserts for the generated message.
     */
    void log(LogEvent event, Throwable throwable, Object... inserts);

}
