/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output;


/**
 * <p>
 * A destination is a place to which serviceability entries, i.e. logging or tracing, are
 * written.
 * </p>
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 * 
 * @author Glyn Normington
 * @author Christopher Frost
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface Destination {

    /**
     * Write an entry to this destination.
     * 
     * @param entry The entry to write
     */
    void write(Entry entry);
    
    /**
     * Instructs this destination to flush all of its output.
     */
    void flush();    
    
    /**
     * Closes the destination
     */
    void close();
    
    /**
     * Opens the destination for writing
     */
    void open();
}
