/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output;

/**
 * An EntryFilter is used to filter Entry instances as they pass
 * through an EntryPublisher and its associated Destinations.
 *
 * <strong>Concurrent Semantics</strong><br />
 * EntryFilter implementations <strong>must</strong> be thread safe.
 *
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface EntryFilter {
    
    /**
     * Filter the given Entry, returning true if the entry passes through 
     * the filter and should be output.
     * @param entry The entry to be filtered
     * @return true if the entry passes through the filter, otherwise false.
     */
    boolean filter(Entry entry);
    
    /**
     * Filter an entry for the suppled source and level, returning true if
     * it passes through the filter and should be output.
     * @param entrySource The source of the entry to be filtered
     * @param level The level of the entry to be filtered
     * @return true if the entry passes through the filter, otherwise false.
     */
    boolean filter(String entrySource, Level level); 
}
