/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output;

/**
 * An <code>EntryPublisher</code> is used to publish {@link Entry Entries} typically to one or more
 * {@link Destination Destinations}.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface EntryPublisher {

    /**
     * Requests that the supplied entry be published.<p/> An <code>EntryPublisher</code> may choose to buffer its
     * publications such that it is guaranteed that the supplied entry <em>will</em> be published upon return from
     * this method by <strong>not</strong> that the entry <em>has</em> been published.
     * 
     * @param entry
     */
    void publish(Entry entry);

    /**
     * Requests that the publisher flush its buffer such that it is guaranteed that all {@link Entry Entries} that
     * has been passed for publishing thus far are published.
     */
    void flush();
    
    /**
     * Requests that the publisher close such that it releases any resources that it is using.
     */
    void close();
}
