/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output;

/**
 * An <code>EntryPublisherFactory</code> is used to create {@link EntryPublisher EntryPublishers}
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * Implementations <strong>must</strong> be thread-safe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
public interface EntryPublisherFactory {

    /**
     * Creates a new {@link EntryPublisher} which will publish entries to the supplied {@link Destination Destinations}
     * 
     * @param destinations the <code>Destinations</code> to which the <code>EntryPublisher</code> will publish
     *        entries
     * @return the <code>EntryPublisher</code>
     */
    EntryPublisher createEntryPublisher(Destination[] destinations);
}
