/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output.internal;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;

/**
 * A special <code>FileWriter</code> that writes a header into the <code>File</code> to which it is writing when it
 * is first constructed.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * This class is <strong>not</strong> thread-safe.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
class HeaderWritingFileWriter extends FileWriter {

    private final String header;

    /**
     * Creates a new <code>HeaderWritingFileWriter</code> that will append its output to the supplied file.
     * @param file The file to which the writer will write
     * @throws IOException if a problem occurs creating the writer or writing out the header
     */
    HeaderWritingFileWriter(File file) throws IOException {
        super(file, true);
        header = buildHeader();
        writeHeader();
    }

    private String buildHeader() {
        StringWriter stringWriter = new StringWriter();
        PrintWriter printer = new PrintWriter(stringWriter);
        printer.println("--------------------------------------------------------------------------------");
        printer.println("|");
        printer.println("| SpringSource dm Server ");
        printer.println("|");
        printer.println("--------------------------------------------------------------------------------");
        printer.flush();
        return stringWriter.toString();
    }

    private void writeHeader() throws IOException {
        append(header);
    }
}
