/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output.internal;

/**
 * A RolloverPolicy is used by a {@link RollingOverFileWriter} to control when its output file should be rolled over.
 * <strong>Concurrent Semantics</strong><br />
 * Implementations must be <strong>thread-safe</strong>.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
interface RolloverPolicy {

    /**
     * Returns true if a rollover is required.
     * 
     * @param fileSize The current size of the file to which output is being written
     * @return true if a rollover is required.
     */
    boolean isRolloverRequired(long fileSize);

    /**
     * Returns the identifier to be used when creating a rollover file, typically based on the time at which the
     * rollover occurred.
     * 
     * @return an identifier for the rollover file
     */
    String getRolloverIdentifier();
}
