/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.serviceability.output.internal;

import java.util.ArrayList;
import java.util.List;

import com.springsource.server.serviceability.output.Destination;
import com.springsource.server.serviceability.output.EntryPublisher;
import com.springsource.server.serviceability.output.EntryPublisherFactory;

/**
 * Standard implementation of {@link EntryPublisherFactory}
 * 
 * <strong>Concurrent Semantics</strong><br />
 * This class is <strong>thread-safe</strong>.
 * 
 * @author Andy Wilkinson
 * @since 1.0
 */
class StandardEntryPublisherFactory implements EntryPublisherFactory {

    private List<EntryPublisher> entryPublishers = new ArrayList<EntryPublisher>();

    private final Object entryPublishersLock = new Object();

    /**
     * Creates a <code>StandardEntryPublisherFactory<code>. 
     */
    StandardEntryPublisherFactory() {

        Thread entryPublisherFlusherThread = new Thread("EntryPublisherFlusher") {

            public void run() {
                while (true) {
                    synchronized (entryPublishersLock) {
                        for (EntryPublisher entryPublisher : entryPublishers) {
                            entryPublisher.flush();
                        }
                    }

                    try {
                        Thread.sleep(1000);
                    } catch (InterruptedException ie) {

                    }
                }
            }
        };

        entryPublisherFlusherThread.setDaemon(true);
        entryPublisherFlusherThread.start();
        
        Runtime.getRuntime().addShutdownHook(new Thread("EntryPublisherFlushingShutdownHook") {
            public void run() {
                synchronized (entryPublishersLock) {
                    for (EntryPublisher entryPublisher: entryPublishers) {
                        entryPublisher.flush();
                    }
                }
            }
        });
    }

    /** 
     * {@inheritDoc}
     */
    public EntryPublisher createEntryPublisher(Destination[] destinations) {
        EntryPublisher entryPublisher = new StandardEntryPublisher(destinations);
        synchronized (entryPublishersLock) {
            entryPublishers.add(entryPublisher);
        }
        return entryPublisher;
    }
}
