/* 
 * This file is part of the SpringSource Application Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource Application Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource Application Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource Application Server. If not, see <http://www.gnu.org/licenses/>.
 */
package com.springsource.server.serviceability.tracing.aspects;

import com.springsource.server.serviceability.tracing.CallContextHolder;
import com.springsource.server.serviceability.tracing.Tracer;

/**
 * Manages the call context for calls into the tracing subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementation is stateless.
 * 
 * @author Rob Harrop
 * @since 1.0
 */

public final aspect CallContextAspect {

    pointcut callToTrace() : call(* Tracer.trace*(..)) && !within(com.springsource.server.serviceability.tracing.aspects..*);

    before() : callToTrace() {
        CallContextHolder.setContext(thisEnclosingJoinPointStaticPart.getSignature().getName(),
                thisJoinPointStaticPart.getSourceLocation().getLine());
    }

    after() : callToTrace() {
        CallContextHolder.clearContext();
    }
}
