/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package org.slf4j.impl;



import org.slf4j.IMarkerFactory;
import org.slf4j.MarkerFactory;
import org.slf4j.helpers.BasicMarkerFactory;
import org.slf4j.spi.MarkerFactoryBinder;



/**

 * 

 * The binding of {@link MarkerFactory} class with an actual instance of 

 * {@link IMarkerFactory} is performed using information returned by this class. 

 * 

 * @author Ceki G&uuml;lc&uuml;

 */

public class StaticMarkerBinder implements MarkerFactoryBinder {



  /**

   * The unique instance of this class.

   */

  public static final StaticMarkerBinder SINGLETON = new StaticMarkerBinder();

  

  final IMarkerFactory markerFactory = new BasicMarkerFactory();

  

  private StaticMarkerBinder() {

  }

  

  /**

   * Currently this method always returns an instance of 

   * {@link BasicMarkerFactory}.

   */

  public IMarkerFactory getMarkerFactory() {

    return markerFactory;

  }

  

  /**

   * Currently, this method returns the class name of

   * {@link BasicMarkerFactory}.

   */

  public String getMarkerFactoryClassStr() {

    return BasicMarkerFactory.class.getName();

  }
}

