/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.admin.web;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.ServletRequestUtils;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.multiaction.MultiActionController;

import com.springsource.server.servlet.admin.service.ApplicationManagerService;

/**
 * Spring MVC 2.0 based <em>MultiActionController</em> that handles all requests intended for the
 * {@link ApplicationManagerService}.
 * 
 * @author Sam Brannen
 * @author Christopher Frost
 */
public class ApplicationManagerController extends MultiActionController {

    private final ApplicationManagerService applicationManagerService;

    public ApplicationManagerController(ApplicationManagerService applicationManagerService) {
        this.applicationManagerService = applicationManagerService;
    }

    private ModelAndView createContextListModelAndView(boolean redirect, String msg) {
        if (redirect) {
            return new ModelAndView("redirect:list.htm").addObject("message", msg);
        } else {
            return new ModelAndView("list").addObject("result", msg).addObject("applications",
                this.applicationManagerService.findAppInfoForDeployedApplications()).addObject("properties",
                this.applicationManagerService.getServerProperties()).addObject("destinations", this.applicationManagerService.getDestinations());
        }
    }

    /**
     * Custom handler for displaying a list of all installed applications.
     */
    public ModelAndView list(HttpServletRequest request, HttpServletResponse response) {
        String message = request.getParameter("message");
        if (message == null) {
            return createContextListModelAndView(false, "Applications Listed");
        } else {
            return createContextListModelAndView(false, message);
        }
    }

    /**
     * Custom handler for deploying an application.
     */
    public ModelAndView deploy(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        MultipartFile multipartFile = multipartRequest.getFile("application");
        String msg;
        if (multipartFile.isEmpty()) {
            msg = "Error: Please select the application you would like to upload.";
        } else {
            msg = this.applicationManagerService.deploy(multipartFile);
        }
        return createContextListModelAndView(true, msg);
    }

    /**
     * Custom handler for undeploying an application.
     */
    public ModelAndView undeploy(HttpServletRequest request, HttpServletResponse response) throws ServletRequestBindingException {
        String msg = this.applicationManagerService.undeploy(ServletRequestUtils.getRequiredStringParameter(request, "path"));
        return createContextListModelAndView(true, msg);
    }

}
