/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.core;

import javax.servlet.ServletContext;

/**
 * <code>Context</code> defines a simple API for a web application <em>context</em> deployed within a
 * {@link ServletContainer}.
 * 
 * <p>
 * Concrete implementations should:
 * </p>
 * <ul>
 * <li>provide a reasonable implementation of {@link Object#toString()}</li>
 * <li>specify whether or not they provide reasonable implementations of {@link Object#equals(Object)} and
 * {@link Object#hashCode()}</li>
 * </ul>
 * 
 * @author Sam Brannen
 * @author Rob Harrop
 * @since 1.0
 * @see ServletContainer
 */
public interface Context {

    /**
     * @return the unique path under which this web application context is mapped and/or deployed.
     */
    public String getPath();

    /**
     * @return the <em>root</em> directory for this web application context.
     */
    public String getContextRoot();

    /**
     * @return the {@link ServletContext} for this web application context.
     */
    ServletContext getServletContext();

    /**
     * @return <code>true</code> if the {@link #reload()} operation is supported by this web application context.
     * @see #reload()
     */
    boolean isReloadable();

    /**
     * Reloads this web application context, if {@link #isReloadable() supported}.
     * 
     * <p>
     * Concrete implementations may choose to throw an {@link UnsupportedOperationException} if context reloading is not
     * {@link #isReloadable() supported}.
     * </p>
     * 
     * @see #isReloadable()
     */
    boolean reload();

}
