/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.core;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * Custom {@link LogEvent} enums for the servlet container subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
public enum ServletContainerLogEvent implements LogEvent {

    /* START OF ENUM DEFINITIONS */

    STARTING_CONTAINER(ServletContainerLogEvent.CONTAINER_BLOCK, 0, Level.INFO),

    CREATING_CONNECTOR(ServletContainerLogEvent.CONTAINER_BLOCK, 1, Level.INFO),

    STOPPING_CONTAINER(ServletContainerLogEvent.CONTAINER_BLOCK, 2, Level.INFO),

    FAILED_TO_START_CONTAINER(ServletContainerLogEvent.CONTAINER_BLOCK, 3, Level.ERROR),

    FAILED_TO_STOP_CONTAINER(ServletContainerLogEvent.CONTAINER_BLOCK, 4, Level.ERROR),

    PORT_IN_USE(ServletContainerLogEvent.CONTAINER_BLOCK, 5, Level.ERROR),

    CREATING_CONTEXT(ServletContainerLogEvent.CONTEXT_BLOCK, 0, Level.INFO),

    STARTING_CONTEXT(ServletContainerLogEvent.CONTEXT_BLOCK, 1, Level.INFO),

    REMOVING_CONTEXT(ServletContainerLogEvent.CONTEXT_BLOCK, 2, Level.INFO),

    FAILED_TO_CREATE_CONTEXT(ServletContainerLogEvent.CONTEXT_BLOCK, 3, Level.ERROR),

    FAILED_TO_START_CONTEXT_DUE_TO_EXISING_CONTEXT_PATH(ServletContainerLogEvent.CONTEXT_BLOCK, 4, Level.ERROR),

    FAILED_TO_START_CONTEXT_DUE_TO_UNKNOWN_ERROR(ServletContainerLogEvent.CONTEXT_BLOCK, 5, Level.ERROR),

    FAILED_TO_DEPLOY_WAR(ServletContainerLogEvent.WAR_BLOCK, 0, Level.ERROR);

    /* END OF ENUM DEFINITIONS */

    private static final int CONTAINER_BLOCK = 0;

    private static final int CONTEXT_BLOCK = 1000;

    private static final int WAR_BLOCK = 2000;

    private static final String SUBSYSTEM_CODE = "SC";

    private static final String SUBSYSTEM_NAME = "ServletContainer";

    private final LogEventDelegate delegate;

    private ServletContainerLogEvent(int block, int code, Level level) {
        this.delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, block + code, level);
    }

    public String getEventCode() {
        return this.delegate.getEventCode();
    }

    public Level getLevel() {
        return this.delegate.getLevel();
    }

    public String getSubsystemName() {
        return SUBSYSTEM_NAME;
    }

}
