/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.servlet.tomcat;

import javax.servlet.Servlet;

import org.apache.catalina.core.StandardWrapper;

import com.springsource.server.serviceability.ffdc.NonNull;
import com.springsource.server.servlet.core.DynamicContext;

/**
 * Tomcat-based implementation of the {@link DynamicContext} interface.
 * 
 * @see TomcatContext
 * @see DynamicContext
 * @see com.springsource.server.servlet.core.ServletContainer
 * @author Sam Brannen
 * @author Rob Harrop
 * @since 1.0
 */
public class TomcatDynamicContext extends TomcatContext implements DynamicContext {

    /**
     * Creates a new TomcatContext with the supplied Catalina {@link org.apache.catalina.Context context}.
     * 
     * @param catalinaContext the underlying Catalina context to use; must not be <code>null</code>
     */
    public TomcatDynamicContext(@NonNull org.apache.catalina.Context catalinaContext) {
        super(catalinaContext);
    }

    /**
     * {@inheritDoc}
     */
    public void addServlet(final String servletName, final Servlet servlet) {
        final StandardWrapper wrapper = new StandardWrapper();
        wrapper.setServletClass(ProxyServlet.class.getName());
        wrapper.setServletName(servletName);
        wrapper.addInitParameter(ProxyServlet.INIT_PARAM_PROXY_SERVLET, servletName);
        getServletContext().setAttribute(servletName, servlet);
        getCatalinaContext().addChild(wrapper);
    }

    /**
     * {@inheritDoc}
     */
    public void addServletMapping(String servletName, String mappingPath) {
        getCatalinaContext().addServletMapping(mappingPath, servletName);
    }

}
