/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.web.core;

import java.util.Set;

import com.springsource.server.deployer.core.DeploymentContext;
import com.springsource.server.deployer.core.Module;
import com.springsource.server.deployer.core.ModuleDeployer;
import com.springsource.server.kernel.core.BundleStarter;
import com.springsource.server.osgi.framework.OsgiFramework;
import com.springsource.server.osgi.manifest.BundleManifestFactory;
import com.springsource.server.servlet.core.DeployedWebApplicationNamesRegistry;
import com.springsource.server.servlet.core.ServletContainer;

/**
 * This deployer implements {@link ModuleDeployer} with standard Java EE WAR deployment capability.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is thread-safe.
 * 
 * @author Glyn Normington
 * @author Sam Brannen
 * @since 1.0
 */
class WarDeployer implements ModuleDeployer {

    private static final String WAR_EXTENSION = ".war";

    private final BundleManifestFactory bundleManifestFactory;

    private final OsgiFramework osgi;

    private final ServletContainer servletContainer;

    private final DeployedWebApplicationNamesRegistry deployedWebApplicationNamesRegistry;

    private final BundleStarter bundleStarter;

    public WarDeployer(OsgiFramework osgi, BundleManifestFactory bundleManifestFactory, ServletContainer servletContainer,
        DeployedWebApplicationNamesRegistry deployedWebApplicationNamesRegistry, BundleStarter bundleStarter) {
        this.osgi = osgi;
        this.bundleManifestFactory = bundleManifestFactory;
        this.servletContainer = servletContainer;
        this.deployedWebApplicationNamesRegistry = deployedWebApplicationNamesRegistry;
        this.bundleStarter = bundleStarter;
    }

    /**
     * {@inheritDoc}
     */
    public int getOrder() {
        return WAR_ORDER;
    }

    /**
     * {@inheritDoc}
     */
    public boolean canDeploy(DeploymentContext deploymentContext, Module module) {
        if (module.getModuleData().getFilename().toLowerCase().endsWith(WAR_EXTENSION)) {
            module.setPersonality(new WarModulePersonality(this.osgi, this.bundleManifestFactory, this.servletContainer, module,
                this.deployedWebApplicationNamesRegistry, deploymentContext, this.bundleStarter));
            return true;
        }
        return false;
    }

    /**
     * Always returns &quot;{@link WarModulePersonality#PERSONALITY}&quot;.
     */
    public final String getPersonality() {
        return WarModulePersonality.PERSONALITY;
    }

    /**
     * {@inheritDoc}
     */
    public Set<PersonalityBundle> getBundles(DeploymentContext deploymentContext) {
        return null;
    }

}
