/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.web.core.internal;

import com.springsource.server.serviceability.logging.LogEvent;
import com.springsource.server.serviceability.logging.LogEventDelegate;
import com.springsource.server.serviceability.output.Level;

/**
 * Custom {@link LogEvent} enums for the web subsystem.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
public enum WebLogEvent implements LogEvent {

    /* START OF ENUM DEFINITIONS */

    WEB_BUNDLE_FAILED_TO_PUBLISH_APPLICATION_CONTEXT(WebLogEvent.CONTEXT_BLOCK, 0, Level.ERROR),

    WEB_BUNDLE_FAILED_TO_PUBLISH_APPLICATION_CONTEXT_WITHIN_TIMEOUT(WebLogEvent.CONTEXT_BLOCK, 1, Level.ERROR);

    /* END OF ENUM DEFINITIONS */

    private static final int CONTEXT_BLOCK = 1000;

    private static final String SUBSYSTEM_CODE = "WE";

    private static final String SUBSYSTEM_NAME = "Web";

    private final LogEventDelegate delegate;

    private WebLogEvent(int block, int code, Level level) {
        this.delegate = new LogEventDelegate(SUBSYSTEM_NAME, SUBSYSTEM_CODE, block + code, level);
    }

    public String getEventCode() {
        return this.delegate.getEventCode();
    }

    public Level getLevel() {
        return this.delegate.getLevel();
    }

    public String getSubsystemName() {
        return SUBSYSTEM_NAME;
    }

}
