/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.web.core.internal.webxml;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * Abstract superclass for parameters.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Immutable and therefore thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
abstract class AbstractParam implements DeploymentDescriptorElement {

    protected static final String PARAM_NAME_ELEMENT = "param-name";

    protected static final String PARAM_VALUE_ELEMENT = "param-value";

    private final String name;

    private final String value;

    /**
     * Creates a new <code>AbstractParam</code> element with the supplied <code>name</code> and <code>value</code>.
     */
    public AbstractParam(String name, String value) {
        this.name = name;
        this.value = value;
    }

    /**
     * {@inheritDoc}
     */
    public void appendToDocument(Document doc, Element root) {
        Element contextParamElement = doc.createElement(getElementName());
        WebXmlBuilder.appendTextElement(doc, contextParamElement, PARAM_NAME_ELEMENT, getName());
        WebXmlBuilder.appendTextElement(doc, contextParamElement, PARAM_VALUE_ELEMENT, getValue());
        root.appendChild(contextParamElement);
    }

    /**
     * Gets the name of the element represented by this <code>AbstractParam</code>.
     */
    protected abstract String getElementName();

    /**
     * Gets the parameter's name.
     */
    public final String getName() {
        return name;
    }

    /**
     * Gets the parameter's value.
     */
    public final String getValue() {
        return value;
    }

}
