/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.web.core.internal.webxml;

import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * Object representation of a Java EE web application deployment descriptor (i.e., &quot;<code>web.xml</code>&quot;).
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Mutable POJO and therefore <strong>not</strong> thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 */
class DeploymentDescriptor {

    private List<ServletContextListener> servletContextListeners = new ArrayList<ServletContextListener>();

    private List<ContextParam> contextParams = new ArrayList<ContextParam>();

    private List<Servlet> servlets = new ArrayList<Servlet>();

    private List<Filter> filters = new ArrayList<Filter>();

    private SessionConfig sessionConfig;

    private WelcomeFile welcomeFile;

    private List<ErrorPage> errorPages = new ArrayList<ErrorPage>();

    /**
     * @return
     */
    public List<ServletContextListener> getServletContextListeners() {
        return this.servletContextListeners;
    }

    /**
     * @param
     */
    public void setServletContextListeners(List<ServletContextListener> servletContextListeners) {
        this.servletContextListeners = servletContextListeners;
    }

    /**
     * @return
     */
    public List<ContextParam> getContextParams() {
        return this.contextParams;
    }

    /**
     * @param
     */
    public void setContextParams(List<ContextParam> contextParams) {
        this.contextParams = contextParams;
    }

    /**
     * @return
     */
    public List<Servlet> getServlets() {
        return this.servlets;
    }

    /**
     * @param
     */
    public void setServlets(List<Servlet> servlets) {
        this.servlets = servlets;
    }

    /**
     * @return
     */
    public List<Filter> getFilters() {
        return this.filters;
    }

    /**
     * @param
     */
    public void setFilters(List<Filter> filters) {
        this.filters = filters;
    }

    /**
     * @return
     */
    public SessionConfig getSessionConfig() {
        return this.sessionConfig;
    }

    /**
     * @param
     */
    public void setSessionConfig(SessionConfig sessionConfig) {
        this.sessionConfig = sessionConfig;
    }

    /**
     * @return
     */
    public WelcomeFile getWelcomeFile() {
        return this.welcomeFile;
    }

    /**
     * @param
     */
    public void setWelcomeFile(WelcomeFile welcomeFile) {
        this.welcomeFile = welcomeFile;
    }

    /**
     * @return
     */
    public List<ErrorPage> getErrorPages() {
        return this.errorPages;
    }

    /**
     * @param
     */
    public void setErrorPages(List<ErrorPage> errorPages) {
        this.errorPages = errorPages;
    }

    public void writeToDocument(Element root, Document doc) {
        appendContextParams(doc, root);
        appendServletContextListeners(doc, root);
        appendFilters(doc, root);
        appendServlets(doc, root);
        appendSessionConfig(doc, root);
        appendWelcomeFile(doc, root);
        appendErrorPages(doc, root);
    }

    protected void appendServletContextListeners(Document doc, Element root) {
        for (ServletContextListener servletContextListener : getServletContextListeners()) {
            servletContextListener.appendToDocument(doc, root);
        }
    }

    protected void appendContextParams(Document doc, Element root) {
        for (ContextParam contextParam : getContextParams()) {
            contextParam.appendToDocument(doc, root);
        }
    }

    protected void appendFilters(Document doc, Element root) {
        for (Filter filter : getFilters()) {
            filter.appendToDocument(doc, root);
        }
    }

    protected void appendServlets(Document doc, Element root) {
        for (Servlet servlet : getServlets()) {
            servlet.appendToDocument(doc, root);
        }
    }

    protected void appendErrorPages(Document doc, Element root) {
        for (ErrorPage errorPage : getErrorPages()) {
            errorPage.appendToDocument(doc, root);
        }
    }

    protected void appendSessionConfig(Document doc, Element root) {
        if (getSessionConfig() != null) {
            getSessionConfig().appendToDocument(doc, root);
        }
    }

    protected void appendWelcomeFile(Document doc, Element root) {
        if (getWelcomeFile() != null) {
            getWelcomeFile().appendToDocument(doc, root);
        }
    }

}
