/* 
 * This file is part of the SpringSource dm Server.
 * 
 * Copyright (C) 2008 SpringSource Inc.
 * 
 * The SpringSource dm Server is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * The SpringSource dm Server is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * the SpringSource dm Server. If not, see <http://www.gnu.org/licenses/>.
 */

package com.springsource.server.web.core.internal.webxml;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * Object representation of <code>web.xml</code>'s <code>&lt;welcome-file&gt;</code> element.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Immutable and therefore thread-safe.
 * 
 * @author Sam Brannen
 * @since 1.0
 * @see DeploymentDescriptor
 */
class WelcomeFile implements DeploymentDescriptorElement {

    protected static final String WELCOME_FILE_ELEMENT = "welcome-file";

    private static final String WELCOME_FILE_LIST_ELEMENT = "welcome-file-list";

    private final String[] welcomeFiles;

    /**
     * Creates a new <code>WelcomeFile</code> element with the supplied list of welcome files.
     */
    public WelcomeFile(String[] welcomeFiles) {
        this.welcomeFiles = welcomeFiles;
    }

    /**
     * {@inheritDoc}
     */
    public void appendToDocument(Document doc, Element root) {
        Element welcomeFileListElement = doc.createElement(WELCOME_FILE_LIST_ELEMENT);
        for (String welcomeFile : this.welcomeFiles) {
            WebXmlBuilder.appendTextElement(doc, welcomeFileListElement, WELCOME_FILE_ELEMENT, welcomeFile);
        }
        root.appendChild(welcomeFileListElement);
    }

    /**
     * Gets the list of welcome files.
     */
    public String[] getWelcomeFiles() {
        return this.welcomeFiles;
    }

}
